# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_webui_friends.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_clientserver_friends_pb2 as steammessages__clientserver__friends__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_webui_friends.proto',
  package='',
  syntax='proto2',
  serialized_options=_b('\220\001\001'),
  serialized_pb=_b('\n!steammessages_webui_friends.proto\x1a steammessages_unified_base.proto\x1a\x18steammessages_base.proto\x1a(steammessages_clientserver_friends.proto\">\n\x1a\x43\x43ommunity_GetApps_Request\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\x05\x12\x10\n\x08language\x18\x02 \x01(\r\"B\n\x1b\x43\x43ommunity_GetApps_Response\x12#\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x15.CCDDBAppDetailCommon\"T\n1CCommunity_GetAppRichPresenceLocalization_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x10\n\x08language\x18\x02 \x01(\t\"\x97\x01\n2CCommunity_GetAppRichPresenceLocalization_Response\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12R\n\x0btoken_lists\x18\x02 \x03(\x0b\x32=.CCommunity_GetAppRichPresenceLocalization_Response_TokenList\"W\n8CCommunity_GetAppRichPresenceLocalization_Response_Token\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9b\x01\n<CCommunity_GetAppRichPresenceLocalization_Response_TokenList\x12\x10\n\x08language\x18\x01 \x01(\t\x12I\n\x06tokens\x18\x02 \x03(\x0b\x32\x39.CCommunity_GetAppRichPresenceLocalization_Response_Token\"\xf6\x01\n\x12\x43\x43ommunity_Comment\x12\x12\n\ngidcomment\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x11\n\ttimestamp\x18\x03 \x01(\r\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x0f\n\x07upvotes\x18\x05 \x01(\x05\x12\x0e\n\x06hidden\x18\x06 \x01(\x08\x12\x16\n\x0ehidden_by_user\x18\x07 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x08 \x01(\x08\x12!\n\tipaddress\x18\t \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x14\n\x0ctotal_hidden\x18\n \x01(\x05\x12\x17\n\x0fupvoted_by_user\x18\x0b \x01(\x08\"\x88\x03\n$CCommunity_GetCommentThread_Response\x12%\n\x08\x63omments\x18\x01 \x03(\x0b\x32\x13.CCommunity_Comment\x12-\n\x10\x64\x65leted_comments\x18\x02 \x03(\x0b\x32\x13.CCommunity_Comment\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x04 \x01(\x06\x12\r\n\x05start\x18\x05 \x01(\x05\x12\r\n\x05\x63ount\x18\x06 \x01(\x05\x12\x13\n\x0btotal_count\x18\x07 \x01(\x05\x12\x0f\n\x07upvotes\x18\x08 \x01(\x05\x12\x10\n\x08upvoters\x18\t \x03(\r\x12\x17\n\x0fuser_subscribed\x18\n \x01(\x08\x12\x14\n\x0cuser_upvoted\x18\x0b \x01(\x08\x12\x18\n\x10\x61nswer_commentid\x18\x0c \x01(\x06\x12\x14\n\x0c\x61nswer_actor\x18\r \x01(\r\x12\x19\n\x11\x61nswer_actor_rank\x18\x0e \x01(\x05\x12\x10\n\x08\x63\x61n_post\x18\x0f \x01(\x08\"v\n\'CCommunity_PostCommentToThread_Response\x12\x12\n\ngidcomment\x18\x01 \x01(\x06\x12\x17\n\x0f\x63ommentthreadid\x18\x02 \x01(\x06\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x0f\n\x07upvotes\x18\x04 \x01(\x05\"-\n+CCommunity_DeleteCommentFromThread_Response\"\x89\x01\n%CCommunity_RateCommentThread_Response\x12\x12\n\ngidcomment\x18\x01 \x01(\x04\x12\x17\n\x0f\x63ommentthreadid\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x0f\n\x07upvotes\x18\x04 \x01(\r\x12\x13\n\x0bhas_upvoted\x18\x05 \x01(\x08\"\x9c\x01\n+CCommunity_GetCommentThreadRatings_Response\x12\x17\n\x0f\x63ommentthreadid\x18\x01 \x01(\x04\x12\x12\n\ngidcomment\x18\x02 \x01(\x04\x12\x0f\n\x07upvotes\x18\x03 \x01(\r\x12\x13\n\x0bhas_upvoted\x18\x04 \x01(\x08\x12\x1a\n\x12upvoter_accountids\x18\x05 \x03(\r\"j\n\'CCommunity_RateClanAnnouncement_Request\x12\x16\n\x0e\x61nnouncementid\x18\x01 \x01(\x04\x12\x0f\n\x07vote_up\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lan_accountid\x18\x03 \x01(\r\"*\n(CCommunity_RateClanAnnouncement_Response\"K\n1CCommunity_GetClanAnnouncementVoteForUser_Request\x12\x16\n\x0e\x61nnouncementid\x18\x01 \x01(\x04\"Z\n2CCommunity_GetClanAnnouncementVoteForUser_Response\x12\x10\n\x08voted_up\x18\x01 \x01(\x08\x12\x12\n\nvoted_down\x18\x02 \x01(\x08\"i\n$CCommunity_GetAvatarHistory_Response\x12\x41\n\x07\x61vatars\x18\x01 \x03(\x0b\x32\x30.CCommunity_GetAvatarHistory_Response_AvatarData\"p\n/CCommunity_GetAvatarHistory_Response_AvatarData\x12\x13\n\x0b\x61vatar_sha1\x18\x01 \x01(\t\x12\x15\n\ruser_uploaded\x18\x02 \x01(\x08\x12\x11\n\ttimestamp\x18\x03 \x01(\r\"/\n\x0c\x43\x41ppPriority\x12\x10\n\x08priority\x18\x01 \x01(\r\x12\r\n\x05\x61ppid\x18\x02 \x03(\r\"W\n+CCommunity_GetUserPartnerEventNews_Response\x12(\n\x07results\x18\x01 \x03(\x0b\x32\x17.CClanMatchEventByRange\"\xc3\x01\n\x1d\x43\x43ommunity_PartnerEventResult\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12\x18\n\x10\x61nnouncement_gid\x18\x03 \x01(\x06\x12\r\n\x05\x61ppid\x18\x04 \x01(\r\x12\x19\n\x11possible_takeover\x18\x05 \x01(\x08\x12 \n\x15rtime32_last_modified\x18\x06 \x01(\r:\x01\x30\x12\x19\n\x11user_app_priority\x18\x07 \x01(\x05\"[\n(CCommunity_GetBestEventsForUser_Response\x12/\n\x07results\x18\x01 \x03(\x0b\x32\x1e.CCommunity_PartnerEventResult\"9\n7CCommunity_ClearUserPartnerEventsAppPriorities_Response\"O\n#CCommunity_PartnerEventsAppPriority\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11user_app_priority\x18\x02 \x01(\x05\"q\n5CCommunity_GetUserPartnerEventsAppPriorities_Response\x12\x38\n\npriorities\x18\x01 \x03(\x0b\x32$.CCommunity_PartnerEventsAppPriority\"9\n7CCommunity_ClearSinglePartnerEventsAppPriority_Response\"1\n/CCommunity_PartnerEventsShowMoreForApp_Response\"1\n/CCommunity_PartnerEventsShowLessForApp_Response\"\x81\x01\n+CCommunity_MarkPartnerEventsForUser_Request\x12R\n\x08markings\x18\x01 \x03(\x0b\x32@.CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking\"\xaf\x01\n?CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12\"\n\x10\x64isplay_location\x18\x03 \x01(\x05\x42\x08\x82\xb5\x18\x04\x65num\x12\x12\n\nmark_shown\x18\x04 \x01(\x08\x12\x11\n\tmark_read\x18\x05 \x01(\x08\".\n,CCommunity_MarkPartnerEventsForUser_Response\"\x84\x01\n1CCommunity_GetUserPartnerEventViewStatus_Response\x12O\n\x06\x65vents\x18\x01 \x03(\x0b\x32?.CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent\"\x9d\x01\n>CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent\x12\x11\n\tevent_gid\x18\x01 \x01(\x06\x12\x17\n\x0flast_shown_time\x18\x02 \x01(\r\x12\x16\n\x0elast_read_time\x18\x03 \x01(\r\x12\x17\n\x0f\x63lan_account_id\x18\x04 \x01(\r\"=\n.CWebRTCClient_InitiateWebRTCConnection_Request\x12\x0b\n\x03sdp\x18\x01 \x01(\t\"M\n/CWebRTCClient_InitiateWebRTCConnection_Response\x12\x1a\n\x12remote_description\x18\x01 \x01(\t\"\x8b\x01\n+CWebRTC_WebRTCSessionConnected_Notification\x12\x0c\n\x04ssrc\x18\x01 \x01(\r\x12\x11\n\tclient_ip\x18\x02 \x01(\r\x12\x13\n\x0b\x63lient_port\x18\x03 \x01(\r\x12\x11\n\tserver_ip\x18\x04 \x01(\r\x12\x13\n\x0bserver_port\x18\x05 \x01(\r\"\xde\x01\n2CWebRTC_WebRTCUpdateRemoteDescription_Notification\x12\x1a\n\x12remote_description\x18\x01 \x01(\t\x12\"\n\x1aremote_description_version\x18\x02 \x01(\x04\x12h\n\x13ssrcs_to_accountids\x18\x03 \x03(\x0b\x32K.CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping\"m\nJCWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping\x12\x0c\n\x04ssrc\x18\x01 \x01(\r\x12\x11\n\taccountid\x18\x02 \x01(\r\"\xdb\x01\n9CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request\x12\x18\n\x10ip_webrtc_server\x18\x01 \x01(\r\x12\x1a\n\x12port_webrtc_server\x18\x02 \x01(\r\x12 \n\x18ip_webrtc_session_client\x18\x03 \x01(\r\x12\"\n\x1aport_webrtc_session_client\x18\x04 \x01(\r\x12\"\n\x1aremote_description_version\x18\x05 \x01(\x04\"<\n:CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response\"A\n&CVoiceChat_RequestOneOnOneChat_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\"?\n\'CVoiceChat_RequestOneOnOneChat_Response\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\"^\n-CVoiceChat_OneOnOneChatRequested_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_partner\x18\x02 \x01(\x06\"p\n%CVoiceChat_AnswerOneOnOneChat_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_partner\x18\x02 \x01(\x06\x12\x18\n\x10\x61\x63\x63\x65pted_request\x18\x03 \x01(\x08\"(\n&CVoiceChat_AnswerOneOnOneChat_Response\"~\n3CVoiceChat_OneOnOneChatRequestResponse_Notification\x12\x14\n\x0cvoicechat_id\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_partner\x18\x02 \x01(\x06\x12\x18\n\x10\x61\x63\x63\x65pted_request\x18\x03 \x01(\x08\"=\n\"CVoiceChat_EndOneOnOneChat_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\"%\n#CVoiceChat_EndOneOnOneChat_Response\"U\n$CVoiceChat_LeaveOneOnOneChat_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\x12\x14\n\x0cvoice_chatid\x18\x02 \x01(\x06\"\'\n%CVoiceChat_LeaveOneOnOneChat_Response\"\xdd\x01\n+CVoiceChat_UserJoinedVoiceChat_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\x0e\n\x06\x63hatid\x18\x03 \x01(\x04\x12 \n\x18one_on_one_steamid_lower\x18\x04 \x01(\x06\x12!\n\x19one_on_one_steamid_higher\x18\x05 \x01(\x06\x12\x15\n\rchat_group_id\x18\x06 \x01(\x04\x12\x16\n\x0euser_sessionid\x18\x07 \x01(\r\"\xe0\x01\n\'CVoiceChat_UserVoiceStatus_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\x1e\n\x16user_muted_mic_locally\x18\x03 \x01(\x08\x12!\n\x19user_muted_output_locally\x18\x04 \x01(\x08\x12#\n\x1buser_has_no_mic_for_session\x18\x05 \x01(\x08\x12!\n\x19user_webaudio_sample_rate\x18\x06 \x01(\x05\"y\n(CVoiceChat_AllMembersStatus_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x37\n\x05users\x18\x02 \x03(\x0b\x32(.CVoiceChat_UserVoiceStatus_Notification\"\x88\x02\n,CVoiceChat_UpdateVoiceChatWebRTCData_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x18\n\x10ip_webrtc_server\x18\x02 \x01(\r\x12\x1a\n\x12port_webrtc_server\x18\x03 \x01(\r\x12\x18\n\x10ip_webrtc_client\x18\x04 \x01(\r\x12\x1a\n\x12port_webrtc_client\x18\x05 \x01(\r\x12\x1e\n\x16ssrc_my_sending_stream\x18\x06 \x01(\r\x12\x12\n\nuser_agent\x18\x07 \x01(\t\x12\"\n\x1ahas_audio_worklets_support\x18\x08 \x01(\x08\"O\n-CVoiceChat_UpdateVoiceChatWebRTCData_Response\x12\x1e\n\x16send_client_voice_logs\x18\x01 \x01(\x08\"i\n,CVoiceChat_UploadClientVoiceChatLogs_Request\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12#\n\x1b\x63lient_voice_logs_new_lines\x18\x02 \x01(\t\"/\n-CVoiceChat_UploadClientVoiceChatLogs_Response\"$\n\"CVoiceChat_LeaveVoiceChat_Response\"\xdb\x01\n)CVoiceChat_UserLeftVoiceChat_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\x0e\n\x06\x63hatid\x18\x03 \x01(\x04\x12 \n\x18one_on_one_steamid_lower\x18\x04 \x01(\x06\x12!\n\x19one_on_one_steamid_higher\x18\x05 \x01(\x06\x12\x15\n\rchat_group_id\x18\x06 \x01(\x04\x12\x16\n\x0euser_sessionid\x18\x07 \x01(\r\"\xaa\x01\n&CVoiceChat_VoiceChatEnded_Notification\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x06\x12 \n\x18one_on_one_steamid_lower\x18\x02 \x01(\x06\x12!\n\x19one_on_one_steamid_higher\x18\x03 \x01(\x06\x12\x0e\n\x06\x63hatid\x18\x04 \x01(\x04\x12\x15\n\rchat_group_id\x18\x05 \x01(\x04\"H\n(CSteamTV_CreateBroadcastChannel_Response\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"m\n\'CSteamTV_GetBroadcastChannelID_Response\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x13\n\x0bunique_name\x18\x02 \x01(\t\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\".\n,CSteamTV_SetBroadcastChannelProfile_Response\"\xe4\x01\n,CSteamTV_GetBroadcastChannelProfile_Response\x12\x13\n\x0bunique_name\x18\x01 \x01(\t\x12\x15\n\rowner_steamid\x18\x02 \x01(\x06\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08language\x18\x04 \x01(\t\x12\x10\n\x08headline\x18\x05 \x01(\t\x12\x0f\n\x07summary\x18\x06 \x01(\t\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\r\n\x05rules\x18\x08 \x01(\t\x12\x0e\n\x06panels\x18\t \x01(\t\x12\x14\n\x0cis_partnered\x18\n \x01(\x08\"H\n*CSteamTV_SetBroadcastChannelImage_Response\x12\x1a\n\x12replace_image_hash\x18\x01 \x01(\t\"r\n+CSteamTV_GetBroadcastChannelImages_Response\x12\x43\n\x06images\x18\x01 \x03(\x0b\x32\x33.CSteamTV_GetBroadcastChannelImages_Response_Images\"{\n2CSteamTV_GetBroadcastChannelImages_Response_Images\x12\x1c\n\nimage_type\x18\x01 \x01(\x05\x42\x08\x82\xb5\x18\x04\x65num\x12\x12\n\nimage_path\x18\x02 \x01(\t\x12\x13\n\x0bimage_index\x18\x03 \x01(\r\"n\n*CSteamTV_GetBroadcastChannelLinks_Response\x12@\n\x05links\x18\x01 \x03(\x0b\x32\x31.CSteamTV_GetBroadcastChannelLinks_Response_Links\"\xa7\x01\n0CSteamTV_GetBroadcastChannelLinks_Response_Links\x12\x12\n\nlink_index\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x18\n\x10link_description\x18\x03 \x01(\t\x12\x0c\n\x04left\x18\x04 \x01(\r\x12\x0b\n\x03top\x18\x05 \x01(\r\x12\r\n\x05width\x18\x06 \x01(\r\x12\x0e\n\x06height\x18\x07 \x01(\r\"\xac\x01\n5CSteamTV_SetBroadcastChannelLinkRegions_Request_Links\x12\x12\n\nlink_index\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x18\n\x10link_description\x18\x03 \x01(\t\x12\x0c\n\x04left\x18\x04 \x01(\r\x12\x0b\n\x03top\x18\x05 \x01(\r\x12\r\n\x05width\x18\x06 \x01(\r\x12\x0e\n\x06height\x18\x07 \x01(\r\"2\n0CSteamTV_SetBroadcastChannelLinkRegions_Response\"\x91\x02\n+CSteamTV_GetBroadcastChannelStatus_Response\x12\x0f\n\x07is_live\x18\x01 \x01(\x08\x12\x13\n\x0bis_disabled\x18\x02 \x01(\x08\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\x12\x0f\n\x07viewers\x18\x04 \x01(\x04\x12\r\n\x05views\x18\x05 \x01(\x04\x12\x1b\n\x13\x62roadcaster_steamid\x18\x06 \x01(\x06\x12\x15\n\rthumbnail_url\x18\x07 \x01(\t\x12\x11\n\tfollowers\x18\x08 \x01(\x04\x12\x13\n\x0bsubscribers\x18\t \x01(\x04\x12\x13\n\x0bunique_name\x18\n \x01(\t\x12\x1c\n\x14\x62roadcast_session_id\x18\x0b \x01(\x04\"\x98\x03\n\x18GetBroadcastChannelEntry\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x13\n\x0bunique_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x61ppid\x18\x04 \x01(\r\x12\x0f\n\x07viewers\x18\x05 \x01(\x04\x12\r\n\x05views\x18\x06 \x01(\x04\x12\x15\n\rthumbnail_url\x18\x07 \x01(\t\x12\x11\n\tfollowers\x18\x08 \x01(\x04\x12\x10\n\x08headline\x18\t \x01(\t\x12\x12\n\navatar_url\x18\n \x01(\t\x12\x1b\n\x13\x62roadcaster_steamid\x18\x0b \x01(\x06\x12\x13\n\x0bsubscribers\x18\x0c \x01(\x04\x12\x16\n\x0e\x62\x61\x63kground_url\x18\r \x01(\t\x12\x13\n\x0bis_featured\x18\x0e \x01(\x08\x12\x13\n\x0bis_disabled\x18\x0f \x01(\x08\x12\x0f\n\x07is_live\x18\x10 \x01(\x08\x12\x10\n\x08language\x18\x11 \x01(\t\x12\x0f\n\x07reports\x18\x12 \x01(\r\x12\x14\n\x0cis_partnered\x18\x13 \x01(\x08\"S\n%CSteamTV_GetFollowedChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"U\n\'CSteamTV_GetSubscribedChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"?\n(CSteamTV_FollowBroadcastChannel_Response\x12\x13\n\x0bis_followed\x18\x01 \x01(\x08\"D\n+CSteamTV_SubscribeBroadcastChannel_Response\x12\x15\n\ris_subscribed\x18\x01 \x01(\x08\"*\n(CSteamTV_ReportBroadcastChannel_Response\"^\n0CSteamTV_GetBroadcastChannelInteraction_Response\x12\x13\n\x0bis_followed\x18\x01 \x01(\x08\x12\x15\n\ris_subscribed\x18\x02 \x01(\x08\"\xb5\x01\n\rCSteamTV_Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0f\n\x07viewers\x18\x04 \x01(\x04\x12+\n\x08\x63hannels\x18\x05 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\x14\n\x0crelease_date\x18\x06 \x01(\t\x12\x11\n\tdeveloper\x18\x07 \x01(\t\x12\x11\n\tpublisher\x18\x08 \x01(\t\"=\n\x1a\x43SteamTV_GetGames_Response\x12\x1f\n\x07results\x18\x01 \x03(\x0b\x32\x0e.CSteamTV_Game\"K\n\x1d\x43SteamTV_GetChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"\x89\x01\n1CSteamTV_GetBroadcastChannelBroadcasters_Response\x12T\n\x0c\x62roadcasters\x18\x01 \x03(\x0b\x32>.CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster\"r\n=CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nrtmp_token\x18\x03 \x01(\t\"z\n\x10\x43SteamTV_ChatBan\x12\x16\n\x0eissuer_steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hatter_steamid\x18\x02 \x01(\x06\x12\x14\n\x0ctime_expires\x18\x03 \x01(\t\x12\x11\n\tpermanent\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\"\x87\x01\n\x1b\x43SteamTV_AddChatBan_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hatter_steamid\x18\x02 \x01(\x06\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\x12\x11\n\tpermanent\x18\x04 \x01(\x08\x12\x0c\n\x04undo\x18\x05 \x01(\x08\"\x1e\n\x1c\x43SteamTV_AddChatBan_Response\"C\n\x1d\x43SteamTV_GetChatBans_Response\x12\"\n\x07results\x18\x01 \x03(\x0b\x32\x11.CSteamTV_ChatBan\"j\n!CSteamTV_AddChatModerator_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\x12\x19\n\x11moderator_steamid\x18\x02 \x01(\x06\x12\x0c\n\x04undo\x18\x03 \x01(\x08\"$\n\"CSteamTV_AddChatModerator_Response\"B\n\"CSteamTV_GetChatModerators_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"7\n\x16\x43SteamTV_ChatModerator\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n#CSteamTV_GetChatModerators_Response\x12(\n\x07results\x18\x01 \x03(\x0b\x32\x17.CSteamTV_ChatModerator\"\x1e\n\x1c\x43SteamTV_AddWordBan_Response\"0\n\x1d\x43SteamTV_GetWordBans_Response\x12\x0f\n\x07results\x18\x01 \x03(\t\"9\n\x19\x43SteamTV_JoinChat_Request\x12\x1c\n\x14\x62roadcast_channel_id\x18\x01 \x01(\x06\"a\n\x1a\x43SteamTV_JoinChat_Response\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x19\n\x11view_url_template\x18\x02 \x01(\t\x12\x17\n\x0f\x66lair_group_ids\x18\x03 \x03(\x04\"F\n\x18\x43SteamTV_Search_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"g\n(CSteamTV_GetSteamTVUserSettings_Response\x12\x19\n\x11stream_live_email\x18\x01 \x01(\x08\x12 \n\x18stream_live_notification\x18\x02 \x01(\x08\"*\n(CSteamTV_SetSteamTVUserSettings_Response\"V\n(CSteamTV_GetMyBroadcastChannels_Response\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"S\n\"CSteamTV_HomePageTemplate_Takeover\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\"s\n$CSteamTV_HomePageTemplate_SingleGame\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\r\n\x05title\x18\x03 \x01(\t\"_\n\rGameListEntry\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tgame_name\x18\x02 \x01(\t\x12,\n\tbroadcast\x18\x03 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\"T\n\"CSteamTV_HomePageTemplate_GameList\x12\x1f\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x0e.GameListEntry\x12\r\n\x05title\x18\x02 \x01(\t\"f\n&CSteamTV_HomePageTemplate_QuickExplore\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"f\n&CSteamTV_HomePageTemplate_ConveyorBelt\x12-\n\nbroadcasts\x18\x01 \x03(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"z\n$CSteamTV_HomePageTemplate_WatchParty\x12,\n\tbroadcast\x18\x01 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\x12\x15\n\rchat_group_id\x18\x03 \x01(\x04\"b\n#CSteamTV_HomePageTemplate_Developer\x12,\n\tbroadcast\x18\x01 \x01(\x0b\x32\x19.GetBroadcastChannelEntry\x12\r\n\x05title\x18\x02 \x01(\t\"0\n\x1f\x43SteamTV_HomePageTemplate_Event\x12\r\n\x05title\x18\x01 \x01(\t\"\x8f\x04\n\x1b\x43SteamTV_HomePageContentRow\x12\x1f\n\rtemplate_type\x18\x01 \x01(\x05\x42\x08\x82\xb5\x18\x04\x65num\x12\x35\n\x08takeover\x18\x02 \x01(\x0b\x32#.CSteamTV_HomePageTemplate_Takeover\x12:\n\x0bsingle_game\x18\x03 \x01(\x0b\x32%.CSteamTV_HomePageTemplate_SingleGame\x12\x36\n\tgame_list\x18\x04 \x01(\x0b\x32#.CSteamTV_HomePageTemplate_GameList\x12>\n\rquick_explore\x18\x05 \x01(\x0b\x32\'.CSteamTV_HomePageTemplate_QuickExplore\x12>\n\rconveyor_belt\x18\x06 \x01(\x0b\x32\'.CSteamTV_HomePageTemplate_ConveyorBelt\x12:\n\x0bwatch_party\x18\x07 \x01(\x0b\x32%.CSteamTV_HomePageTemplate_WatchParty\x12\x37\n\tdeveloper\x18\x08 \x01(\x0b\x32$.CSteamTV_HomePageTemplate_Developer\x12/\n\x05\x65vent\x18\t \x01(\x0b\x32 .CSteamTV_HomePageTemplate_Event\"S\n%CSteamTV_GetHomePageContents_Response\x12*\n\x04rows\x18\x01 \x03(\x0b\x32\x1c.CSteamTV_HomePageContentRow\"\xea\x01\n\x1a\x43SteamTV_BroadcastClipInfo\x12\x19\n\x11\x62roadcast_clip_id\x18\x01 \x01(\x04\x12\x12\n\nchannel_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x1b\n\x13\x62roadcaster_steamid\x18\x04 \x01(\x06\x12\x17\n\x0f\x63reator_steamid\x18\x05 \x01(\x06\x12\x19\n\x11video_description\x18\x06 \x01(\t\x12\x11\n\tlive_time\x18\x07 \x01(\r\x12\x11\n\tlength_ms\x18\x08 \x01(\r\x12\x16\n\x0ethumbnail_path\x18\t \x01(\t\"p\n*CSteamTV_GetBroadcastChannelClips_Response\x12*\n\x05\x63lips\x18\x01 \x03(\x0b\x32\x1b.CSteamTV_BroadcastClipInfo\x12\x16\n\x0ethumbnail_host\x18\x02 \x01(\t\"P\n\x14\x43\x46riendsListCategory\x12\x0f\n\x07groupid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x61\x63\x63ountid_members\x18\x03 \x03(\r\"$\n\"CFriendsList_GetCategories_Request\"P\n#CFriendsList_GetCategories_Response\x12)\n\ncategories\x18\x01 \x03(\x0b\x32\x15.CFriendsListCategory\"U\n\x19\x43\x46riendsListFavoriteEntry\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x0e\n\x06\x63lanid\x18\x02 \x01(\r\x12\x15\n\rchat_group_id\x18\x03 \x01(\x04\"#\n!CFriendsList_GetFavorites_Request\"S\n\"CFriendsList_GetFavorites_Response\x12-\n\tfavorites\x18\x01 \x03(\x0b\x32\x1a.CFriendsListFavoriteEntry\"R\n!CFriendsList_SetFavorites_Request\x12-\n\tfavorites\x18\x01 \x03(\x0b\x32\x1a.CFriendsListFavoriteEntry\"$\n\"CFriendsList_SetFavorites_Response\"[\n*CFriendsList_FavoritesChanged_Notification\x12-\n\tfavorites\x18\x01 \x03(\x0b\x32\x1a.CFriendsListFavoriteEntry\"%\n#CFriendsList_GetFriendsList_Request\"S\n$CFriendsList_GetFriendsList_Response\x12+\n\x0b\x66riendslist\x18\x01 \x01(\x0b\x32\x16.CMsgClientFriendsList\"D\n!CClan_RespondToClanInvite_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\"$\n\"CClan_RespondToClanInvite_Response\"y\n*CProductImpressionsFromClient_Notification\x12K\n\x0bimpressions\x18\x01 \x03(\x0b\x32\x36.CProductImpressionsFromClient_Notification_Impression\"w\n5CProductImpressionsFromClient_Notification_Impression\x12\x16\n\x04type\x18\x01 \x01(\x05\x42\x08\x82\xb5\x18\x04\x65num\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x17\n\x0fnum_impressions\x18\x03 \x01(\r\"\x10\n\x0eNotImplemented2\xe5\x0e\n\tCommunity\x12\x44\n\x07GetApps\x12\x1b.CCommunity_GetApps_Request\x1a\x1c.CCommunity_GetApps_Response\x12\x89\x01\n\x1eGetAppRichPresenceLocalization\x12\x32.CCommunity_GetAppRichPresenceLocalization_Request\x1a\x33.CCommunity_GetAppRichPresenceLocalization_Response\x12J\n\x10GetCommentThread\x12\x0f.NotImplemented\x1a%.CCommunity_GetCommentThread_Response\x12P\n\x13PostCommentToThread\x12\x0f.NotImplemented\x1a(.CCommunity_PostCommentToThread_Response\x12X\n\x17\x44\x65leteCommentFromThread\x12\x0f.NotImplemented\x1a,.CCommunity_DeleteCommentFromThread_Response\x12L\n\x11RateCommentThread\x12\x0f.NotImplemented\x1a&.CCommunity_RateCommentThread_Response\x12X\n\x17GetCommentThreadRatings\x12\x0f.NotImplemented\x1a,.CCommunity_GetCommentThreadRatings_Response\x12k\n\x14RateClanAnnouncement\x12(.CCommunity_RateClanAnnouncement_Request\x1a).CCommunity_RateClanAnnouncement_Response\x12\x89\x01\n\x1eGetClanAnnouncementVoteForUser\x12\x32.CCommunity_GetClanAnnouncementVoteForUser_Request\x1a\x33.CCommunity_GetClanAnnouncementVoteForUser_Response\x12J\n\x10GetAvatarHistory\x12\x0f.NotImplemented\x1a%.CCommunity_GetAvatarHistory_Response\x12X\n\x17GetUserPartnerEventNews\x12\x0f.NotImplemented\x1a,.CCommunity_GetUserPartnerEventNews_Response\x12R\n\x14GetBestEventsForUser\x12\x0f.NotImplemented\x1a).CCommunity_GetBestEventsForUser_Response\x12w\n\x18MarkPartnerEventsForUser\x12,.CCommunity_MarkPartnerEventsForUser_Request\x1a-.CCommunity_MarkPartnerEventsForUser_Response\x12\x64\n\x1dGetUserPartnerEventViewStatus\x12\x0f.NotImplemented\x1a\x32.CCommunity_GetUserPartnerEventViewStatus_Response\x12`\n\x1bPartnerEventsShowMoreForApp\x12\x0f.NotImplemented\x1a\x30.CCommunity_PartnerEventsShowMoreForApp_Response\x12`\n\x1bPartnerEventsShowLessForApp\x12\x0f.NotImplemented\x1a\x30.CCommunity_PartnerEventsShowLessForApp_Response\x12p\n#ClearUserPartnerEventsAppPriorities\x12\x0f.NotImplemented\x1a\x38.CCommunity_ClearUserPartnerEventsAppPriorities_Response\x12l\n!GetUserPartnerEventsAppPriorities\x12\x0f.NotImplemented\x1a\x36.CCommunity_GetUserPartnerEventsAppPriorities_Response\x12p\n#ClearSinglePartnerEventsAppPriority\x12\x0f.NotImplemented\x1a\x38.CCommunity_ClearSinglePartnerEventsAppPriority_Response2\xae\x02\n\x0cWebRTCClient\x12}\n\x18InitiateWebRTCConnection\x12/.CWebRTCClient_InitiateWebRTCConnection_Request\x1a\x30.CWebRTCClient_InitiateWebRTCConnection_Response\x12\x9e\x01\n#AcknowledgeUpdatedRemoteDescription\x12:.CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request\x1a;.CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response2\xdf\x01\n\x19WebRTCClientNotifications\x12Y\n\x1cNotifyWebRTCSessionConnected\x12,.CWebRTC_WebRTCSessionConnected_Notification\x1a\x0b.NoResponse\x12g\n#NotifyWebRTCUpdateRemoteDescription\x12\x33.CWebRTC_WebRTCUpdateRemoteDescription_Notification\x1a\x0b.NoResponse2\xae\x06\n\tVoiceChat\x12z\n\x19UpdateVoiceChatWebRTCData\x12-.CVoiceChat_UpdateVoiceChatWebRTCData_Request\x1a..CVoiceChat_UpdateVoiceChatWebRTCData_Response\x12N\n\x15NotifyUserVoiceStatus\x12(.CVoiceChat_UserVoiceStatus_Notification\x1a\x0b.NoResponse\x12z\n\x19UploadClientVoiceChatLogs\x12-.CVoiceChat_UploadClientVoiceChatLogs_Request\x1a..CVoiceChat_UploadClientVoiceChatLogs_Response\x12\x46\n\x0eLeaveVoiceChat\x12\x0f.NotImplemented\x1a#.CVoiceChat_LeaveVoiceChat_Response\x12h\n\x13RequestOneOnOneChat\x12\'.CVoiceChat_RequestOneOnOneChat_Request\x1a(.CVoiceChat_RequestOneOnOneChat_Response\x12\x65\n\x12\x41nswerOneOnOneChat\x12&.CVoiceChat_AnswerOneOnOneChat_Request\x1a\'.CVoiceChat_AnswerOneOnOneChat_Response\x12\\\n\x0f\x45ndOneOnOneChat\x12#.CVoiceChat_EndOneOnOneChat_Request\x1a$.CVoiceChat_EndOneOnOneChat_Response\x12\x62\n\x11LeaveOneOnOneChat\x12%.CVoiceChat_LeaveOneOnOneChat_Request\x1a&.CVoiceChat_LeaveOneOnOneChat_Response2\xed\x04\n\x0fVoiceChatClient\x12V\n\x19NotifyUserJoinedVoiceChat\x12,.CVoiceChat_UserJoinedVoiceChat_Notification\x1a\x0b.NoResponse\x12R\n\x17NotifyUserLeftVoiceChat\x12*.CVoiceChat_UserLeftVoiceChat_Notification\x1a\x0b.NoResponse\x12L\n\x14NotifyVoiceChatEnded\x12\'.CVoiceChat_VoiceChatEnded_Notification\x1a\x0b.NoResponse\x12N\n\x15NotifyUserVoiceStatus\x12(.CVoiceChat_UserVoiceStatus_Notification\x1a\x0b.NoResponse\x12S\n\x19NotifyAllUsersVoiceStatus\x12).CVoiceChat_AllMembersStatus_Notification\x1a\x0b.NoResponse\x12Z\n\x1bNotifyOneOnOneChatRequested\x12..CVoiceChat_OneOnOneChatRequested_Notification\x1a\x0b.NoResponse\x12_\n\x1aNotifyOneOnOneChatResponse\x12\x34.CVoiceChat_OneOnOneChatRequestResponse_Notification\x1a\x0b.NoResponse2\xa2\x14\n\x07SteamTV\x12T\n\x16\x43reateBroadcastChannel\x12\x0f.NotImplemented\x1a).CSteamTV_CreateBroadcastChannel_Response\x12R\n\x15GetBroadcastChannelID\x12\x0f.NotImplemented\x1a(.CSteamTV_GetBroadcastChannelID_Response\x12\\\n\x1aSetBroadcastChannelProfile\x12\x0f.NotImplemented\x1a-.CSteamTV_SetBroadcastChannelProfile_Response\x12\\\n\x1aGetBroadcastChannelProfile\x12\x0f.NotImplemented\x1a-.CSteamTV_GetBroadcastChannelProfile_Response\x12X\n\x18SetBroadcastChannelImage\x12\x0f.NotImplemented\x1a+.CSteamTV_SetBroadcastChannelImage_Response\x12Z\n\x19GetBroadcastChannelImages\x12\x0f.NotImplemented\x1a,.CSteamTV_GetBroadcastChannelImages_Response\x12\x64\n\x1eSetBroadcastChannelLinkRegions\x12\x0f.NotImplemented\x1a\x31.CSteamTV_SetBroadcastChannelLinkRegions_Response\x12X\n\x18GetBroadcastChannelLinks\x12\x0f.NotImplemented\x1a+.CSteamTV_GetBroadcastChannelLinks_Response\x12\x66\n\x1fGetBroadcastChannelBroadcasters\x12\x0f.NotImplemented\x1a\x32.CSteamTV_GetBroadcastChannelBroadcasters_Response\x12N\n\x13GetFollowedChannels\x12\x0f.NotImplemented\x1a&.CSteamTV_GetFollowedChannels_Response\x12R\n\x15GetSubscribedChannels\x12\x0f.NotImplemented\x1a(.CSteamTV_GetSubscribedChannels_Response\x12Z\n\x19GetBroadcastChannelStatus\x12\x0f.NotImplemented\x1a,.CSteamTV_GetBroadcastChannelStatus_Response\x12T\n\x16\x46ollowBroadcastChannel\x12\x0f.NotImplemented\x1a).CSteamTV_FollowBroadcastChannel_Response\x12Z\n\x19SubscribeBroadcastChannel\x12\x0f.NotImplemented\x1a,.CSteamTV_SubscribeBroadcastChannel_Response\x12X\n\x18GetBroadcastChannelClips\x12\x0f.NotImplemented\x1a+.CSteamTV_GetBroadcastChannelClips_Response\x12T\n\x16ReportBroadcastChannel\x12\x0f.NotImplemented\x1a).CSteamTV_ReportBroadcastChannel_Response\x12\x64\n\x1eGetBroadcastChannelInteraction\x12\x0f.NotImplemented\x1a\x31.CSteamTV_GetBroadcastChannelInteraction_Response\x12\x38\n\x08GetGames\x12\x0f.NotImplemented\x1a\x1b.CSteamTV_GetGames_Response\x12>\n\x0bGetChannels\x12\x0f.NotImplemented\x1a\x1e.CSteamTV_GetChannels_Response\x12I\n\nAddChatBan\x12\x1c.CSteamTV_AddChatBan_Request\x1a\x1d.CSteamTV_AddChatBan_Response\x12>\n\x0bGetChatBans\x12\x0f.NotImplemented\x1a\x1e.CSteamTV_GetChatBans_Response\x12[\n\x10\x41\x64\x64\x43hatModerator\x12\".CSteamTV_AddChatModerator_Request\x1a#.CSteamTV_AddChatModerator_Response\x12^\n\x11GetChatModerators\x12#.CSteamTV_GetChatModerators_Request\x1a$.CSteamTV_GetChatModerators_Response\x12<\n\nAddWordBan\x12\x0f.NotImplemented\x1a\x1d.CSteamTV_AddWordBan_Response\x12>\n\x0bGetWordBans\x12\x0f.NotImplemented\x1a\x1e.CSteamTV_GetWordBans_Response\x12\x43\n\x08JoinChat\x12\x1a.CSteamTV_JoinChat_Request\x1a\x1b.CSteamTV_JoinChat_Response\x12\x34\n\x06Search\x12\x0f.NotImplemented\x1a\x19.CSteamTV_Search_Response\x12T\n\x16GetSteamTVUserSettings\x12\x0f.NotImplemented\x1a).CSteamTV_GetSteamTVUserSettings_Response\x12T\n\x16SetSteamTVUserSettings\x12\x0f.NotImplemented\x1a).CSteamTV_SetSteamTVUserSettings_Response\x12T\n\x16GetMyBroadcastChannels\x12\x0f.NotImplemented\x1a).CSteamTV_GetMyBroadcastChannels_Response\x12N\n\x13GetHomePageContents\x12\x0f.NotImplemented\x1a&.CSteamTV_GetHomePageContents_Response2\xfa\x02\n\x0b\x46riendsList\x12Z\n\rGetCategories\x12#.CFriendsList_GetCategories_Request\x1a$.CFriendsList_GetCategories_Response\x12]\n\x0eGetFriendsList\x12$.CFriendsList_GetFriendsList_Request\x1a%.CFriendsList_GetFriendsList_Response\x12W\n\x0cGetFavorites\x12\".CFriendsList_GetFavorites_Request\x1a#.CFriendsList_GetFavorites_Response\x12W\n\x0cSetFavorites\x12\".CFriendsList_SetFavorites_Request\x1a#.CFriendsList_SetFavorites_Response2a\n\x11\x46riendsListClient\x12L\n\x10\x46\x61voritesChanged\x12+.CFriendsList_FavoritesChanged_Notification\x1a\x0b.NoResponse2f\n\x04\x43lan\x12^\n\x13RespondToClanInvite\x12\".CClan_RespondToClanInvite_Request\x1a#.CClan_RespondToClanInvite_Response2W\n\x11\x45xperimentService\x12\x42\n\"ReportProductImpressionsFromClient\x12\x0f.NotImplemented\x1a\x0b.NoResponseB\x03\x90\x01\x01')
  ,
  dependencies=[steammessages__unified__base__pb2.DESCRIPTOR,steammessages__base__pb2.DESCRIPTOR,steammessages__clientserver__friends__pb2.DESCRIPTOR,])




_CCOMMUNITY_GETAPPS_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetApps_Request',
  full_name='CCommunity_GetApps_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appids', full_name='CCommunity_GetApps_Request.appids', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='CCommunity_GetApps_Request.language', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=201,
)


_CCOMMUNITY_GETAPPS_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetApps_Response',
  full_name='CCommunity_GetApps_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps', full_name='CCommunity_GetApps_Response.apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=269,
)


_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetAppRichPresenceLocalization_Request',
  full_name='CCommunity_GetAppRichPresenceLocalization_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_GetAppRichPresenceLocalization_Request.appid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='CCommunity_GetAppRichPresenceLocalization_Request.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=355,
)


_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetAppRichPresenceLocalization_Response',
  full_name='CCommunity_GetAppRichPresenceLocalization_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_GetAppRichPresenceLocalization_Response.appid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_lists', full_name='CCommunity_GetAppRichPresenceLocalization_Response.token_lists', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=509,
)


_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN = _descriptor.Descriptor(
  name='CCommunity_GetAppRichPresenceLocalization_Response_Token',
  full_name='CCommunity_GetAppRichPresenceLocalization_Response_Token',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CCommunity_GetAppRichPresenceLocalization_Response_Token.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='CCommunity_GetAppRichPresenceLocalization_Response_Token.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=598,
)


_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST = _descriptor.Descriptor(
  name='CCommunity_GetAppRichPresenceLocalization_Response_TokenList',
  full_name='CCommunity_GetAppRichPresenceLocalization_Response_TokenList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CCommunity_GetAppRichPresenceLocalization_Response_TokenList.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tokens', full_name='CCommunity_GetAppRichPresenceLocalization_Response_TokenList.tokens', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=756,
)


_CCOMMUNITY_COMMENT = _descriptor.Descriptor(
  name='CCommunity_Comment',
  full_name='CCommunity_Comment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_Comment.gidcomment', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CCommunity_Comment.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CCommunity_Comment.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='CCommunity_Comment.text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upvotes', full_name='CCommunity_Comment.upvotes', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='CCommunity_Comment.hidden', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_by_user', full_name='CCommunity_Comment.hidden_by_user', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='CCommunity_Comment.deleted', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipaddress', full_name='CCommunity_Comment.ipaddress', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_hidden', full_name='CCommunity_Comment.total_hidden', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upvoted_by_user', full_name='CCommunity_Comment.upvoted_by_user', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=1005,
)


_CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetCommentThread_Response',
  full_name='CCommunity_GetCommentThread_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='comments', full_name='CCommunity_GetCommentThread_Response.comments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deleted_comments', full_name='CCommunity_GetCommentThread_Response.deleted_comments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CCommunity_GetCommentThread_Response.steamid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commentthreadid', full_name='CCommunity_GetCommentThread_Response.commentthreadid', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='CCommunity_GetCommentThread_Response.start', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_GetCommentThread_Response.count', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_count', full_name='CCommunity_GetCommentThread_Response.total_count', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upvotes', full_name='CCommunity_GetCommentThread_Response.upvotes', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upvoters', full_name='CCommunity_GetCommentThread_Response.upvoters', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_subscribed', full_name='CCommunity_GetCommentThread_Response.user_subscribed', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_upvoted', full_name='CCommunity_GetCommentThread_Response.user_upvoted', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answer_commentid', full_name='CCommunity_GetCommentThread_Response.answer_commentid', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answer_actor', full_name='CCommunity_GetCommentThread_Response.answer_actor', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='answer_actor_rank', full_name='CCommunity_GetCommentThread_Response.answer_actor_rank', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_post', full_name='CCommunity_GetCommentThread_Response.can_post', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1400,
)


_CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_PostCommentToThread_Response',
  full_name='CCommunity_PostCommentToThread_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_PostCommentToThread_Response.gidcomment', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commentthreadid', full_name='CCommunity_PostCommentToThread_Response.commentthreadid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_PostCommentToThread_Response.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upvotes', full_name='CCommunity_PostCommentToThread_Response.upvotes', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1520,
)


_CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_DeleteCommentFromThread_Response',
  full_name='CCommunity_DeleteCommentFromThread_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1522,
  serialized_end=1567,
)


_CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_RateCommentThread_Response',
  full_name='CCommunity_RateCommentThread_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_RateCommentThread_Response.gidcomment', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commentthreadid', full_name='CCommunity_RateCommentThread_Response.commentthreadid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCommunity_RateCommentThread_Response.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upvotes', full_name='CCommunity_RateCommentThread_Response.upvotes', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_upvoted', full_name='CCommunity_RateCommentThread_Response.has_upvoted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1570,
  serialized_end=1707,
)


_CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetCommentThreadRatings_Response',
  full_name='CCommunity_GetCommentThreadRatings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commentthreadid', full_name='CCommunity_GetCommentThreadRatings_Response.commentthreadid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gidcomment', full_name='CCommunity_GetCommentThreadRatings_Response.gidcomment', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upvotes', full_name='CCommunity_GetCommentThreadRatings_Response.upvotes', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_upvoted', full_name='CCommunity_GetCommentThreadRatings_Response.has_upvoted', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upvoter_accountids', full_name='CCommunity_GetCommentThreadRatings_Response.upvoter_accountids', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1710,
  serialized_end=1866,
)


_CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST = _descriptor.Descriptor(
  name='CCommunity_RateClanAnnouncement_Request',
  full_name='CCommunity_RateClanAnnouncement_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcementid', full_name='CCommunity_RateClanAnnouncement_Request.announcementid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vote_up', full_name='CCommunity_RateClanAnnouncement_Request.vote_up', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clan_accountid', full_name='CCommunity_RateClanAnnouncement_Request.clan_accountid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1868,
  serialized_end=1974,
)


_CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_RateClanAnnouncement_Response',
  full_name='CCommunity_RateClanAnnouncement_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1976,
  serialized_end=2018,
)


_CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetClanAnnouncementVoteForUser_Request',
  full_name='CCommunity_GetClanAnnouncementVoteForUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcementid', full_name='CCommunity_GetClanAnnouncementVoteForUser_Request.announcementid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2020,
  serialized_end=2095,
)


_CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetClanAnnouncementVoteForUser_Response',
  full_name='CCommunity_GetClanAnnouncementVoteForUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voted_up', full_name='CCommunity_GetClanAnnouncementVoteForUser_Response.voted_up', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voted_down', full_name='CCommunity_GetClanAnnouncementVoteForUser_Response.voted_down', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2097,
  serialized_end=2187,
)


_CCOMMUNITY_GETAVATARHISTORY_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetAvatarHistory_Response',
  full_name='CCommunity_GetAvatarHistory_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatars', full_name='CCommunity_GetAvatarHistory_Response.avatars', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2189,
  serialized_end=2294,
)


_CCOMMUNITY_GETAVATARHISTORY_RESPONSE_AVATARDATA = _descriptor.Descriptor(
  name='CCommunity_GetAvatarHistory_Response_AvatarData',
  full_name='CCommunity_GetAvatarHistory_Response_AvatarData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatar_sha1', full_name='CCommunity_GetAvatarHistory_Response_AvatarData.avatar_sha1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_uploaded', full_name='CCommunity_GetAvatarHistory_Response_AvatarData.user_uploaded', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CCommunity_GetAvatarHistory_Response_AvatarData.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2296,
  serialized_end=2408,
)


_CAPPPRIORITY = _descriptor.Descriptor(
  name='CAppPriority',
  full_name='CAppPriority',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='CAppPriority.priority', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CAppPriority.appid', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2410,
  serialized_end=2457,
)


_CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetUserPartnerEventNews_Response',
  full_name='CCommunity_GetUserPartnerEventNews_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CCommunity_GetUserPartnerEventNews_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2459,
  serialized_end=2546,
)


_CCOMMUNITY_PARTNEREVENTRESULT = _descriptor.Descriptor(
  name='CCommunity_PartnerEventResult',
  full_name='CCommunity_PartnerEventResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clanid', full_name='CCommunity_PartnerEventResult.clanid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_gid', full_name='CCommunity_PartnerEventResult.event_gid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='announcement_gid', full_name='CCommunity_PartnerEventResult.announcement_gid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_PartnerEventResult.appid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='possible_takeover', full_name='CCommunity_PartnerEventResult.possible_takeover', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rtime32_last_modified', full_name='CCommunity_PartnerEventResult.rtime32_last_modified', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_app_priority', full_name='CCommunity_PartnerEventResult.user_app_priority', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2549,
  serialized_end=2744,
)


_CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetBestEventsForUser_Response',
  full_name='CCommunity_GetBestEventsForUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CCommunity_GetBestEventsForUser_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2746,
  serialized_end=2837,
)


_CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_ClearUserPartnerEventsAppPriorities_Response',
  full_name='CCommunity_ClearUserPartnerEventsAppPriorities_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2839,
  serialized_end=2896,
)


_CCOMMUNITY_PARTNEREVENTSAPPPRIORITY = _descriptor.Descriptor(
  name='CCommunity_PartnerEventsAppPriority',
  full_name='CCommunity_PartnerEventsAppPriority',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCommunity_PartnerEventsAppPriority.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_app_priority', full_name='CCommunity_PartnerEventsAppPriority.user_app_priority', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2898,
  serialized_end=2977,
)


_CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetUserPartnerEventsAppPriorities_Response',
  full_name='CCommunity_GetUserPartnerEventsAppPriorities_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='priorities', full_name='CCommunity_GetUserPartnerEventsAppPriorities_Response.priorities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2979,
  serialized_end=3092,
)


_CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_ClearSinglePartnerEventsAppPriority_Response',
  full_name='CCommunity_ClearSinglePartnerEventsAppPriority_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3094,
  serialized_end=3151,
)


_CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_PartnerEventsShowMoreForApp_Response',
  full_name='CCommunity_PartnerEventsShowMoreForApp_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3153,
  serialized_end=3202,
)


_CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_PartnerEventsShowLessForApp_Response',
  full_name='CCommunity_PartnerEventsShowLessForApp_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3204,
  serialized_end=3253,
)


_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST = _descriptor.Descriptor(
  name='CCommunity_MarkPartnerEventsForUser_Request',
  full_name='CCommunity_MarkPartnerEventsForUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='markings', full_name='CCommunity_MarkPartnerEventsForUser_Request.markings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3256,
  serialized_end=3385,
)


_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING = _descriptor.Descriptor(
  name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking',
  full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clanid', full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking.clanid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_gid', full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking.event_gid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_location', full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking.display_location', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\004enum'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mark_shown', full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking.mark_shown', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mark_read', full_name='CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking.mark_read', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3388,
  serialized_end=3563,
)


_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_MarkPartnerEventsForUser_Response',
  full_name='CCommunity_MarkPartnerEventsForUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3565,
  serialized_end=3611,
)


_CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetUserPartnerEventViewStatus_Response',
  full_name='CCommunity_GetUserPartnerEventViewStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='CCommunity_GetUserPartnerEventViewStatus_Response.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3614,
  serialized_end=3746,
)


_CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE_PARTNEREVENT = _descriptor.Descriptor(
  name='CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent',
  full_name='CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_gid', full_name='CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent.event_gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_shown_time', full_name='CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent.last_shown_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_read_time', full_name='CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent.last_read_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clan_account_id', full_name='CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent.clan_account_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3749,
  serialized_end=3906,
)


_CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_REQUEST = _descriptor.Descriptor(
  name='CWebRTCClient_InitiateWebRTCConnection_Request',
  full_name='CWebRTCClient_InitiateWebRTCConnection_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdp', full_name='CWebRTCClient_InitiateWebRTCConnection_Request.sdp', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3908,
  serialized_end=3969,
)


_CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_RESPONSE = _descriptor.Descriptor(
  name='CWebRTCClient_InitiateWebRTCConnection_Response',
  full_name='CWebRTCClient_InitiateWebRTCConnection_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='remote_description', full_name='CWebRTCClient_InitiateWebRTCConnection_Response.remote_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3971,
  serialized_end=4048,
)


_CWEBRTC_WEBRTCSESSIONCONNECTED_NOTIFICATION = _descriptor.Descriptor(
  name='CWebRTC_WebRTCSessionConnected_Notification',
  full_name='CWebRTC_WebRTCSessionConnected_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ssrc', full_name='CWebRTC_WebRTCSessionConnected_Notification.ssrc', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='CWebRTC_WebRTCSessionConnected_Notification.client_ip', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_port', full_name='CWebRTC_WebRTCSessionConnected_Notification.client_port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_ip', full_name='CWebRTC_WebRTCSessionConnected_Notification.server_ip', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_port', full_name='CWebRTC_WebRTCSessionConnected_Notification.server_port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4051,
  serialized_end=4190,
)


_CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION = _descriptor.Descriptor(
  name='CWebRTC_WebRTCUpdateRemoteDescription_Notification',
  full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='remote_description', full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification.remote_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_description_version', full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification.remote_description_version', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ssrcs_to_accountids', full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification.ssrcs_to_accountids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4193,
  serialized_end=4415,
)


_CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION_CSSRCTOACCOUNTIDMAPPING = _descriptor.Descriptor(
  name='CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping',
  full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ssrc', full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping.ssrc', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping.accountid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4417,
  serialized_end=4526,
)


_CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_REQUEST = _descriptor.Descriptor(
  name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request',
  full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_webrtc_server', full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request.ip_webrtc_server', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_webrtc_server', full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request.port_webrtc_server', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip_webrtc_session_client', full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request.ip_webrtc_session_client', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_webrtc_session_client', full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request.port_webrtc_session_client', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_description_version', full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request.remote_description_version', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4529,
  serialized_end=4748,
)


_CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_RESPONSE = _descriptor.Descriptor(
  name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response',
  full_name='CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4750,
  serialized_end=4810,
)


_CVOICECHAT_REQUESTONEONONECHAT_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_RequestOneOnOneChat_Request',
  full_name='CVoiceChat_RequestOneOnOneChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_RequestOneOnOneChat_Request.steamid_partner', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4812,
  serialized_end=4877,
)


_CVOICECHAT_REQUESTONEONONECHAT_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_RequestOneOnOneChat_Response',
  full_name='CVoiceChat_RequestOneOnOneChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_RequestOneOnOneChat_Response.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4879,
  serialized_end=4942,
)


_CVOICECHAT_ONEONONECHATREQUESTED_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_OneOnOneChatRequested_Notification',
  full_name='CVoiceChat_OneOnOneChatRequested_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_OneOnOneChatRequested_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_OneOnOneChatRequested_Notification.steamid_partner', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4944,
  serialized_end=5038,
)


_CVOICECHAT_ANSWERONEONONECHAT_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_AnswerOneOnOneChat_Request',
  full_name='CVoiceChat_AnswerOneOnOneChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_AnswerOneOnOneChat_Request.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_AnswerOneOnOneChat_Request.steamid_partner', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accepted_request', full_name='CVoiceChat_AnswerOneOnOneChat_Request.accepted_request', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5040,
  serialized_end=5152,
)


_CVOICECHAT_ANSWERONEONONECHAT_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_AnswerOneOnOneChat_Response',
  full_name='CVoiceChat_AnswerOneOnOneChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5154,
  serialized_end=5194,
)


_CVOICECHAT_ONEONONECHATREQUESTRESPONSE_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_OneOnOneChatRequestResponse_Notification',
  full_name='CVoiceChat_OneOnOneChatRequestResponse_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voicechat_id', full_name='CVoiceChat_OneOnOneChatRequestResponse_Notification.voicechat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_OneOnOneChatRequestResponse_Notification.steamid_partner', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accepted_request', full_name='CVoiceChat_OneOnOneChatRequestResponse_Notification.accepted_request', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5196,
  serialized_end=5322,
)


_CVOICECHAT_ENDONEONONECHAT_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_EndOneOnOneChat_Request',
  full_name='CVoiceChat_EndOneOnOneChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_EndOneOnOneChat_Request.steamid_partner', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5324,
  serialized_end=5385,
)


_CVOICECHAT_ENDONEONONECHAT_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_EndOneOnOneChat_Response',
  full_name='CVoiceChat_EndOneOnOneChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5387,
  serialized_end=5424,
)


_CVOICECHAT_LEAVEONEONONECHAT_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_LeaveOneOnOneChat_Request',
  full_name='CVoiceChat_LeaveOneOnOneChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CVoiceChat_LeaveOneOnOneChat_Request.steamid_partner', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_LeaveOneOnOneChat_Request.voice_chatid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5426,
  serialized_end=5511,
)


_CVOICECHAT_LEAVEONEONONECHAT_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_LeaveOneOnOneChat_Response',
  full_name='CVoiceChat_LeaveOneOnOneChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5513,
  serialized_end=5552,
)


_CVOICECHAT_USERJOINEDVOICECHAT_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_UserJoinedVoiceChat_Notification',
  full_name='CVoiceChat_UserJoinedVoiceChat_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatid', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.chatid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_lower', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.one_on_one_steamid_lower', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_higher', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.one_on_one_steamid_higher', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.chat_group_id', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_sessionid', full_name='CVoiceChat_UserJoinedVoiceChat_Notification.user_sessionid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5555,
  serialized_end=5776,
)


_CVOICECHAT_USERVOICESTATUS_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_UserVoiceStatus_Notification',
  full_name='CVoiceChat_UserVoiceStatus_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_UserVoiceStatus_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CVoiceChat_UserVoiceStatus_Notification.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_muted_mic_locally', full_name='CVoiceChat_UserVoiceStatus_Notification.user_muted_mic_locally', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_muted_output_locally', full_name='CVoiceChat_UserVoiceStatus_Notification.user_muted_output_locally', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_has_no_mic_for_session', full_name='CVoiceChat_UserVoiceStatus_Notification.user_has_no_mic_for_session', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_webaudio_sample_rate', full_name='CVoiceChat_UserVoiceStatus_Notification.user_webaudio_sample_rate', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5779,
  serialized_end=6003,
)


_CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_AllMembersStatus_Notification',
  full_name='CVoiceChat_AllMembersStatus_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_AllMembersStatus_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='CVoiceChat_AllMembersStatus_Notification.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6005,
  serialized_end=6126,
)


_CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_UpdateVoiceChatWebRTCData_Request',
  full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip_webrtc_server', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.ip_webrtc_server', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_webrtc_server', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.port_webrtc_server', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip_webrtc_client', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.ip_webrtc_client', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_webrtc_client', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.port_webrtc_client', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ssrc_my_sending_stream', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.ssrc_my_sending_stream', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_agent', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.user_agent', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_audio_worklets_support', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Request.has_audio_worklets_support', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6129,
  serialized_end=6393,
)


_CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_UpdateVoiceChatWebRTCData_Response',
  full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='send_client_voice_logs', full_name='CVoiceChat_UpdateVoiceChatWebRTCData_Response.send_client_voice_logs', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6395,
  serialized_end=6474,
)


_CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_REQUEST = _descriptor.Descriptor(
  name='CVoiceChat_UploadClientVoiceChatLogs_Request',
  full_name='CVoiceChat_UploadClientVoiceChatLogs_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_UploadClientVoiceChatLogs_Request.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_voice_logs_new_lines', full_name='CVoiceChat_UploadClientVoiceChatLogs_Request.client_voice_logs_new_lines', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6476,
  serialized_end=6581,
)


_CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_UploadClientVoiceChatLogs_Response',
  full_name='CVoiceChat_UploadClientVoiceChatLogs_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6583,
  serialized_end=6630,
)


_CVOICECHAT_LEAVEVOICECHAT_RESPONSE = _descriptor.Descriptor(
  name='CVoiceChat_LeaveVoiceChat_Response',
  full_name='CVoiceChat_LeaveVoiceChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6632,
  serialized_end=6668,
)


_CVOICECHAT_USERLEFTVOICECHAT_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_UserLeftVoiceChat_Notification',
  full_name='CVoiceChat_UserLeftVoiceChat_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_UserLeftVoiceChat_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CVoiceChat_UserLeftVoiceChat_Notification.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatid', full_name='CVoiceChat_UserLeftVoiceChat_Notification.chatid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_lower', full_name='CVoiceChat_UserLeftVoiceChat_Notification.one_on_one_steamid_lower', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_higher', full_name='CVoiceChat_UserLeftVoiceChat_Notification.one_on_one_steamid_higher', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CVoiceChat_UserLeftVoiceChat_Notification.chat_group_id', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_sessionid', full_name='CVoiceChat_UserLeftVoiceChat_Notification.user_sessionid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6671,
  serialized_end=6890,
)


_CVOICECHAT_VOICECHATENDED_NOTIFICATION = _descriptor.Descriptor(
  name='CVoiceChat_VoiceChatEnded_Notification',
  full_name='CVoiceChat_VoiceChatEnded_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voice_chatid', full_name='CVoiceChat_VoiceChatEnded_Notification.voice_chatid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_lower', full_name='CVoiceChat_VoiceChatEnded_Notification.one_on_one_steamid_lower', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one_on_one_steamid_higher', full_name='CVoiceChat_VoiceChatEnded_Notification.one_on_one_steamid_higher', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatid', full_name='CVoiceChat_VoiceChatEnded_Notification.chatid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CVoiceChat_VoiceChatEnded_Notification.chat_group_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6893,
  serialized_end=7063,
)


_CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_CreateBroadcastChannel_Response',
  full_name='CSteamTV_CreateBroadcastChannel_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_CreateBroadcastChannel_Response.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7065,
  serialized_end=7137,
)


_CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelID_Response',
  full_name='CSteamTV_GetBroadcastChannelID_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetBroadcastChannelID_Response.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unique_name', full_name='CSteamTV_GetBroadcastChannelID_Response.unique_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CSteamTV_GetBroadcastChannelID_Response.steamid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7139,
  serialized_end=7248,
)


_CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_SetBroadcastChannelProfile_Response',
  full_name='CSteamTV_SetBroadcastChannelProfile_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7250,
  serialized_end=7296,
)


_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelProfile_Response',
  full_name='CSteamTV_GetBroadcastChannelProfile_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unique_name', full_name='CSteamTV_GetBroadcastChannelProfile_Response.unique_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_steamid', full_name='CSteamTV_GetBroadcastChannelProfile_Response.owner_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_GetBroadcastChannelProfile_Response.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='CSteamTV_GetBroadcastChannelProfile_Response.language', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline', full_name='CSteamTV_GetBroadcastChannelProfile_Response.headline', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='CSteamTV_GetBroadcastChannelProfile_Response.summary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='CSteamTV_GetBroadcastChannelProfile_Response.schedule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rules', full_name='CSteamTV_GetBroadcastChannelProfile_Response.rules', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='panels', full_name='CSteamTV_GetBroadcastChannelProfile_Response.panels', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_partnered', full_name='CSteamTV_GetBroadcastChannelProfile_Response.is_partnered', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7299,
  serialized_end=7527,
)


_CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_SetBroadcastChannelImage_Response',
  full_name='CSteamTV_SetBroadcastChannelImage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='replace_image_hash', full_name='CSteamTV_SetBroadcastChannelImage_Response.replace_image_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7529,
  serialized_end=7601,
)


_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelImages_Response',
  full_name='CSteamTV_GetBroadcastChannelImages_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='images', full_name='CSteamTV_GetBroadcastChannelImages_Response.images', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7603,
  serialized_end=7717,
)


_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelImages_Response_Images',
  full_name='CSteamTV_GetBroadcastChannelImages_Response_Images',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_type', full_name='CSteamTV_GetBroadcastChannelImages_Response_Images.image_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\004enum'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_path', full_name='CSteamTV_GetBroadcastChannelImages_Response_Images.image_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_index', full_name='CSteamTV_GetBroadcastChannelImages_Response_Images.image_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7719,
  serialized_end=7842,
)


_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelLinks_Response',
  full_name='CSteamTV_GetBroadcastChannelLinks_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='links', full_name='CSteamTV_GetBroadcastChannelLinks_Response.links', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7844,
  serialized_end=7954,
)


_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelLinks_Response_Links',
  full_name='CSteamTV_GetBroadcastChannelLinks_Response_Links',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link_index', full_name='CSteamTV_GetBroadcastChannelLinks_Response_Links.link_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='CSteamTV_GetBroadcastChannelLinks_Response_Links.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link_description', full_name='CSteamTV_GetBroadcastChannelLinks_Response_Links.link_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left', full_name='CSteamTV_GetBroadcastChannelLinks_Response_Links.left', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top', full_name='CSteamTV_GetBroadcastChannelLinks_Response_Links.top', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width', full_name='CSteamTV_GetBroadcastChannelLinks_Response_Links.width', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='CSteamTV_GetBroadcastChannelLinks_Response_Links.height', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7957,
  serialized_end=8124,
)


_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS = _descriptor.Descriptor(
  name='CSteamTV_SetBroadcastChannelLinkRegions_Request_Links',
  full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request_Links',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link_index', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request_Links.link_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request_Links.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link_description', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request_Links.link_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request_Links.left', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request_Links.top', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request_Links.width', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='CSteamTV_SetBroadcastChannelLinkRegions_Request_Links.height', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8127,
  serialized_end=8299,
)


_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_SetBroadcastChannelLinkRegions_Response',
  full_name='CSteamTV_SetBroadcastChannelLinkRegions_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8301,
  serialized_end=8351,
)


_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelStatus_Response',
  full_name='CSteamTV_GetBroadcastChannelStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_live', full_name='CSteamTV_GetBroadcastChannelStatus_Response.is_live', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_disabled', full_name='CSteamTV_GetBroadcastChannelStatus_Response.is_disabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSteamTV_GetBroadcastChannelStatus_Response.appid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='viewers', full_name='CSteamTV_GetBroadcastChannelStatus_Response.viewers', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='views', full_name='CSteamTV_GetBroadcastChannelStatus_Response.views', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='CSteamTV_GetBroadcastChannelStatus_Response.broadcaster_steamid', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnail_url', full_name='CSteamTV_GetBroadcastChannelStatus_Response.thumbnail_url', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='followers', full_name='CSteamTV_GetBroadcastChannelStatus_Response.followers', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribers', full_name='CSteamTV_GetBroadcastChannelStatus_Response.subscribers', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unique_name', full_name='CSteamTV_GetBroadcastChannelStatus_Response.unique_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broadcast_session_id', full_name='CSteamTV_GetBroadcastChannelStatus_Response.broadcast_session_id', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8354,
  serialized_end=8627,
)


_GETBROADCASTCHANNELENTRY = _descriptor.Descriptor(
  name='GetBroadcastChannelEntry',
  full_name='GetBroadcastChannelEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='GetBroadcastChannelEntry.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unique_name', full_name='GetBroadcastChannelEntry.unique_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='GetBroadcastChannelEntry.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appid', full_name='GetBroadcastChannelEntry.appid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='viewers', full_name='GetBroadcastChannelEntry.viewers', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='views', full_name='GetBroadcastChannelEntry.views', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnail_url', full_name='GetBroadcastChannelEntry.thumbnail_url', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='followers', full_name='GetBroadcastChannelEntry.followers', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline', full_name='GetBroadcastChannelEntry.headline', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avatar_url', full_name='GetBroadcastChannelEntry.avatar_url', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='GetBroadcastChannelEntry.broadcaster_steamid', index=10,
      number=11, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribers', full_name='GetBroadcastChannelEntry.subscribers', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='background_url', full_name='GetBroadcastChannelEntry.background_url', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_featured', full_name='GetBroadcastChannelEntry.is_featured', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_disabled', full_name='GetBroadcastChannelEntry.is_disabled', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_live', full_name='GetBroadcastChannelEntry.is_live', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='GetBroadcastChannelEntry.language', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reports', full_name='GetBroadcastChannelEntry.reports', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_partnered', full_name='GetBroadcastChannelEntry.is_partnered', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8630,
  serialized_end=9038,
)


_CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetFollowedChannels_Response',
  full_name='CSteamTV_GetFollowedChannels_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetFollowedChannels_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9040,
  serialized_end=9123,
)


_CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetSubscribedChannels_Response',
  full_name='CSteamTV_GetSubscribedChannels_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetSubscribedChannels_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9125,
  serialized_end=9210,
)


_CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_FollowBroadcastChannel_Response',
  full_name='CSteamTV_FollowBroadcastChannel_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_followed', full_name='CSteamTV_FollowBroadcastChannel_Response.is_followed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9212,
  serialized_end=9275,
)


_CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_SubscribeBroadcastChannel_Response',
  full_name='CSteamTV_SubscribeBroadcastChannel_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_subscribed', full_name='CSteamTV_SubscribeBroadcastChannel_Response.is_subscribed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9277,
  serialized_end=9345,
)


_CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_ReportBroadcastChannel_Response',
  full_name='CSteamTV_ReportBroadcastChannel_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9347,
  serialized_end=9389,
)


_CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelInteraction_Response',
  full_name='CSteamTV_GetBroadcastChannelInteraction_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_followed', full_name='CSteamTV_GetBroadcastChannelInteraction_Response.is_followed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_subscribed', full_name='CSteamTV_GetBroadcastChannelInteraction_Response.is_subscribed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9391,
  serialized_end=9485,
)


_CSTEAMTV_GAME = _descriptor.Descriptor(
  name='CSteamTV_Game',
  full_name='CSteamTV_Game',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSteamTV_Game.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_Game.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='CSteamTV_Game.image', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='viewers', full_name='CSteamTV_Game.viewers', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channels', full_name='CSteamTV_Game.channels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='release_date', full_name='CSteamTV_Game.release_date', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='CSteamTV_Game.developer', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='publisher', full_name='CSteamTV_Game.publisher', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9488,
  serialized_end=9669,
)


_CSTEAMTV_GETGAMES_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetGames_Response',
  full_name='CSteamTV_GetGames_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetGames_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9671,
  serialized_end=9732,
)


_CSTEAMTV_GETCHANNELS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetChannels_Response',
  full_name='CSteamTV_GetChannels_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetChannels_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9734,
  serialized_end=9809,
)


_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelBroadcasters_Response',
  full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcasters', full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response.broadcasters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9812,
  serialized_end=9949,
)


_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster',
  full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rtmp_token', full_name='CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster.rtmp_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9951,
  serialized_end=10065,
)


_CSTEAMTV_CHATBAN = _descriptor.Descriptor(
  name='CSteamTV_ChatBan',
  full_name='CSteamTV_ChatBan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer_steamid', full_name='CSteamTV_ChatBan.issuer_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatter_steamid', full_name='CSteamTV_ChatBan.chatter_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_expires', full_name='CSteamTV_ChatBan.time_expires', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='permanent', full_name='CSteamTV_ChatBan.permanent', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_ChatBan.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10067,
  serialized_end=10189,
)


_CSTEAMTV_ADDCHATBAN_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_AddChatBan_Request',
  full_name='CSteamTV_AddChatBan_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_AddChatBan_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatter_steamid', full_name='CSteamTV_AddChatBan_Request.chatter_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CSteamTV_AddChatBan_Request.duration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='permanent', full_name='CSteamTV_AddChatBan_Request.permanent', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo', full_name='CSteamTV_AddChatBan_Request.undo', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10192,
  serialized_end=10327,
)


_CSTEAMTV_ADDCHATBAN_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_AddChatBan_Response',
  full_name='CSteamTV_AddChatBan_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10329,
  serialized_end=10359,
)


_CSTEAMTV_GETCHATBANS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetChatBans_Response',
  full_name='CSteamTV_GetChatBans_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetChatBans_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10361,
  serialized_end=10428,
)


_CSTEAMTV_ADDCHATMODERATOR_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_AddChatModerator_Request',
  full_name='CSteamTV_AddChatModerator_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_AddChatModerator_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='moderator_steamid', full_name='CSteamTV_AddChatModerator_Request.moderator_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo', full_name='CSteamTV_AddChatModerator_Request.undo', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10430,
  serialized_end=10536,
)


_CSTEAMTV_ADDCHATMODERATOR_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_AddChatModerator_Response',
  full_name='CSteamTV_AddChatModerator_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10538,
  serialized_end=10574,
)


_CSTEAMTV_GETCHATMODERATORS_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_GetChatModerators_Request',
  full_name='CSteamTV_GetChatModerators_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_GetChatModerators_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10576,
  serialized_end=10642,
)


_CSTEAMTV_CHATMODERATOR = _descriptor.Descriptor(
  name='CSteamTV_ChatModerator',
  full_name='CSteamTV_ChatModerator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CSteamTV_ChatModerator.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSteamTV_ChatModerator.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10644,
  serialized_end=10699,
)


_CSTEAMTV_GETCHATMODERATORS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetChatModerators_Response',
  full_name='CSteamTV_GetChatModerators_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetChatModerators_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10701,
  serialized_end=10780,
)


_CSTEAMTV_ADDWORDBAN_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_AddWordBan_Response',
  full_name='CSteamTV_AddWordBan_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10782,
  serialized_end=10812,
)


_CSTEAMTV_GETWORDBANS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetWordBans_Response',
  full_name='CSteamTV_GetWordBans_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetWordBans_Response.results', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10814,
  serialized_end=10862,
)


_CSTEAMTV_JOINCHAT_REQUEST = _descriptor.Descriptor(
  name='CSteamTV_JoinChat_Request',
  full_name='CSteamTV_JoinChat_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_channel_id', full_name='CSteamTV_JoinChat_Request.broadcast_channel_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10864,
  serialized_end=10921,
)


_CSTEAMTV_JOINCHAT_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_JoinChat_Response',
  full_name='CSteamTV_JoinChat_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CSteamTV_JoinChat_Response.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_url_template', full_name='CSteamTV_JoinChat_Response.view_url_template', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flair_group_ids', full_name='CSteamTV_JoinChat_Response.flair_group_ids', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10923,
  serialized_end=11020,
)


_CSTEAMTV_SEARCH_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_Search_Response',
  full_name='CSteamTV_Search_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_Search_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11022,
  serialized_end=11092,
)


_CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetSteamTVUserSettings_Response',
  full_name='CSteamTV_GetSteamTVUserSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_live_email', full_name='CSteamTV_GetSteamTVUserSettings_Response.stream_live_email', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_live_notification', full_name='CSteamTV_GetSteamTVUserSettings_Response.stream_live_notification', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11094,
  serialized_end=11197,
)


_CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_SetSteamTVUserSettings_Response',
  full_name='CSteamTV_SetSteamTVUserSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11199,
  serialized_end=11241,
)


_CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetMyBroadcastChannels_Response',
  full_name='CSteamTV_GetMyBroadcastChannels_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='CSteamTV_GetMyBroadcastChannels_Response.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11243,
  serialized_end=11329,
)


_CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_Takeover',
  full_name='CSteamTV_HomePageTemplate_Takeover',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcasts', full_name='CSteamTV_HomePageTemplate_Takeover.broadcasts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11331,
  serialized_end=11414,
)


_CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_SingleGame',
  full_name='CSteamTV_HomePageTemplate_SingleGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcasts', full_name='CSteamTV_HomePageTemplate_SingleGame.broadcasts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CSteamTV_HomePageTemplate_SingleGame.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_SingleGame.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11416,
  serialized_end=11531,
)


_GAMELISTENTRY = _descriptor.Descriptor(
  name='GameListEntry',
  full_name='GameListEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='GameListEntry.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_name', full_name='GameListEntry.game_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broadcast', full_name='GameListEntry.broadcast', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11533,
  serialized_end=11628,
)


_CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_GameList',
  full_name='CSteamTV_HomePageTemplate_GameList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='CSteamTV_HomePageTemplate_GameList.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_GameList.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11630,
  serialized_end=11714,
)


_CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_QuickExplore',
  full_name='CSteamTV_HomePageTemplate_QuickExplore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcasts', full_name='CSteamTV_HomePageTemplate_QuickExplore.broadcasts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_QuickExplore.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11716,
  serialized_end=11818,
)


_CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_ConveyorBelt',
  full_name='CSteamTV_HomePageTemplate_ConveyorBelt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcasts', full_name='CSteamTV_HomePageTemplate_ConveyorBelt.broadcasts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_ConveyorBelt.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11820,
  serialized_end=11922,
)


_CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_WatchParty',
  full_name='CSteamTV_HomePageTemplate_WatchParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast', full_name='CSteamTV_HomePageTemplate_WatchParty.broadcast', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_WatchParty.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CSteamTV_HomePageTemplate_WatchParty.chat_group_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11924,
  serialized_end=12046,
)


_CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_Developer',
  full_name='CSteamTV_HomePageTemplate_Developer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast', full_name='CSteamTV_HomePageTemplate_Developer.broadcast', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_Developer.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12048,
  serialized_end=12146,
)


_CSTEAMTV_HOMEPAGETEMPLATE_EVENT = _descriptor.Descriptor(
  name='CSteamTV_HomePageTemplate_Event',
  full_name='CSteamTV_HomePageTemplate_Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='CSteamTV_HomePageTemplate_Event.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12148,
  serialized_end=12196,
)


_CSTEAMTV_HOMEPAGECONTENTROW = _descriptor.Descriptor(
  name='CSteamTV_HomePageContentRow',
  full_name='CSteamTV_HomePageContentRow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template_type', full_name='CSteamTV_HomePageContentRow.template_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\004enum'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='takeover', full_name='CSteamTV_HomePageContentRow.takeover', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='single_game', full_name='CSteamTV_HomePageContentRow.single_game', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_list', full_name='CSteamTV_HomePageContentRow.game_list', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quick_explore', full_name='CSteamTV_HomePageContentRow.quick_explore', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conveyor_belt', full_name='CSteamTV_HomePageContentRow.conveyor_belt', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='watch_party', full_name='CSteamTV_HomePageContentRow.watch_party', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='developer', full_name='CSteamTV_HomePageContentRow.developer', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event', full_name='CSteamTV_HomePageContentRow.event', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12199,
  serialized_end=12726,
)


_CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetHomePageContents_Response',
  full_name='CSteamTV_GetHomePageContents_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rows', full_name='CSteamTV_GetHomePageContents_Response.rows', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12728,
  serialized_end=12811,
)


_CSTEAMTV_BROADCASTCLIPINFO = _descriptor.Descriptor(
  name='CSteamTV_BroadcastClipInfo',
  full_name='CSteamTV_BroadcastClipInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_clip_id', full_name='CSteamTV_BroadcastClipInfo.broadcast_clip_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='CSteamTV_BroadcastClipInfo.channel_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CSteamTV_BroadcastClipInfo.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='CSteamTV_BroadcastClipInfo.broadcaster_steamid', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator_steamid', full_name='CSteamTV_BroadcastClipInfo.creator_steamid', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_description', full_name='CSteamTV_BroadcastClipInfo.video_description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='live_time', full_name='CSteamTV_BroadcastClipInfo.live_time', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length_ms', full_name='CSteamTV_BroadcastClipInfo.length_ms', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnail_path', full_name='CSteamTV_BroadcastClipInfo.thumbnail_path', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12814,
  serialized_end=13048,
)


_CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE = _descriptor.Descriptor(
  name='CSteamTV_GetBroadcastChannelClips_Response',
  full_name='CSteamTV_GetBroadcastChannelClips_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clips', full_name='CSteamTV_GetBroadcastChannelClips_Response.clips', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnail_host', full_name='CSteamTV_GetBroadcastChannelClips_Response.thumbnail_host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13050,
  serialized_end=13162,
)


_CFRIENDSLISTCATEGORY = _descriptor.Descriptor(
  name='CFriendsListCategory',
  full_name='CFriendsListCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupid', full_name='CFriendsListCategory.groupid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CFriendsListCategory.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accountid_members', full_name='CFriendsListCategory.accountid_members', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13164,
  serialized_end=13244,
)


_CFRIENDSLIST_GETCATEGORIES_REQUEST = _descriptor.Descriptor(
  name='CFriendsList_GetCategories_Request',
  full_name='CFriendsList_GetCategories_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13246,
  serialized_end=13282,
)


_CFRIENDSLIST_GETCATEGORIES_RESPONSE = _descriptor.Descriptor(
  name='CFriendsList_GetCategories_Response',
  full_name='CFriendsList_GetCategories_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='categories', full_name='CFriendsList_GetCategories_Response.categories', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13284,
  serialized_end=13364,
)


_CFRIENDSLISTFAVORITEENTRY = _descriptor.Descriptor(
  name='CFriendsListFavoriteEntry',
  full_name='CFriendsListFavoriteEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CFriendsListFavoriteEntry.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clanid', full_name='CFriendsListFavoriteEntry.clanid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chat_group_id', full_name='CFriendsListFavoriteEntry.chat_group_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13366,
  serialized_end=13451,
)


_CFRIENDSLIST_GETFAVORITES_REQUEST = _descriptor.Descriptor(
  name='CFriendsList_GetFavorites_Request',
  full_name='CFriendsList_GetFavorites_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13453,
  serialized_end=13488,
)


_CFRIENDSLIST_GETFAVORITES_RESPONSE = _descriptor.Descriptor(
  name='CFriendsList_GetFavorites_Response',
  full_name='CFriendsList_GetFavorites_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='favorites', full_name='CFriendsList_GetFavorites_Response.favorites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13490,
  serialized_end=13573,
)


_CFRIENDSLIST_SETFAVORITES_REQUEST = _descriptor.Descriptor(
  name='CFriendsList_SetFavorites_Request',
  full_name='CFriendsList_SetFavorites_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='favorites', full_name='CFriendsList_SetFavorites_Request.favorites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13575,
  serialized_end=13657,
)


_CFRIENDSLIST_SETFAVORITES_RESPONSE = _descriptor.Descriptor(
  name='CFriendsList_SetFavorites_Response',
  full_name='CFriendsList_SetFavorites_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13659,
  serialized_end=13695,
)


_CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CFriendsList_FavoritesChanged_Notification',
  full_name='CFriendsList_FavoritesChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='favorites', full_name='CFriendsList_FavoritesChanged_Notification.favorites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13697,
  serialized_end=13788,
)


_CFRIENDSLIST_GETFRIENDSLIST_REQUEST = _descriptor.Descriptor(
  name='CFriendsList_GetFriendsList_Request',
  full_name='CFriendsList_GetFriendsList_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13790,
  serialized_end=13827,
)


_CFRIENDSLIST_GETFRIENDSLIST_RESPONSE = _descriptor.Descriptor(
  name='CFriendsList_GetFriendsList_Response',
  full_name='CFriendsList_GetFriendsList_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='friendslist', full_name='CFriendsList_GetFriendsList_Response.friendslist', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13829,
  serialized_end=13912,
)


_CCLAN_RESPONDTOCLANINVITE_REQUEST = _descriptor.Descriptor(
  name='CClan_RespondToClanInvite_Request',
  full_name='CClan_RespondToClanInvite_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CClan_RespondToClanInvite_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accept', full_name='CClan_RespondToClanInvite_Request.accept', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13914,
  serialized_end=13982,
)


_CCLAN_RESPONDTOCLANINVITE_RESPONSE = _descriptor.Descriptor(
  name='CClan_RespondToClanInvite_Response',
  full_name='CClan_RespondToClanInvite_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13984,
  serialized_end=14020,
)


_CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION = _descriptor.Descriptor(
  name='CProductImpressionsFromClient_Notification',
  full_name='CProductImpressionsFromClient_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='impressions', full_name='CProductImpressionsFromClient_Notification.impressions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14022,
  serialized_end=14143,
)


_CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION = _descriptor.Descriptor(
  name='CProductImpressionsFromClient_Notification_Impression',
  full_name='CProductImpressionsFromClient_Notification_Impression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CProductImpressionsFromClient_Notification_Impression.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\004enum'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CProductImpressionsFromClient_Notification_Impression.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_impressions', full_name='CProductImpressionsFromClient_Notification_Impression.num_impressions', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14145,
  serialized_end=14264,
)


_NOTIMPLEMENTED = _descriptor.Descriptor(
  name='NotImplemented',
  full_name='NotImplemented',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14266,
  serialized_end=14282,
)

_CCOMMUNITY_GETAPPS_RESPONSE.fields_by_name['apps'].message_type = steammessages__base__pb2._CCDDBAPPDETAILCOMMON
_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE.fields_by_name['token_lists'].message_type = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST
_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST.fields_by_name['tokens'].message_type = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN
_CCOMMUNITY_COMMENT.fields_by_name['ipaddress'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE.fields_by_name['comments'].message_type = _CCOMMUNITY_COMMENT
_CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE.fields_by_name['deleted_comments'].message_type = _CCOMMUNITY_COMMENT
_CCOMMUNITY_GETAVATARHISTORY_RESPONSE.fields_by_name['avatars'].message_type = _CCOMMUNITY_GETAVATARHISTORY_RESPONSE_AVATARDATA
_CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE.fields_by_name['results'].message_type = steammessages__base__pb2._CCLANMATCHEVENTBYRANGE
_CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE.fields_by_name['results'].message_type = _CCOMMUNITY_PARTNEREVENTRESULT
_CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE.fields_by_name['priorities'].message_type = _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY
_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST.fields_by_name['markings'].message_type = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING
_CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE.fields_by_name['events'].message_type = _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE_PARTNEREVENT
_CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION.fields_by_name['ssrcs_to_accountids'].message_type = _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION_CSSRCTOACCOUNTIDMAPPING
_CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION.fields_by_name['users'].message_type = _CVOICECHAT_USERVOICESTATUS_NOTIFICATION
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE.fields_by_name['images'].message_type = _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES
_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE.fields_by_name['links'].message_type = _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS
_CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE.fields_by_name['results'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE.fields_by_name['results'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_GAME.fields_by_name['channels'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_GETGAMES_RESPONSE.fields_by_name['results'].message_type = _CSTEAMTV_GAME
_CSTEAMTV_GETCHANNELS_RESPONSE.fields_by_name['results'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE.fields_by_name['broadcasters'].message_type = _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER
_CSTEAMTV_GETCHATBANS_RESPONSE.fields_by_name['results'].message_type = _CSTEAMTV_CHATBAN
_CSTEAMTV_GETCHATMODERATORS_RESPONSE.fields_by_name['results'].message_type = _CSTEAMTV_CHATMODERATOR
_CSTEAMTV_SEARCH_RESPONSE.fields_by_name['results'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE.fields_by_name['results'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER.fields_by_name['broadcasts'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME.fields_by_name['broadcasts'].message_type = _GETBROADCASTCHANNELENTRY
_GAMELISTENTRY.fields_by_name['broadcast'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST.fields_by_name['entries'].message_type = _GAMELISTENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE.fields_by_name['broadcasts'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT.fields_by_name['broadcasts'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY.fields_by_name['broadcast'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER.fields_by_name['broadcast'].message_type = _GETBROADCASTCHANNELENTRY
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['takeover'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['single_game'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['game_list'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['quick_explore'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['conveyor_belt'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['watch_party'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['developer'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['event'].message_type = _CSTEAMTV_HOMEPAGETEMPLATE_EVENT
_CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE.fields_by_name['rows'].message_type = _CSTEAMTV_HOMEPAGECONTENTROW
_CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE.fields_by_name['clips'].message_type = _CSTEAMTV_BROADCASTCLIPINFO
_CFRIENDSLIST_GETCATEGORIES_RESPONSE.fields_by_name['categories'].message_type = _CFRIENDSLISTCATEGORY
_CFRIENDSLIST_GETFAVORITES_RESPONSE.fields_by_name['favorites'].message_type = _CFRIENDSLISTFAVORITEENTRY
_CFRIENDSLIST_SETFAVORITES_REQUEST.fields_by_name['favorites'].message_type = _CFRIENDSLISTFAVORITEENTRY
_CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION.fields_by_name['favorites'].message_type = _CFRIENDSLISTFAVORITEENTRY
_CFRIENDSLIST_GETFRIENDSLIST_RESPONSE.fields_by_name['friendslist'].message_type = steammessages__clientserver__friends__pb2._CMSGCLIENTFRIENDSLIST
_CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION.fields_by_name['impressions'].message_type = _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION
DESCRIPTOR.message_types_by_name['CCommunity_GetApps_Request'] = _CCOMMUNITY_GETAPPS_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetApps_Response'] = _CCOMMUNITY_GETAPPS_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetAppRichPresenceLocalization_Request'] = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetAppRichPresenceLocalization_Response'] = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetAppRichPresenceLocalization_Response_Token'] = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN
DESCRIPTOR.message_types_by_name['CCommunity_GetAppRichPresenceLocalization_Response_TokenList'] = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST
DESCRIPTOR.message_types_by_name['CCommunity_Comment'] = _CCOMMUNITY_COMMENT
DESCRIPTOR.message_types_by_name['CCommunity_GetCommentThread_Response'] = _CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_PostCommentToThread_Response'] = _CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_DeleteCommentFromThread_Response'] = _CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_RateCommentThread_Response'] = _CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetCommentThreadRatings_Response'] = _CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_RateClanAnnouncement_Request'] = _CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_RateClanAnnouncement_Response'] = _CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetClanAnnouncementVoteForUser_Request'] = _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetClanAnnouncementVoteForUser_Response'] = _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetAvatarHistory_Response'] = _CCOMMUNITY_GETAVATARHISTORY_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetAvatarHistory_Response_AvatarData'] = _CCOMMUNITY_GETAVATARHISTORY_RESPONSE_AVATARDATA
DESCRIPTOR.message_types_by_name['CAppPriority'] = _CAPPPRIORITY
DESCRIPTOR.message_types_by_name['CCommunity_GetUserPartnerEventNews_Response'] = _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_PartnerEventResult'] = _CCOMMUNITY_PARTNEREVENTRESULT
DESCRIPTOR.message_types_by_name['CCommunity_GetBestEventsForUser_Response'] = _CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_ClearUserPartnerEventsAppPriorities_Response'] = _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_PartnerEventsAppPriority'] = _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY
DESCRIPTOR.message_types_by_name['CCommunity_GetUserPartnerEventsAppPriorities_Response'] = _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_ClearSinglePartnerEventsAppPriority_Response'] = _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_PartnerEventsShowMoreForApp_Response'] = _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_PartnerEventsShowLessForApp_Response'] = _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_MarkPartnerEventsForUser_Request'] = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking'] = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING
DESCRIPTOR.message_types_by_name['CCommunity_MarkPartnerEventsForUser_Response'] = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetUserPartnerEventViewStatus_Response'] = _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent'] = _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE_PARTNEREVENT
DESCRIPTOR.message_types_by_name['CWebRTCClient_InitiateWebRTCConnection_Request'] = _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_REQUEST
DESCRIPTOR.message_types_by_name['CWebRTCClient_InitiateWebRTCConnection_Response'] = _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_RESPONSE
DESCRIPTOR.message_types_by_name['CWebRTC_WebRTCSessionConnected_Notification'] = _CWEBRTC_WEBRTCSESSIONCONNECTED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CWebRTC_WebRTCUpdateRemoteDescription_Notification'] = _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION
DESCRIPTOR.message_types_by_name['CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping'] = _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION_CSSRCTOACCOUNTIDMAPPING
DESCRIPTOR.message_types_by_name['CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request'] = _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_REQUEST
DESCRIPTOR.message_types_by_name['CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response'] = _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_RequestOneOnOneChat_Request'] = _CVOICECHAT_REQUESTONEONONECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_RequestOneOnOneChat_Response'] = _CVOICECHAT_REQUESTONEONONECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_OneOnOneChatRequested_Notification'] = _CVOICECHAT_ONEONONECHATREQUESTED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_AnswerOneOnOneChat_Request'] = _CVOICECHAT_ANSWERONEONONECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_AnswerOneOnOneChat_Response'] = _CVOICECHAT_ANSWERONEONONECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_OneOnOneChatRequestResponse_Notification'] = _CVOICECHAT_ONEONONECHATREQUESTRESPONSE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_EndOneOnOneChat_Request'] = _CVOICECHAT_ENDONEONONECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_EndOneOnOneChat_Response'] = _CVOICECHAT_ENDONEONONECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_LeaveOneOnOneChat_Request'] = _CVOICECHAT_LEAVEONEONONECHAT_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_LeaveOneOnOneChat_Response'] = _CVOICECHAT_LEAVEONEONONECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_UserJoinedVoiceChat_Notification'] = _CVOICECHAT_USERJOINEDVOICECHAT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_UserVoiceStatus_Notification'] = _CVOICECHAT_USERVOICESTATUS_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_AllMembersStatus_Notification'] = _CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_UpdateVoiceChatWebRTCData_Request'] = _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_UpdateVoiceChatWebRTCData_Response'] = _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_UploadClientVoiceChatLogs_Request'] = _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_REQUEST
DESCRIPTOR.message_types_by_name['CVoiceChat_UploadClientVoiceChatLogs_Response'] = _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_LeaveVoiceChat_Response'] = _CVOICECHAT_LEAVEVOICECHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CVoiceChat_UserLeftVoiceChat_Notification'] = _CVOICECHAT_USERLEFTVOICECHAT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVoiceChat_VoiceChatEnded_Notification'] = _CVOICECHAT_VOICECHATENDED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CSteamTV_CreateBroadcastChannel_Response'] = _CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelID_Response'] = _CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_SetBroadcastChannelProfile_Response'] = _CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelProfile_Response'] = _CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_SetBroadcastChannelImage_Response'] = _CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelImages_Response'] = _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelImages_Response_Images'] = _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelLinks_Response'] = _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelLinks_Response_Links'] = _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS
DESCRIPTOR.message_types_by_name['CSteamTV_SetBroadcastChannelLinkRegions_Request_Links'] = _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS
DESCRIPTOR.message_types_by_name['CSteamTV_SetBroadcastChannelLinkRegions_Response'] = _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelStatus_Response'] = _CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE
DESCRIPTOR.message_types_by_name['GetBroadcastChannelEntry'] = _GETBROADCASTCHANNELENTRY
DESCRIPTOR.message_types_by_name['CSteamTV_GetFollowedChannels_Response'] = _CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetSubscribedChannels_Response'] = _CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_FollowBroadcastChannel_Response'] = _CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_SubscribeBroadcastChannel_Response'] = _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_ReportBroadcastChannel_Response'] = _CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelInteraction_Response'] = _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_Game'] = _CSTEAMTV_GAME
DESCRIPTOR.message_types_by_name['CSteamTV_GetGames_Response'] = _CSTEAMTV_GETGAMES_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetChannels_Response'] = _CSTEAMTV_GETCHANNELS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelBroadcasters_Response'] = _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster'] = _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER
DESCRIPTOR.message_types_by_name['CSteamTV_ChatBan'] = _CSTEAMTV_CHATBAN
DESCRIPTOR.message_types_by_name['CSteamTV_AddChatBan_Request'] = _CSTEAMTV_ADDCHATBAN_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_AddChatBan_Response'] = _CSTEAMTV_ADDCHATBAN_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetChatBans_Response'] = _CSTEAMTV_GETCHATBANS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_AddChatModerator_Request'] = _CSTEAMTV_ADDCHATMODERATOR_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_AddChatModerator_Response'] = _CSTEAMTV_ADDCHATMODERATOR_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetChatModerators_Request'] = _CSTEAMTV_GETCHATMODERATORS_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_ChatModerator'] = _CSTEAMTV_CHATMODERATOR
DESCRIPTOR.message_types_by_name['CSteamTV_GetChatModerators_Response'] = _CSTEAMTV_GETCHATMODERATORS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_AddWordBan_Response'] = _CSTEAMTV_ADDWORDBAN_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetWordBans_Response'] = _CSTEAMTV_GETWORDBANS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_JoinChat_Request'] = _CSTEAMTV_JOINCHAT_REQUEST
DESCRIPTOR.message_types_by_name['CSteamTV_JoinChat_Response'] = _CSTEAMTV_JOINCHAT_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_Search_Response'] = _CSTEAMTV_SEARCH_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetSteamTVUserSettings_Response'] = _CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_SetSteamTVUserSettings_Response'] = _CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_GetMyBroadcastChannels_Response'] = _CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_Takeover'] = _CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_SingleGame'] = _CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME
DESCRIPTOR.message_types_by_name['GameListEntry'] = _GAMELISTENTRY
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_GameList'] = _CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_QuickExplore'] = _CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_ConveyorBelt'] = _CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_WatchParty'] = _CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_Developer'] = _CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageTemplate_Event'] = _CSTEAMTV_HOMEPAGETEMPLATE_EVENT
DESCRIPTOR.message_types_by_name['CSteamTV_HomePageContentRow'] = _CSTEAMTV_HOMEPAGECONTENTROW
DESCRIPTOR.message_types_by_name['CSteamTV_GetHomePageContents_Response'] = _CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE
DESCRIPTOR.message_types_by_name['CSteamTV_BroadcastClipInfo'] = _CSTEAMTV_BROADCASTCLIPINFO
DESCRIPTOR.message_types_by_name['CSteamTV_GetBroadcastChannelClips_Response'] = _CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendsListCategory'] = _CFRIENDSLISTCATEGORY
DESCRIPTOR.message_types_by_name['CFriendsList_GetCategories_Request'] = _CFRIENDSLIST_GETCATEGORIES_REQUEST
DESCRIPTOR.message_types_by_name['CFriendsList_GetCategories_Response'] = _CFRIENDSLIST_GETCATEGORIES_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendsListFavoriteEntry'] = _CFRIENDSLISTFAVORITEENTRY
DESCRIPTOR.message_types_by_name['CFriendsList_GetFavorites_Request'] = _CFRIENDSLIST_GETFAVORITES_REQUEST
DESCRIPTOR.message_types_by_name['CFriendsList_GetFavorites_Response'] = _CFRIENDSLIST_GETFAVORITES_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendsList_SetFavorites_Request'] = _CFRIENDSLIST_SETFAVORITES_REQUEST
DESCRIPTOR.message_types_by_name['CFriendsList_SetFavorites_Response'] = _CFRIENDSLIST_SETFAVORITES_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendsList_FavoritesChanged_Notification'] = _CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CFriendsList_GetFriendsList_Request'] = _CFRIENDSLIST_GETFRIENDSLIST_REQUEST
DESCRIPTOR.message_types_by_name['CFriendsList_GetFriendsList_Response'] = _CFRIENDSLIST_GETFRIENDSLIST_RESPONSE
DESCRIPTOR.message_types_by_name['CClan_RespondToClanInvite_Request'] = _CCLAN_RESPONDTOCLANINVITE_REQUEST
DESCRIPTOR.message_types_by_name['CClan_RespondToClanInvite_Response'] = _CCLAN_RESPONDTOCLANINVITE_RESPONSE
DESCRIPTOR.message_types_by_name['CProductImpressionsFromClient_Notification'] = _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CProductImpressionsFromClient_Notification_Impression'] = _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION
DESCRIPTOR.message_types_by_name['NotImplemented'] = _NOTIMPLEMENTED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CCommunity_GetApps_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetApps_Request', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETAPPS_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetApps_Request)
  ))
_sym_db.RegisterMessage(CCommunity_GetApps_Request)

CCommunity_GetApps_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetApps_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETAPPS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetApps_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetApps_Response)

CCommunity_GetAppRichPresenceLocalization_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetAppRichPresenceLocalization_Request', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetAppRichPresenceLocalization_Request)
  ))
_sym_db.RegisterMessage(CCommunity_GetAppRichPresenceLocalization_Request)

CCommunity_GetAppRichPresenceLocalization_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetAppRichPresenceLocalization_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetAppRichPresenceLocalization_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetAppRichPresenceLocalization_Response)

CCommunity_GetAppRichPresenceLocalization_Response_Token = _reflection.GeneratedProtocolMessageType('CCommunity_GetAppRichPresenceLocalization_Response_Token', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKEN,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetAppRichPresenceLocalization_Response_Token)
  ))
_sym_db.RegisterMessage(CCommunity_GetAppRichPresenceLocalization_Response_Token)

CCommunity_GetAppRichPresenceLocalization_Response_TokenList = _reflection.GeneratedProtocolMessageType('CCommunity_GetAppRichPresenceLocalization_Response_TokenList', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE_TOKENLIST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetAppRichPresenceLocalization_Response_TokenList)
  ))
_sym_db.RegisterMessage(CCommunity_GetAppRichPresenceLocalization_Response_TokenList)

CCommunity_Comment = _reflection.GeneratedProtocolMessageType('CCommunity_Comment', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_COMMENT,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_Comment)
  ))
_sym_db.RegisterMessage(CCommunity_Comment)

CCommunity_GetCommentThread_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetCommentThread_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetCommentThread_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetCommentThread_Response)

CCommunity_PostCommentToThread_Response = _reflection.GeneratedProtocolMessageType('CCommunity_PostCommentToThread_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PostCommentToThread_Response)
  ))
_sym_db.RegisterMessage(CCommunity_PostCommentToThread_Response)

CCommunity_DeleteCommentFromThread_Response = _reflection.GeneratedProtocolMessageType('CCommunity_DeleteCommentFromThread_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_DeleteCommentFromThread_Response)
  ))
_sym_db.RegisterMessage(CCommunity_DeleteCommentFromThread_Response)

CCommunity_RateCommentThread_Response = _reflection.GeneratedProtocolMessageType('CCommunity_RateCommentThread_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_RateCommentThread_Response)
  ))
_sym_db.RegisterMessage(CCommunity_RateCommentThread_Response)

CCommunity_GetCommentThreadRatings_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetCommentThreadRatings_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetCommentThreadRatings_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetCommentThreadRatings_Response)

CCommunity_RateClanAnnouncement_Request = _reflection.GeneratedProtocolMessageType('CCommunity_RateClanAnnouncement_Request', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_RateClanAnnouncement_Request)
  ))
_sym_db.RegisterMessage(CCommunity_RateClanAnnouncement_Request)

CCommunity_RateClanAnnouncement_Response = _reflection.GeneratedProtocolMessageType('CCommunity_RateClanAnnouncement_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_RateClanAnnouncement_Response)
  ))
_sym_db.RegisterMessage(CCommunity_RateClanAnnouncement_Response)

CCommunity_GetClanAnnouncementVoteForUser_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetClanAnnouncementVoteForUser_Request', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetClanAnnouncementVoteForUser_Request)
  ))
_sym_db.RegisterMessage(CCommunity_GetClanAnnouncementVoteForUser_Request)

CCommunity_GetClanAnnouncementVoteForUser_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetClanAnnouncementVoteForUser_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetClanAnnouncementVoteForUser_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetClanAnnouncementVoteForUser_Response)

CCommunity_GetAvatarHistory_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetAvatarHistory_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETAVATARHISTORY_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetAvatarHistory_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetAvatarHistory_Response)

CCommunity_GetAvatarHistory_Response_AvatarData = _reflection.GeneratedProtocolMessageType('CCommunity_GetAvatarHistory_Response_AvatarData', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETAVATARHISTORY_RESPONSE_AVATARDATA,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetAvatarHistory_Response_AvatarData)
  ))
_sym_db.RegisterMessage(CCommunity_GetAvatarHistory_Response_AvatarData)

CAppPriority = _reflection.GeneratedProtocolMessageType('CAppPriority', (_message.Message,), dict(
  DESCRIPTOR = _CAPPPRIORITY,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CAppPriority)
  ))
_sym_db.RegisterMessage(CAppPriority)

CCommunity_GetUserPartnerEventNews_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetUserPartnerEventNews_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetUserPartnerEventNews_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetUserPartnerEventNews_Response)

CCommunity_PartnerEventResult = _reflection.GeneratedProtocolMessageType('CCommunity_PartnerEventResult', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_PARTNEREVENTRESULT,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PartnerEventResult)
  ))
_sym_db.RegisterMessage(CCommunity_PartnerEventResult)

CCommunity_GetBestEventsForUser_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetBestEventsForUser_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetBestEventsForUser_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetBestEventsForUser_Response)

CCommunity_ClearUserPartnerEventsAppPriorities_Response = _reflection.GeneratedProtocolMessageType('CCommunity_ClearUserPartnerEventsAppPriorities_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_ClearUserPartnerEventsAppPriorities_Response)
  ))
_sym_db.RegisterMessage(CCommunity_ClearUserPartnerEventsAppPriorities_Response)

CCommunity_PartnerEventsAppPriority = _reflection.GeneratedProtocolMessageType('CCommunity_PartnerEventsAppPriority', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_PARTNEREVENTSAPPPRIORITY,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PartnerEventsAppPriority)
  ))
_sym_db.RegisterMessage(CCommunity_PartnerEventsAppPriority)

CCommunity_GetUserPartnerEventsAppPriorities_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetUserPartnerEventsAppPriorities_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetUserPartnerEventsAppPriorities_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetUserPartnerEventsAppPriorities_Response)

CCommunity_ClearSinglePartnerEventsAppPriority_Response = _reflection.GeneratedProtocolMessageType('CCommunity_ClearSinglePartnerEventsAppPriority_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_ClearSinglePartnerEventsAppPriority_Response)
  ))
_sym_db.RegisterMessage(CCommunity_ClearSinglePartnerEventsAppPriority_Response)

CCommunity_PartnerEventsShowMoreForApp_Response = _reflection.GeneratedProtocolMessageType('CCommunity_PartnerEventsShowMoreForApp_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PartnerEventsShowMoreForApp_Response)
  ))
_sym_db.RegisterMessage(CCommunity_PartnerEventsShowMoreForApp_Response)

CCommunity_PartnerEventsShowLessForApp_Response = _reflection.GeneratedProtocolMessageType('CCommunity_PartnerEventsShowLessForApp_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_PartnerEventsShowLessForApp_Response)
  ))
_sym_db.RegisterMessage(CCommunity_PartnerEventsShowLessForApp_Response)

CCommunity_MarkPartnerEventsForUser_Request = _reflection.GeneratedProtocolMessageType('CCommunity_MarkPartnerEventsForUser_Request', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_MarkPartnerEventsForUser_Request)
  ))
_sym_db.RegisterMessage(CCommunity_MarkPartnerEventsForUser_Request)

CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking = _reflection.GeneratedProtocolMessageType('CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking)
  ))
_sym_db.RegisterMessage(CCommunity_MarkPartnerEventsForUser_Request_PartnerEventMarking)

CCommunity_MarkPartnerEventsForUser_Response = _reflection.GeneratedProtocolMessageType('CCommunity_MarkPartnerEventsForUser_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_MarkPartnerEventsForUser_Response)
  ))
_sym_db.RegisterMessage(CCommunity_MarkPartnerEventsForUser_Response)

CCommunity_GetUserPartnerEventViewStatus_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetUserPartnerEventViewStatus_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetUserPartnerEventViewStatus_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetUserPartnerEventViewStatus_Response)

CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent = _reflection.GeneratedProtocolMessageType('CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE_PARTNEREVENT,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent)
  ))
_sym_db.RegisterMessage(CCommunity_GetUserPartnerEventViewStatus_Response_PartnerEvent)

CWebRTCClient_InitiateWebRTCConnection_Request = _reflection.GeneratedProtocolMessageType('CWebRTCClient_InitiateWebRTCConnection_Request', (_message.Message,), dict(
  DESCRIPTOR = _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTCClient_InitiateWebRTCConnection_Request)
  ))
_sym_db.RegisterMessage(CWebRTCClient_InitiateWebRTCConnection_Request)

CWebRTCClient_InitiateWebRTCConnection_Response = _reflection.GeneratedProtocolMessageType('CWebRTCClient_InitiateWebRTCConnection_Response', (_message.Message,), dict(
  DESCRIPTOR = _CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTCClient_InitiateWebRTCConnection_Response)
  ))
_sym_db.RegisterMessage(CWebRTCClient_InitiateWebRTCConnection_Response)

CWebRTC_WebRTCSessionConnected_Notification = _reflection.GeneratedProtocolMessageType('CWebRTC_WebRTCSessionConnected_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CWEBRTC_WEBRTCSESSIONCONNECTED_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTC_WebRTCSessionConnected_Notification)
  ))
_sym_db.RegisterMessage(CWebRTC_WebRTCSessionConnected_Notification)

CWebRTC_WebRTCUpdateRemoteDescription_Notification = _reflection.GeneratedProtocolMessageType('CWebRTC_WebRTCUpdateRemoteDescription_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTC_WebRTCUpdateRemoteDescription_Notification)
  ))
_sym_db.RegisterMessage(CWebRTC_WebRTCUpdateRemoteDescription_Notification)

CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping = _reflection.GeneratedProtocolMessageType('CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping', (_message.Message,), dict(
  DESCRIPTOR = _CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION_CSSRCTOACCOUNTIDMAPPING,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping)
  ))
_sym_db.RegisterMessage(CWebRTC_WebRTCUpdateRemoteDescription_Notification_CSSRCToAccountIDMapping)

CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request = _reflection.GeneratedProtocolMessageType('CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request', (_message.Message,), dict(
  DESCRIPTOR = _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request)
  ))
_sym_db.RegisterMessage(CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Request)

CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response = _reflection.GeneratedProtocolMessageType('CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response', (_message.Message,), dict(
  DESCRIPTOR = _CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response)
  ))
_sym_db.RegisterMessage(CWebRTCClient_AcknowledgeUpdatedRemoteDescription_Response)

CVoiceChat_RequestOneOnOneChat_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_RequestOneOnOneChat_Request', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_REQUESTONEONONECHAT_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_RequestOneOnOneChat_Request)
  ))
_sym_db.RegisterMessage(CVoiceChat_RequestOneOnOneChat_Request)

CVoiceChat_RequestOneOnOneChat_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_RequestOneOnOneChat_Response', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_REQUESTONEONONECHAT_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_RequestOneOnOneChat_Response)
  ))
_sym_db.RegisterMessage(CVoiceChat_RequestOneOnOneChat_Response)

CVoiceChat_OneOnOneChatRequested_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_OneOnOneChatRequested_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_ONEONONECHATREQUESTED_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_OneOnOneChatRequested_Notification)
  ))
_sym_db.RegisterMessage(CVoiceChat_OneOnOneChatRequested_Notification)

CVoiceChat_AnswerOneOnOneChat_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_AnswerOneOnOneChat_Request', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_ANSWERONEONONECHAT_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_AnswerOneOnOneChat_Request)
  ))
_sym_db.RegisterMessage(CVoiceChat_AnswerOneOnOneChat_Request)

CVoiceChat_AnswerOneOnOneChat_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_AnswerOneOnOneChat_Response', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_ANSWERONEONONECHAT_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_AnswerOneOnOneChat_Response)
  ))
_sym_db.RegisterMessage(CVoiceChat_AnswerOneOnOneChat_Response)

CVoiceChat_OneOnOneChatRequestResponse_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_OneOnOneChatRequestResponse_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_ONEONONECHATREQUESTRESPONSE_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_OneOnOneChatRequestResponse_Notification)
  ))
_sym_db.RegisterMessage(CVoiceChat_OneOnOneChatRequestResponse_Notification)

CVoiceChat_EndOneOnOneChat_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_EndOneOnOneChat_Request', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_ENDONEONONECHAT_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_EndOneOnOneChat_Request)
  ))
_sym_db.RegisterMessage(CVoiceChat_EndOneOnOneChat_Request)

CVoiceChat_EndOneOnOneChat_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_EndOneOnOneChat_Response', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_ENDONEONONECHAT_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_EndOneOnOneChat_Response)
  ))
_sym_db.RegisterMessage(CVoiceChat_EndOneOnOneChat_Response)

CVoiceChat_LeaveOneOnOneChat_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_LeaveOneOnOneChat_Request', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_LEAVEONEONONECHAT_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_LeaveOneOnOneChat_Request)
  ))
_sym_db.RegisterMessage(CVoiceChat_LeaveOneOnOneChat_Request)

CVoiceChat_LeaveOneOnOneChat_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_LeaveOneOnOneChat_Response', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_LEAVEONEONONECHAT_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_LeaveOneOnOneChat_Response)
  ))
_sym_db.RegisterMessage(CVoiceChat_LeaveOneOnOneChat_Response)

CVoiceChat_UserJoinedVoiceChat_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_UserJoinedVoiceChat_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_USERJOINEDVOICECHAT_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UserJoinedVoiceChat_Notification)
  ))
_sym_db.RegisterMessage(CVoiceChat_UserJoinedVoiceChat_Notification)

CVoiceChat_UserVoiceStatus_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_UserVoiceStatus_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_USERVOICESTATUS_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UserVoiceStatus_Notification)
  ))
_sym_db.RegisterMessage(CVoiceChat_UserVoiceStatus_Notification)

CVoiceChat_AllMembersStatus_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_AllMembersStatus_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_AllMembersStatus_Notification)
  ))
_sym_db.RegisterMessage(CVoiceChat_AllMembersStatus_Notification)

CVoiceChat_UpdateVoiceChatWebRTCData_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_UpdateVoiceChatWebRTCData_Request', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UpdateVoiceChatWebRTCData_Request)
  ))
_sym_db.RegisterMessage(CVoiceChat_UpdateVoiceChatWebRTCData_Request)

CVoiceChat_UpdateVoiceChatWebRTCData_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_UpdateVoiceChatWebRTCData_Response', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UpdateVoiceChatWebRTCData_Response)
  ))
_sym_db.RegisterMessage(CVoiceChat_UpdateVoiceChatWebRTCData_Response)

CVoiceChat_UploadClientVoiceChatLogs_Request = _reflection.GeneratedProtocolMessageType('CVoiceChat_UploadClientVoiceChatLogs_Request', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UploadClientVoiceChatLogs_Request)
  ))
_sym_db.RegisterMessage(CVoiceChat_UploadClientVoiceChatLogs_Request)

CVoiceChat_UploadClientVoiceChatLogs_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_UploadClientVoiceChatLogs_Response', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UploadClientVoiceChatLogs_Response)
  ))
_sym_db.RegisterMessage(CVoiceChat_UploadClientVoiceChatLogs_Response)

CVoiceChat_LeaveVoiceChat_Response = _reflection.GeneratedProtocolMessageType('CVoiceChat_LeaveVoiceChat_Response', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_LEAVEVOICECHAT_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_LeaveVoiceChat_Response)
  ))
_sym_db.RegisterMessage(CVoiceChat_LeaveVoiceChat_Response)

CVoiceChat_UserLeftVoiceChat_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_UserLeftVoiceChat_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_USERLEFTVOICECHAT_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_UserLeftVoiceChat_Notification)
  ))
_sym_db.RegisterMessage(CVoiceChat_UserLeftVoiceChat_Notification)

CVoiceChat_VoiceChatEnded_Notification = _reflection.GeneratedProtocolMessageType('CVoiceChat_VoiceChatEnded_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CVOICECHAT_VOICECHATENDED_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CVoiceChat_VoiceChatEnded_Notification)
  ))
_sym_db.RegisterMessage(CVoiceChat_VoiceChatEnded_Notification)

CSteamTV_CreateBroadcastChannel_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_CreateBroadcastChannel_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_CreateBroadcastChannel_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_CreateBroadcastChannel_Response)

CSteamTV_GetBroadcastChannelID_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelID_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelID_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelID_Response)

CSteamTV_SetBroadcastChannelProfile_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_SetBroadcastChannelProfile_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelProfile_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelProfile_Response)

CSteamTV_GetBroadcastChannelProfile_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelProfile_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelProfile_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelProfile_Response)

CSteamTV_SetBroadcastChannelImage_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_SetBroadcastChannelImage_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelImage_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelImage_Response)

CSteamTV_GetBroadcastChannelImages_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelImages_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelImages_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelImages_Response)

CSteamTV_GetBroadcastChannelImages_Response_Images = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelImages_Response_Images', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelImages_Response_Images)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelImages_Response_Images)

CSteamTV_GetBroadcastChannelLinks_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelLinks_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelLinks_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelLinks_Response)

CSteamTV_GetBroadcastChannelLinks_Response_Links = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelLinks_Response_Links', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE_LINKS,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelLinks_Response_Links)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelLinks_Response_Links)

CSteamTV_SetBroadcastChannelLinkRegions_Request_Links = _reflection.GeneratedProtocolMessageType('CSteamTV_SetBroadcastChannelLinkRegions_Request_Links', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_REQUEST_LINKS,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelLinkRegions_Request_Links)
  ))
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelLinkRegions_Request_Links)

CSteamTV_SetBroadcastChannelLinkRegions_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_SetBroadcastChannelLinkRegions_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetBroadcastChannelLinkRegions_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_SetBroadcastChannelLinkRegions_Response)

CSteamTV_GetBroadcastChannelStatus_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelStatus_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelStatus_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelStatus_Response)

GetBroadcastChannelEntry = _reflection.GeneratedProtocolMessageType('GetBroadcastChannelEntry', (_message.Message,), dict(
  DESCRIPTOR = _GETBROADCASTCHANNELENTRY,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:GetBroadcastChannelEntry)
  ))
_sym_db.RegisterMessage(GetBroadcastChannelEntry)

CSteamTV_GetFollowedChannels_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetFollowedChannels_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetFollowedChannels_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetFollowedChannels_Response)

CSteamTV_GetSubscribedChannels_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetSubscribedChannels_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetSubscribedChannels_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetSubscribedChannels_Response)

CSteamTV_FollowBroadcastChannel_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_FollowBroadcastChannel_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_FollowBroadcastChannel_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_FollowBroadcastChannel_Response)

CSteamTV_SubscribeBroadcastChannel_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_SubscribeBroadcastChannel_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SubscribeBroadcastChannel_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_SubscribeBroadcastChannel_Response)

CSteamTV_ReportBroadcastChannel_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_ReportBroadcastChannel_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_ReportBroadcastChannel_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_ReportBroadcastChannel_Response)

CSteamTV_GetBroadcastChannelInteraction_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelInteraction_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelInteraction_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelInteraction_Response)

CSteamTV_Game = _reflection.GeneratedProtocolMessageType('CSteamTV_Game', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GAME,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_Game)
  ))
_sym_db.RegisterMessage(CSteamTV_Game)

CSteamTV_GetGames_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetGames_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETGAMES_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetGames_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetGames_Response)

CSteamTV_GetChannels_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetChannels_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETCHANNELS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetChannels_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetChannels_Response)

CSteamTV_GetBroadcastChannelBroadcasters_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelBroadcasters_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelBroadcasters_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelBroadcasters_Response)

CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE_BROADCASTER,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelBroadcasters_Response_Broadcaster)

CSteamTV_ChatBan = _reflection.GeneratedProtocolMessageType('CSteamTV_ChatBan', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_CHATBAN,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_ChatBan)
  ))
_sym_db.RegisterMessage(CSteamTV_ChatBan)

CSteamTV_AddChatBan_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_AddChatBan_Request', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_ADDCHATBAN_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddChatBan_Request)
  ))
_sym_db.RegisterMessage(CSteamTV_AddChatBan_Request)

CSteamTV_AddChatBan_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_AddChatBan_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_ADDCHATBAN_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddChatBan_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_AddChatBan_Response)

CSteamTV_GetChatBans_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetChatBans_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETCHATBANS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetChatBans_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetChatBans_Response)

CSteamTV_AddChatModerator_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_AddChatModerator_Request', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_ADDCHATMODERATOR_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddChatModerator_Request)
  ))
_sym_db.RegisterMessage(CSteamTV_AddChatModerator_Request)

CSteamTV_AddChatModerator_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_AddChatModerator_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_ADDCHATMODERATOR_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddChatModerator_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_AddChatModerator_Response)

CSteamTV_GetChatModerators_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_GetChatModerators_Request', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETCHATMODERATORS_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetChatModerators_Request)
  ))
_sym_db.RegisterMessage(CSteamTV_GetChatModerators_Request)

CSteamTV_ChatModerator = _reflection.GeneratedProtocolMessageType('CSteamTV_ChatModerator', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_CHATMODERATOR,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_ChatModerator)
  ))
_sym_db.RegisterMessage(CSteamTV_ChatModerator)

CSteamTV_GetChatModerators_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetChatModerators_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETCHATMODERATORS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetChatModerators_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetChatModerators_Response)

CSteamTV_AddWordBan_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_AddWordBan_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_ADDWORDBAN_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_AddWordBan_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_AddWordBan_Response)

CSteamTV_GetWordBans_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetWordBans_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETWORDBANS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetWordBans_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetWordBans_Response)

CSteamTV_JoinChat_Request = _reflection.GeneratedProtocolMessageType('CSteamTV_JoinChat_Request', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_JOINCHAT_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_JoinChat_Request)
  ))
_sym_db.RegisterMessage(CSteamTV_JoinChat_Request)

CSteamTV_JoinChat_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_JoinChat_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_JOINCHAT_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_JoinChat_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_JoinChat_Response)

CSteamTV_Search_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_Search_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_SEARCH_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_Search_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_Search_Response)

CSteamTV_GetSteamTVUserSettings_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetSteamTVUserSettings_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetSteamTVUserSettings_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetSteamTVUserSettings_Response)

CSteamTV_SetSteamTVUserSettings_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_SetSteamTVUserSettings_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_SetSteamTVUserSettings_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_SetSteamTVUserSettings_Response)

CSteamTV_GetMyBroadcastChannels_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetMyBroadcastChannels_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetMyBroadcastChannels_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetMyBroadcastChannels_Response)

CSteamTV_HomePageTemplate_Takeover = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_Takeover', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_HOMEPAGETEMPLATE_TAKEOVER,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_Takeover)
  ))
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_Takeover)

CSteamTV_HomePageTemplate_SingleGame = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_SingleGame', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_HOMEPAGETEMPLATE_SINGLEGAME,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_SingleGame)
  ))
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_SingleGame)

GameListEntry = _reflection.GeneratedProtocolMessageType('GameListEntry', (_message.Message,), dict(
  DESCRIPTOR = _GAMELISTENTRY,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:GameListEntry)
  ))
_sym_db.RegisterMessage(GameListEntry)

CSteamTV_HomePageTemplate_GameList = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_GameList', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_HOMEPAGETEMPLATE_GAMELIST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_GameList)
  ))
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_GameList)

CSteamTV_HomePageTemplate_QuickExplore = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_QuickExplore', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_HOMEPAGETEMPLATE_QUICKEXPLORE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_QuickExplore)
  ))
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_QuickExplore)

CSteamTV_HomePageTemplate_ConveyorBelt = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_ConveyorBelt', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_HOMEPAGETEMPLATE_CONVEYORBELT,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_ConveyorBelt)
  ))
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_ConveyorBelt)

CSteamTV_HomePageTemplate_WatchParty = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_WatchParty', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_HOMEPAGETEMPLATE_WATCHPARTY,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_WatchParty)
  ))
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_WatchParty)

CSteamTV_HomePageTemplate_Developer = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_Developer', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_HOMEPAGETEMPLATE_DEVELOPER,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_Developer)
  ))
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_Developer)

CSteamTV_HomePageTemplate_Event = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageTemplate_Event', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_HOMEPAGETEMPLATE_EVENT,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageTemplate_Event)
  ))
_sym_db.RegisterMessage(CSteamTV_HomePageTemplate_Event)

CSteamTV_HomePageContentRow = _reflection.GeneratedProtocolMessageType('CSteamTV_HomePageContentRow', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_HOMEPAGECONTENTROW,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_HomePageContentRow)
  ))
_sym_db.RegisterMessage(CSteamTV_HomePageContentRow)

CSteamTV_GetHomePageContents_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetHomePageContents_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetHomePageContents_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetHomePageContents_Response)

CSteamTV_BroadcastClipInfo = _reflection.GeneratedProtocolMessageType('CSteamTV_BroadcastClipInfo', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_BROADCASTCLIPINFO,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_BroadcastClipInfo)
  ))
_sym_db.RegisterMessage(CSteamTV_BroadcastClipInfo)

CSteamTV_GetBroadcastChannelClips_Response = _reflection.GeneratedProtocolMessageType('CSteamTV_GetBroadcastChannelClips_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CSteamTV_GetBroadcastChannelClips_Response)
  ))
_sym_db.RegisterMessage(CSteamTV_GetBroadcastChannelClips_Response)

CFriendsListCategory = _reflection.GeneratedProtocolMessageType('CFriendsListCategory', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLISTCATEGORY,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsListCategory)
  ))
_sym_db.RegisterMessage(CFriendsListCategory)

CFriendsList_GetCategories_Request = _reflection.GeneratedProtocolMessageType('CFriendsList_GetCategories_Request', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLIST_GETCATEGORIES_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetCategories_Request)
  ))
_sym_db.RegisterMessage(CFriendsList_GetCategories_Request)

CFriendsList_GetCategories_Response = _reflection.GeneratedProtocolMessageType('CFriendsList_GetCategories_Response', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLIST_GETCATEGORIES_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetCategories_Response)
  ))
_sym_db.RegisterMessage(CFriendsList_GetCategories_Response)

CFriendsListFavoriteEntry = _reflection.GeneratedProtocolMessageType('CFriendsListFavoriteEntry', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLISTFAVORITEENTRY,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsListFavoriteEntry)
  ))
_sym_db.RegisterMessage(CFriendsListFavoriteEntry)

CFriendsList_GetFavorites_Request = _reflection.GeneratedProtocolMessageType('CFriendsList_GetFavorites_Request', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLIST_GETFAVORITES_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetFavorites_Request)
  ))
_sym_db.RegisterMessage(CFriendsList_GetFavorites_Request)

CFriendsList_GetFavorites_Response = _reflection.GeneratedProtocolMessageType('CFriendsList_GetFavorites_Response', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLIST_GETFAVORITES_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetFavorites_Response)
  ))
_sym_db.RegisterMessage(CFriendsList_GetFavorites_Response)

CFriendsList_SetFavorites_Request = _reflection.GeneratedProtocolMessageType('CFriendsList_SetFavorites_Request', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLIST_SETFAVORITES_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_SetFavorites_Request)
  ))
_sym_db.RegisterMessage(CFriendsList_SetFavorites_Request)

CFriendsList_SetFavorites_Response = _reflection.GeneratedProtocolMessageType('CFriendsList_SetFavorites_Response', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLIST_SETFAVORITES_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_SetFavorites_Response)
  ))
_sym_db.RegisterMessage(CFriendsList_SetFavorites_Response)

CFriendsList_FavoritesChanged_Notification = _reflection.GeneratedProtocolMessageType('CFriendsList_FavoritesChanged_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_FavoritesChanged_Notification)
  ))
_sym_db.RegisterMessage(CFriendsList_FavoritesChanged_Notification)

CFriendsList_GetFriendsList_Request = _reflection.GeneratedProtocolMessageType('CFriendsList_GetFriendsList_Request', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLIST_GETFRIENDSLIST_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetFriendsList_Request)
  ))
_sym_db.RegisterMessage(CFriendsList_GetFriendsList_Request)

CFriendsList_GetFriendsList_Response = _reflection.GeneratedProtocolMessageType('CFriendsList_GetFriendsList_Response', (_message.Message,), dict(
  DESCRIPTOR = _CFRIENDSLIST_GETFRIENDSLIST_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsList_GetFriendsList_Response)
  ))
_sym_db.RegisterMessage(CFriendsList_GetFriendsList_Response)

CClan_RespondToClanInvite_Request = _reflection.GeneratedProtocolMessageType('CClan_RespondToClanInvite_Request', (_message.Message,), dict(
  DESCRIPTOR = _CCLAN_RESPONDTOCLANINVITE_REQUEST,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CClan_RespondToClanInvite_Request)
  ))
_sym_db.RegisterMessage(CClan_RespondToClanInvite_Request)

CClan_RespondToClanInvite_Response = _reflection.GeneratedProtocolMessageType('CClan_RespondToClanInvite_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCLAN_RESPONDTOCLANINVITE_RESPONSE,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CClan_RespondToClanInvite_Response)
  ))
_sym_db.RegisterMessage(CClan_RespondToClanInvite_Response)

CProductImpressionsFromClient_Notification = _reflection.GeneratedProtocolMessageType('CProductImpressionsFromClient_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CProductImpressionsFromClient_Notification)
  ))
_sym_db.RegisterMessage(CProductImpressionsFromClient_Notification)

CProductImpressionsFromClient_Notification_Impression = _reflection.GeneratedProtocolMessageType('CProductImpressionsFromClient_Notification_Impression', (_message.Message,), dict(
  DESCRIPTOR = _CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:CProductImpressionsFromClient_Notification_Impression)
  ))
_sym_db.RegisterMessage(CProductImpressionsFromClient_Notification_Impression)

NotImplemented = _reflection.GeneratedProtocolMessageType('NotImplemented', (_message.Message,), dict(
  DESCRIPTOR = _NOTIMPLEMENTED,
  __module__ = 'steammessages_webui_friends_pb2'
  # @@protoc_insertion_point(class_scope:NotImplemented)
  ))
_sym_db.RegisterMessage(NotImplemented)


DESCRIPTOR._options = None
_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST_PARTNEREVENTMARKING.fields_by_name['display_location']._options = None
_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE_IMAGES.fields_by_name['image_type']._options = None
_CSTEAMTV_HOMEPAGECONTENTROW.fields_by_name['template_type']._options = None
_CPRODUCTIMPRESSIONSFROMCLIENT_NOTIFICATION_IMPRESSION.fields_by_name['type']._options = None

_COMMUNITY = _descriptor.ServiceDescriptor(
  name='Community',
  full_name='Community',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=14285,
  serialized_end=16178,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetApps',
    full_name='Community.GetApps',
    index=0,
    containing_service=None,
    input_type=_CCOMMUNITY_GETAPPS_REQUEST,
    output_type=_CCOMMUNITY_GETAPPS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAppRichPresenceLocalization',
    full_name='Community.GetAppRichPresenceLocalization',
    index=1,
    containing_service=None,
    input_type=_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_REQUEST,
    output_type=_CCOMMUNITY_GETAPPRICHPRESENCELOCALIZATION_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommentThread',
    full_name='Community.GetCommentThread',
    index=2,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_GETCOMMENTTHREAD_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PostCommentToThread',
    full_name='Community.PostCommentToThread',
    index=3,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_POSTCOMMENTTOTHREAD_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCommentFromThread',
    full_name='Community.DeleteCommentFromThread',
    index=4,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_DELETECOMMENTFROMTHREAD_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RateCommentThread',
    full_name='Community.RateCommentThread',
    index=5,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_RATECOMMENTTHREAD_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommentThreadRatings',
    full_name='Community.GetCommentThreadRatings',
    index=6,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_GETCOMMENTTHREADRATINGS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RateClanAnnouncement',
    full_name='Community.RateClanAnnouncement',
    index=7,
    containing_service=None,
    input_type=_CCOMMUNITY_RATECLANANNOUNCEMENT_REQUEST,
    output_type=_CCOMMUNITY_RATECLANANNOUNCEMENT_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetClanAnnouncementVoteForUser',
    full_name='Community.GetClanAnnouncementVoteForUser',
    index=8,
    containing_service=None,
    input_type=_CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_REQUEST,
    output_type=_CCOMMUNITY_GETCLANANNOUNCEMENTVOTEFORUSER_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAvatarHistory',
    full_name='Community.GetAvatarHistory',
    index=9,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_GETAVATARHISTORY_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserPartnerEventNews',
    full_name='Community.GetUserPartnerEventNews',
    index=10,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_GETUSERPARTNEREVENTNEWS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBestEventsForUser',
    full_name='Community.GetBestEventsForUser',
    index=11,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_GETBESTEVENTSFORUSER_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MarkPartnerEventsForUser',
    full_name='Community.MarkPartnerEventsForUser',
    index=12,
    containing_service=None,
    input_type=_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_REQUEST,
    output_type=_CCOMMUNITY_MARKPARTNEREVENTSFORUSER_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserPartnerEventViewStatus',
    full_name='Community.GetUserPartnerEventViewStatus',
    index=13,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_GETUSERPARTNEREVENTVIEWSTATUS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PartnerEventsShowMoreForApp',
    full_name='Community.PartnerEventsShowMoreForApp',
    index=14,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_PARTNEREVENTSSHOWMOREFORAPP_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PartnerEventsShowLessForApp',
    full_name='Community.PartnerEventsShowLessForApp',
    index=15,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_PARTNEREVENTSSHOWLESSFORAPP_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ClearUserPartnerEventsAppPriorities',
    full_name='Community.ClearUserPartnerEventsAppPriorities',
    index=16,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_CLEARUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserPartnerEventsAppPriorities',
    full_name='Community.GetUserPartnerEventsAppPriorities',
    index=17,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_GETUSERPARTNEREVENTSAPPPRIORITIES_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ClearSinglePartnerEventsAppPriority',
    full_name='Community.ClearSinglePartnerEventsAppPriority',
    index=18,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CCOMMUNITY_CLEARSINGLEPARTNEREVENTSAPPPRIORITY_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMMUNITY)

DESCRIPTOR.services_by_name['Community'] = _COMMUNITY


_WEBRTCCLIENT = _descriptor.ServiceDescriptor(
  name='WebRTCClient',
  full_name='WebRTCClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=16181,
  serialized_end=16483,
  methods=[
  _descriptor.MethodDescriptor(
    name='InitiateWebRTCConnection',
    full_name='WebRTCClient.InitiateWebRTCConnection',
    index=0,
    containing_service=None,
    input_type=_CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_REQUEST,
    output_type=_CWEBRTCCLIENT_INITIATEWEBRTCCONNECTION_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AcknowledgeUpdatedRemoteDescription',
    full_name='WebRTCClient.AcknowledgeUpdatedRemoteDescription',
    index=1,
    containing_service=None,
    input_type=_CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_REQUEST,
    output_type=_CWEBRTCCLIENT_ACKNOWLEDGEUPDATEDREMOTEDESCRIPTION_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBRTCCLIENT)

DESCRIPTOR.services_by_name['WebRTCClient'] = _WEBRTCCLIENT


_WEBRTCCLIENTNOTIFICATIONS = _descriptor.ServiceDescriptor(
  name='WebRTCClientNotifications',
  full_name='WebRTCClientNotifications',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  serialized_start=16486,
  serialized_end=16709,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyWebRTCSessionConnected',
    full_name='WebRTCClientNotifications.NotifyWebRTCSessionConnected',
    index=0,
    containing_service=None,
    input_type=_CWEBRTC_WEBRTCSESSIONCONNECTED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyWebRTCUpdateRemoteDescription',
    full_name='WebRTCClientNotifications.NotifyWebRTCUpdateRemoteDescription',
    index=1,
    containing_service=None,
    input_type=_CWEBRTC_WEBRTCUPDATEREMOTEDESCRIPTION_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBRTCCLIENTNOTIFICATIONS)

DESCRIPTOR.services_by_name['WebRTCClientNotifications'] = _WEBRTCCLIENTNOTIFICATIONS


_VOICECHAT = _descriptor.ServiceDescriptor(
  name='VoiceChat',
  full_name='VoiceChat',
  file=DESCRIPTOR,
  index=3,
  serialized_options=None,
  serialized_start=16712,
  serialized_end=17526,
  methods=[
  _descriptor.MethodDescriptor(
    name='UpdateVoiceChatWebRTCData',
    full_name='VoiceChat.UpdateVoiceChatWebRTCData',
    index=0,
    containing_service=None,
    input_type=_CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_REQUEST,
    output_type=_CVOICECHAT_UPDATEVOICECHATWEBRTCDATA_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyUserVoiceStatus',
    full_name='VoiceChat.NotifyUserVoiceStatus',
    index=1,
    containing_service=None,
    input_type=_CVOICECHAT_USERVOICESTATUS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UploadClientVoiceChatLogs',
    full_name='VoiceChat.UploadClientVoiceChatLogs',
    index=2,
    containing_service=None,
    input_type=_CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_REQUEST,
    output_type=_CVOICECHAT_UPLOADCLIENTVOICECHATLOGS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveVoiceChat',
    full_name='VoiceChat.LeaveVoiceChat',
    index=3,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CVOICECHAT_LEAVEVOICECHAT_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RequestOneOnOneChat',
    full_name='VoiceChat.RequestOneOnOneChat',
    index=4,
    containing_service=None,
    input_type=_CVOICECHAT_REQUESTONEONONECHAT_REQUEST,
    output_type=_CVOICECHAT_REQUESTONEONONECHAT_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AnswerOneOnOneChat',
    full_name='VoiceChat.AnswerOneOnOneChat',
    index=5,
    containing_service=None,
    input_type=_CVOICECHAT_ANSWERONEONONECHAT_REQUEST,
    output_type=_CVOICECHAT_ANSWERONEONONECHAT_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EndOneOnOneChat',
    full_name='VoiceChat.EndOneOnOneChat',
    index=6,
    containing_service=None,
    input_type=_CVOICECHAT_ENDONEONONECHAT_REQUEST,
    output_type=_CVOICECHAT_ENDONEONONECHAT_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LeaveOneOnOneChat',
    full_name='VoiceChat.LeaveOneOnOneChat',
    index=7,
    containing_service=None,
    input_type=_CVOICECHAT_LEAVEONEONONECHAT_REQUEST,
    output_type=_CVOICECHAT_LEAVEONEONONECHAT_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_VOICECHAT)

DESCRIPTOR.services_by_name['VoiceChat'] = _VOICECHAT


_VOICECHATCLIENT = _descriptor.ServiceDescriptor(
  name='VoiceChatClient',
  full_name='VoiceChatClient',
  file=DESCRIPTOR,
  index=4,
  serialized_options=None,
  serialized_start=17529,
  serialized_end=18150,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyUserJoinedVoiceChat',
    full_name='VoiceChatClient.NotifyUserJoinedVoiceChat',
    index=0,
    containing_service=None,
    input_type=_CVOICECHAT_USERJOINEDVOICECHAT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyUserLeftVoiceChat',
    full_name='VoiceChatClient.NotifyUserLeftVoiceChat',
    index=1,
    containing_service=None,
    input_type=_CVOICECHAT_USERLEFTVOICECHAT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyVoiceChatEnded',
    full_name='VoiceChatClient.NotifyVoiceChatEnded',
    index=2,
    containing_service=None,
    input_type=_CVOICECHAT_VOICECHATENDED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyUserVoiceStatus',
    full_name='VoiceChatClient.NotifyUserVoiceStatus',
    index=3,
    containing_service=None,
    input_type=_CVOICECHAT_USERVOICESTATUS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyAllUsersVoiceStatus',
    full_name='VoiceChatClient.NotifyAllUsersVoiceStatus',
    index=4,
    containing_service=None,
    input_type=_CVOICECHAT_ALLMEMBERSSTATUS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyOneOnOneChatRequested',
    full_name='VoiceChatClient.NotifyOneOnOneChatRequested',
    index=5,
    containing_service=None,
    input_type=_CVOICECHAT_ONEONONECHATREQUESTED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyOneOnOneChatResponse',
    full_name='VoiceChatClient.NotifyOneOnOneChatResponse',
    index=6,
    containing_service=None,
    input_type=_CVOICECHAT_ONEONONECHATREQUESTRESPONSE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_VOICECHATCLIENT)

DESCRIPTOR.services_by_name['VoiceChatClient'] = _VOICECHATCLIENT


_STEAMTV = _descriptor.ServiceDescriptor(
  name='SteamTV',
  full_name='SteamTV',
  file=DESCRIPTOR,
  index=5,
  serialized_options=None,
  serialized_start=18153,
  serialized_end=20747,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateBroadcastChannel',
    full_name='SteamTV.CreateBroadcastChannel',
    index=0,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_CREATEBROADCASTCHANNEL_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelID',
    full_name='SteamTV.GetBroadcastChannelID',
    index=1,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELID_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetBroadcastChannelProfile',
    full_name='SteamTV.SetBroadcastChannelProfile',
    index=2,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_SETBROADCASTCHANNELPROFILE_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelProfile',
    full_name='SteamTV.GetBroadcastChannelProfile',
    index=3,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELPROFILE_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetBroadcastChannelImage',
    full_name='SteamTV.SetBroadcastChannelImage',
    index=4,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_SETBROADCASTCHANNELIMAGE_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelImages',
    full_name='SteamTV.GetBroadcastChannelImages',
    index=5,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELIMAGES_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetBroadcastChannelLinkRegions',
    full_name='SteamTV.SetBroadcastChannelLinkRegions',
    index=6,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_SETBROADCASTCHANNELLINKREGIONS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelLinks',
    full_name='SteamTV.GetBroadcastChannelLinks',
    index=7,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELLINKS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelBroadcasters',
    full_name='SteamTV.GetBroadcastChannelBroadcasters',
    index=8,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELBROADCASTERS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetFollowedChannels',
    full_name='SteamTV.GetFollowedChannels',
    index=9,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETFOLLOWEDCHANNELS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSubscribedChannels',
    full_name='SteamTV.GetSubscribedChannels',
    index=10,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETSUBSCRIBEDCHANNELS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelStatus',
    full_name='SteamTV.GetBroadcastChannelStatus',
    index=11,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELSTATUS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FollowBroadcastChannel',
    full_name='SteamTV.FollowBroadcastChannel',
    index=12,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_FOLLOWBROADCASTCHANNEL_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeBroadcastChannel',
    full_name='SteamTV.SubscribeBroadcastChannel',
    index=13,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_SUBSCRIBEBROADCASTCHANNEL_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelClips',
    full_name='SteamTV.GetBroadcastChannelClips',
    index=14,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELCLIPS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReportBroadcastChannel',
    full_name='SteamTV.ReportBroadcastChannel',
    index=15,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_REPORTBROADCASTCHANNEL_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChannelInteraction',
    full_name='SteamTV.GetBroadcastChannelInteraction',
    index=16,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETBROADCASTCHANNELINTERACTION_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetGames',
    full_name='SteamTV.GetGames',
    index=17,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETGAMES_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetChannels',
    full_name='SteamTV.GetChannels',
    index=18,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETCHANNELS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddChatBan',
    full_name='SteamTV.AddChatBan',
    index=19,
    containing_service=None,
    input_type=_CSTEAMTV_ADDCHATBAN_REQUEST,
    output_type=_CSTEAMTV_ADDCHATBAN_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetChatBans',
    full_name='SteamTV.GetChatBans',
    index=20,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETCHATBANS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddChatModerator',
    full_name='SteamTV.AddChatModerator',
    index=21,
    containing_service=None,
    input_type=_CSTEAMTV_ADDCHATMODERATOR_REQUEST,
    output_type=_CSTEAMTV_ADDCHATMODERATOR_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetChatModerators',
    full_name='SteamTV.GetChatModerators',
    index=22,
    containing_service=None,
    input_type=_CSTEAMTV_GETCHATMODERATORS_REQUEST,
    output_type=_CSTEAMTV_GETCHATMODERATORS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddWordBan',
    full_name='SteamTV.AddWordBan',
    index=23,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_ADDWORDBAN_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetWordBans',
    full_name='SteamTV.GetWordBans',
    index=24,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETWORDBANS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='JoinChat',
    full_name='SteamTV.JoinChat',
    index=25,
    containing_service=None,
    input_type=_CSTEAMTV_JOINCHAT_REQUEST,
    output_type=_CSTEAMTV_JOINCHAT_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='SteamTV.Search',
    index=26,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_SEARCH_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSteamTVUserSettings',
    full_name='SteamTV.GetSteamTVUserSettings',
    index=27,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETSTEAMTVUSERSETTINGS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSteamTVUserSettings',
    full_name='SteamTV.SetSteamTVUserSettings',
    index=28,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_SETSTEAMTVUSERSETTINGS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMyBroadcastChannels',
    full_name='SteamTV.GetMyBroadcastChannels',
    index=29,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETMYBROADCASTCHANNELS_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetHomePageContents',
    full_name='SteamTV.GetHomePageContents',
    index=30,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=_CSTEAMTV_GETHOMEPAGECONTENTS_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STEAMTV)

DESCRIPTOR.services_by_name['SteamTV'] = _STEAMTV


_FRIENDSLIST = _descriptor.ServiceDescriptor(
  name='FriendsList',
  full_name='FriendsList',
  file=DESCRIPTOR,
  index=6,
  serialized_options=None,
  serialized_start=20750,
  serialized_end=21128,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCategories',
    full_name='FriendsList.GetCategories',
    index=0,
    containing_service=None,
    input_type=_CFRIENDSLIST_GETCATEGORIES_REQUEST,
    output_type=_CFRIENDSLIST_GETCATEGORIES_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetFriendsList',
    full_name='FriendsList.GetFriendsList',
    index=1,
    containing_service=None,
    input_type=_CFRIENDSLIST_GETFRIENDSLIST_REQUEST,
    output_type=_CFRIENDSLIST_GETFRIENDSLIST_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetFavorites',
    full_name='FriendsList.GetFavorites',
    index=2,
    containing_service=None,
    input_type=_CFRIENDSLIST_GETFAVORITES_REQUEST,
    output_type=_CFRIENDSLIST_GETFAVORITES_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetFavorites',
    full_name='FriendsList.SetFavorites',
    index=3,
    containing_service=None,
    input_type=_CFRIENDSLIST_SETFAVORITES_REQUEST,
    output_type=_CFRIENDSLIST_SETFAVORITES_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FRIENDSLIST)

DESCRIPTOR.services_by_name['FriendsList'] = _FRIENDSLIST


_FRIENDSLISTCLIENT = _descriptor.ServiceDescriptor(
  name='FriendsListClient',
  full_name='FriendsListClient',
  file=DESCRIPTOR,
  index=7,
  serialized_options=None,
  serialized_start=21130,
  serialized_end=21227,
  methods=[
  _descriptor.MethodDescriptor(
    name='FavoritesChanged',
    full_name='FriendsListClient.FavoritesChanged',
    index=0,
    containing_service=None,
    input_type=_CFRIENDSLIST_FAVORITESCHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FRIENDSLISTCLIENT)

DESCRIPTOR.services_by_name['FriendsListClient'] = _FRIENDSLISTCLIENT


_CLAN = _descriptor.ServiceDescriptor(
  name='Clan',
  full_name='Clan',
  file=DESCRIPTOR,
  index=8,
  serialized_options=None,
  serialized_start=21229,
  serialized_end=21331,
  methods=[
  _descriptor.MethodDescriptor(
    name='RespondToClanInvite',
    full_name='Clan.RespondToClanInvite',
    index=0,
    containing_service=None,
    input_type=_CCLAN_RESPONDTOCLANINVITE_REQUEST,
    output_type=_CCLAN_RESPONDTOCLANINVITE_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLAN)

DESCRIPTOR.services_by_name['Clan'] = _CLAN


_EXPERIMENTSERVICE = _descriptor.ServiceDescriptor(
  name='ExperimentService',
  full_name='ExperimentService',
  file=DESCRIPTOR,
  index=9,
  serialized_options=None,
  serialized_start=21333,
  serialized_end=21420,
  methods=[
  _descriptor.MethodDescriptor(
    name='ReportProductImpressionsFromClient',
    full_name='ExperimentService.ReportProductImpressionsFromClient',
    index=0,
    containing_service=None,
    input_type=_NOTIMPLEMENTED,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXPERIMENTSERVICE)

DESCRIPTOR.services_by_name['ExperimentService'] = _EXPERIMENTSERVICE

Community = service_reflection.GeneratedServiceType('Community', (_service.Service,), dict(
  DESCRIPTOR = _COMMUNITY,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

Community_Stub = service_reflection.GeneratedServiceStubType('Community_Stub', (Community,), dict(
  DESCRIPTOR = _COMMUNITY,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


WebRTCClient = service_reflection.GeneratedServiceType('WebRTCClient', (_service.Service,), dict(
  DESCRIPTOR = _WEBRTCCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

WebRTCClient_Stub = service_reflection.GeneratedServiceStubType('WebRTCClient_Stub', (WebRTCClient,), dict(
  DESCRIPTOR = _WEBRTCCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


WebRTCClientNotifications = service_reflection.GeneratedServiceType('WebRTCClientNotifications', (_service.Service,), dict(
  DESCRIPTOR = _WEBRTCCLIENTNOTIFICATIONS,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

WebRTCClientNotifications_Stub = service_reflection.GeneratedServiceStubType('WebRTCClientNotifications_Stub', (WebRTCClientNotifications,), dict(
  DESCRIPTOR = _WEBRTCCLIENTNOTIFICATIONS,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


VoiceChat = service_reflection.GeneratedServiceType('VoiceChat', (_service.Service,), dict(
  DESCRIPTOR = _VOICECHAT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

VoiceChat_Stub = service_reflection.GeneratedServiceStubType('VoiceChat_Stub', (VoiceChat,), dict(
  DESCRIPTOR = _VOICECHAT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


VoiceChatClient = service_reflection.GeneratedServiceType('VoiceChatClient', (_service.Service,), dict(
  DESCRIPTOR = _VOICECHATCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

VoiceChatClient_Stub = service_reflection.GeneratedServiceStubType('VoiceChatClient_Stub', (VoiceChatClient,), dict(
  DESCRIPTOR = _VOICECHATCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


SteamTV = service_reflection.GeneratedServiceType('SteamTV', (_service.Service,), dict(
  DESCRIPTOR = _STEAMTV,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

SteamTV_Stub = service_reflection.GeneratedServiceStubType('SteamTV_Stub', (SteamTV,), dict(
  DESCRIPTOR = _STEAMTV,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


FriendsList = service_reflection.GeneratedServiceType('FriendsList', (_service.Service,), dict(
  DESCRIPTOR = _FRIENDSLIST,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

FriendsList_Stub = service_reflection.GeneratedServiceStubType('FriendsList_Stub', (FriendsList,), dict(
  DESCRIPTOR = _FRIENDSLIST,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


FriendsListClient = service_reflection.GeneratedServiceType('FriendsListClient', (_service.Service,), dict(
  DESCRIPTOR = _FRIENDSLISTCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

FriendsListClient_Stub = service_reflection.GeneratedServiceStubType('FriendsListClient_Stub', (FriendsListClient,), dict(
  DESCRIPTOR = _FRIENDSLISTCLIENT,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


Clan = service_reflection.GeneratedServiceType('Clan', (_service.Service,), dict(
  DESCRIPTOR = _CLAN,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

Clan_Stub = service_reflection.GeneratedServiceStubType('Clan_Stub', (Clan,), dict(
  DESCRIPTOR = _CLAN,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


ExperimentService = service_reflection.GeneratedServiceType('ExperimentService', (_service.Service,), dict(
  DESCRIPTOR = _EXPERIMENTSERVICE,
  __module__ = 'steammessages_webui_friends_pb2'
  ))

ExperimentService_Stub = service_reflection.GeneratedServiceStubType('ExperimentService_Stub', (ExperimentService,), dict(
  DESCRIPTOR = _EXPERIMENTSERVICE,
  __module__ = 'steammessages_webui_friends_pb2'
  ))


# @@protoc_insertion_point(module_scope)
