# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.encrypted_app_ticket_pb2 as encrypted__app__ticket__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver.proto',
  package='',
  syntax='proto2',
  serialized_options=_b('H\001\220\001\000'),
  serialized_pb=_b('\n steammessages_clientserver.proto\x1a\x18steammessages_base.proto\x1a\x1a\x65ncrypted_app_ticket.proto\"G\n\x1e\x43MsgClientUDSP2PSessionStarted\x12\x16\n\x0esteamid_remote\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\x05\"\x81\x02\n\x1c\x43MsgClientUDSP2PSessionEnded\x12\x16\n\x0esteamid_remote\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\x05\x12\x1a\n\x12session_length_sec\x18\x03 \x01(\x05\x12\x15\n\rsession_error\x18\x04 \x01(\x05\x12\x0f\n\x07nattype\x18\x05 \x01(\x05\x12\x12\n\nbytes_recv\x18\x06 \x01(\x05\x12\x12\n\nbytes_sent\x18\x07 \x01(\x05\x12\x18\n\x10\x62ytes_sent_relay\x18\x08 \x01(\x05\x12\x18\n\x10\x62ytes_recv_relay\x18\t \x01(\x05\x12\x1a\n\x12time_to_connect_ms\x18\n \x01(\x05\"j\n\"CMsgClientRegisterAuthTicketWithCM\x12\x18\n\x10protocol_version\x18\x01 \x01(\r\x12\x0e\n\x06ticket\x18\x03 \x01(\x0c\x12\x1a\n\x12\x63lient_instance_id\x18\x04 \x01(\x04\"\xd1\x01\n\x1c\x43MsgClientTicketAuthComplete\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x0f\n\x07game_id\x18\x02 \x01(\x06\x12\x0e\n\x06\x65state\x18\x03 \x01(\r\x12\x1e\n\x16\x65\x61uth_session_response\x18\x04 \x01(\r\x12\x19\n\x11\x44\x45PRECATED_ticket\x18\x05 \x01(\x0c\x12\x12\n\nticket_crc\x18\x06 \x01(\r\x12\x17\n\x0fticket_sequence\x18\x07 \x01(\r\x12\x16\n\x0eowner_steam_id\x18\x08 \x01(\x06\"\x80\x01\n\x10\x43MsgClientCMList\x12\x14\n\x0c\x63m_addresses\x18\x01 \x03(\r\x12\x10\n\x08\x63m_ports\x18\x02 \x03(\r\x12\x1e\n\x16\x63m_websocket_addresses\x18\x03 \x03(\t\x12$\n\x1cpercent_default_to_websocket\x18\x04 \x01(\r\"\x9c\x01\n\x1b\x43MsgClientP2PConnectionInfo\x12\x15\n\rsteam_id_dest\x18\x01 \x01(\x06\x12\x14\n\x0csteam_id_src\x18\x02 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x11\n\tcandidate\x18\x04 \x01(\x0c\x12\x19\n\x11\x63onnection_id_src\x18\x05 \x01(\x06\x12\x12\n\nrendezvous\x18\x06 \x01(\x0c\"\xc3\x01\n\x1f\x43MsgClientP2PConnectionFailInfo\x12\x15\n\rsteam_id_dest\x18\x01 \x01(\x06\x12\x14\n\x0csteam_id_src\x18\x02 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x1a\n\x12\x65p2p_session_error\x18\x04 \x01(\r\x12\x1a\n\x12\x63onnection_id_dest\x18\x05 \x01(\x06\x12\x14\n\x0c\x63lose_reason\x18\x07 \x01(\r\x12\x15\n\rclose_message\x18\x08 \x01(\t\"C\n\x1f\x43MsgClientNetworkingCertRequest\x12\x10\n\x08key_data\x18\x02 \x01(\x0c\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\"V\n\x1d\x43MsgClientNetworkingCertReply\x12\x0c\n\x04\x63\x65rt\x18\x04 \x01(\x0c\x12\x11\n\tca_key_id\x18\x05 \x01(\x06\x12\x14\n\x0c\x63\x61_signature\x18\x06 \x01(\x0c\"7\n%CMsgClientNetworkingMobileCertRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\";\n#CMsgClientNetworkingMobileCertReply\x12\x14\n\x0c\x65ncoded_cert\x18\x01 \x01(\t\"1\n\x1f\x43MsgClientGetAppOwnershipTicket\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\"]\n\'CMsgClientGetAppOwnershipTicketResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x0e\n\x06ticket\x18\x03 \x01(\x0c\"\'\n\x16\x43MsgClientSessionToken\x12\r\n\x05token\x18\x01 \x01(\x04\"M\n\x1b\x43MsgClientGameConnectTokens\x12\x1e\n\x12max_tokens_to_keep\x18\x01 \x01(\r:\x02\x31\x30\x12\x0e\n\x06tokens\x18\x02 \x03(\x0c\"\xb0\x01\n\x10\x43MsgGSServerType\x12\x15\n\rapp_id_served\x18\x01 \x01(\r\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\"\n\x1a\x64\x65precated_game_ip_address\x18\x03 \x01(\r\x12\x11\n\tgame_port\x18\x04 \x01(\r\x12\x10\n\x08game_dir\x18\x05 \x01(\t\x12\x14\n\x0cgame_version\x18\x06 \x01(\t\x12\x17\n\x0fgame_query_port\x18\x07 \x01(\r\"&\n\x11\x43MsgGSStatusReply\x12\x11\n\tis_secure\x18\x01 \x01(\x08\"\xa9\x01\n\x10\x43MsgGSPlayerList\x12)\n\x07players\x18\x01 \x03(\x0b\x32\x18.CMsgGSPlayerList.Player\x1aj\n\x06Player\x12\x10\n\x08steam_id\x18\x01 \x01(\x04\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\x0c\x12!\n\tpublic_ip\x18\x04 \x01(\x0b\x32\x0e.CMsgIPAddress\"u\n\x11\x43MsgGSUserPlaying\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\x0c\x12!\n\tpublic_ip\x18\x04 \x01(\x0b\x32\x0e.CMsgIPAddress\"*\n\x16\x43MsgGSDisconnectNotice\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"\xb9\x06\n\x15\x43MsgClientGamesPlayed\x12\x37\n\x0cgames_played\x18\x01 \x03(\x0b\x32!.CMsgClientGamesPlayed.GamePlayed\x12\x16\n\x0e\x63lient_os_type\x18\x02 \x01(\r\x12\x1d\n\x15\x63loud_gaming_platform\x18\x03 \x01(\r\x1a\xaf\x05\n\nGamePlayed\x12\x13\n\x0bsteam_id_gs\x18\x01 \x01(\x04\x12\x0f\n\x07game_id\x18\x02 \x01(\x06\x12\"\n\x1a\x64\x65precated_game_ip_address\x18\x03 \x01(\r\x12\x11\n\tgame_port\x18\x04 \x01(\r\x12\x11\n\tis_secure\x18\x05 \x01(\x08\x12\r\n\x05token\x18\x06 \x01(\x0c\x12\x17\n\x0fgame_extra_info\x18\x07 \x01(\t\x12\x16\n\x0egame_data_blob\x18\x08 \x01(\x0c\x12\x12\n\nprocess_id\x18\t \x01(\r\x12\x1d\n\x15streaming_provider_id\x18\n \x01(\r\x12\x12\n\ngame_flags\x18\x0b \x01(\r\x12\x10\n\x08owner_id\x18\x0c \x01(\r\x12\x15\n\rvr_hmd_vendor\x18\r \x01(\t\x12\x14\n\x0cvr_hmd_model\x18\x0e \x01(\t\x12\x1d\n\x12launch_option_type\x18\x0f \x01(\r:\x01\x30\x12#\n\x17primary_controller_type\x18\x10 \x01(\x05:\x02-1\x12\'\n\x1fprimary_steam_controller_serial\x18\x11 \x01(\t\x12\'\n\x1ctotal_steam_controller_count\x18\x12 \x01(\r:\x01\x30\x12+\n total_non_steam_controller_count\x18\x13 \x01(\r:\x01\x30\x12&\n\x1b\x63ontroller_workshop_file_id\x18\x14 \x01(\x04:\x01\x30\x12\x18\n\rlaunch_source\x18\x15 \x01(\r:\x01\x30\x12\x16\n\x0evr_hmd_runtime\x18\x16 \x01(\r\x12\'\n\x0fgame_ip_address\x18\x17 \x01(\x0b\x32\x0e.CMsgIPAddress\x12%\n\x1a\x63ontroller_connection_type\x18\x18 \x01(\r:\x01\x30\"9\n\rCMsgGSApprove\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x16\n\x0eowner_steam_id\x18\x02 \x01(\x06\"I\n\nCMsgGSDeny\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0c\x65\x64\x65ny_reason\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x65ny_string\x18\x03 \x01(\t\"4\n\nCMsgGSKick\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0c\x65\x64\x65ny_reason\x18\x02 \x01(\x05\"\xb6\x01\n\x12\x43MsgClientAuthList\x12\x13\n\x0btokens_left\x18\x01 \x01(\r\x12\x18\n\x10last_request_seq\x18\x02 \x01(\r\x12$\n\x1clast_request_seq_from_server\x18\x03 \x01(\r\x12 \n\x07tickets\x18\x04 \x03(\x0b\x32\x0f.CMsgAuthTicket\x12\x0f\n\x07\x61pp_ids\x18\x05 \x03(\r\x12\x18\n\x10message_sequence\x18\x06 \x01(\r\"V\n\x15\x43MsgClientAuthListAck\x12\x12\n\nticket_crc\x18\x01 \x03(\r\x12\x0f\n\x07\x61pp_ids\x18\x02 \x03(\r\x12\x18\n\x10message_sequence\x18\x03 \x01(\r\"\x8e\x04\n\x15\x43MsgClientLicenseList\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x30\n\x08licenses\x18\x02 \x03(\x0b\x32\x1e.CMsgClientLicenseList.License\x1a\xae\x03\n\x07License\x12\x12\n\npackage_id\x18\x01 \x01(\r\x12\x14\n\x0ctime_created\x18\x02 \x01(\x07\x12\x19\n\x11time_next_process\x18\x03 \x01(\x07\x12\x14\n\x0cminute_limit\x18\x04 \x01(\x05\x12\x14\n\x0cminutes_used\x18\x05 \x01(\x05\x12\x16\n\x0epayment_method\x18\x06 \x01(\r\x12\r\n\x05\x66lags\x18\x07 \x01(\r\x12\x1d\n\x15purchase_country_code\x18\x08 \x01(\t\x12\x14\n\x0clicense_type\x18\t \x01(\r\x12\x16\n\x0eterritory_code\x18\n \x01(\x05\x12\x15\n\rchange_number\x18\x0b \x01(\x05\x12\x10\n\x08owner_id\x18\x0c \x01(\r\x12\x16\n\x0einitial_period\x18\r \x01(\r\x12\x19\n\x11initial_time_unit\x18\x0e \x01(\r\x12\x16\n\x0erenewal_period\x18\x0f \x01(\r\x12\x19\n\x11renewal_time_unit\x18\x10 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x11 \x01(\x04\x12\x19\n\x11master_package_id\x18\x12 \x01(\r\"|\n\x15\x43MsgClientLBSSetScore\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0eleaderboard_id\x18\x02 \x01(\x05\x12\r\n\x05score\x18\x03 \x01(\x05\x12\x0f\n\x07\x64\x65tails\x18\x04 \x01(\x0c\x12\x1b\n\x13upload_score_method\x18\x05 \x01(\x05\"\xa2\x01\n\x1d\x43MsgClientLBSSetScoreResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x1f\n\x17leaderboard_entry_count\x18\x02 \x01(\x05\x12\x15\n\rscore_changed\x18\x03 \x01(\x08\x12\x1c\n\x14global_rank_previous\x18\x04 \x01(\x05\x12\x17\n\x0fglobal_rank_new\x18\x05 \x01(\x05\"M\n\x13\x43MsgClientLBSSetUGC\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0eleaderboard_id\x18\x02 \x01(\x05\x12\x0e\n\x06ugc_id\x18\x03 \x01(\x06\"1\n\x1b\x43MsgClientLBSSetUGCResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"\xa7\x01\n\x1b\x43MsgClientLBSFindOrCreateLB\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x1f\n\x17leaderboard_sort_method\x18\x02 \x01(\x05\x12 \n\x18leaderboard_display_type\x18\x03 \x01(\x05\x12\x1b\n\x13\x63reate_if_not_found\x18\x04 \x01(\x08\x12\x18\n\x10leaderboard_name\x18\x05 \x01(\t\"\xd5\x01\n#CMsgClientLBSFindOrCreateLBResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x16\n\x0eleaderboard_id\x18\x02 \x01(\x05\x12\x1f\n\x17leaderboard_entry_count\x18\x03 \x01(\x05\x12\"\n\x17leaderboard_sort_method\x18\x04 \x01(\x05:\x01\x30\x12#\n\x18leaderboard_display_type\x18\x05 \x01(\x05:\x01\x30\x12\x18\n\x10leaderboard_name\x18\x06 \x01(\t\"\x9f\x01\n\x19\x43MsgClientLBSGetLBEntries\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\x05\x12\x16\n\x0eleaderboard_id\x18\x02 \x01(\x05\x12\x13\n\x0brange_start\x18\x03 \x01(\x05\x12\x11\n\trange_end\x18\x04 \x01(\x05\x12 \n\x18leaderboard_data_request\x18\x05 \x01(\x05\x12\x10\n\x08steamids\x18\x06 \x03(\x06\"\xf8\x01\n!CMsgClientLBSGetLBEntriesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x1f\n\x17leaderboard_entry_count\x18\x02 \x01(\x05\x12\x39\n\x07\x65ntries\x18\x03 \x03(\x0b\x32(.CMsgClientLBSGetLBEntriesResponse.Entry\x1a\x63\n\x05\x45ntry\x12\x15\n\rsteam_id_user\x18\x01 \x01(\x06\x12\x13\n\x0bglobal_rank\x18\x02 \x01(\x05\x12\r\n\x05score\x18\x03 \x01(\x05\x12\x0f\n\x07\x64\x65tails\x18\x04 \x01(\x0c\x12\x0e\n\x06ugc_id\x18\x05 \x01(\x06\"\xbf\x01\n\x1e\x43MsgClientAppMinutesPlayedData\x12L\n\x0eminutes_played\x18\x01 \x03(\x0b\x32\x34.CMsgClientAppMinutesPlayedData.AppMinutesPlayedData\x1aO\n\x14\x41ppMinutesPlayedData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x0f\n\x07\x66orever\x18\x02 \x01(\x05\x12\x16\n\x0elast_two_weeks\x18\x03 \x01(\x05\"\xaa\x01\n\x1a\x43MsgClientIsLimitedAccount\x12\x1b\n\x13\x62is_limited_account\x18\x01 \x01(\x08\x12\x1c\n\x14\x62is_community_banned\x18\x02 \x01(\x08\x12\x1a\n\x12\x62is_locked_account\x18\x03 \x01(\x08\x12\x35\n-bis_limited_account_allowed_to_invite_friends\x18\x04 \x01(\x08\"\xa7\x01\n\x1e\x43MsgClientRequestedClientStats\x12\x42\n\rstats_to_send\x18\x01 \x03(\x0b\x32+.CMsgClientRequestedClientStats.StatsToSend\x1a\x41\n\x0bStatsToSend\x12\x13\n\x0b\x63lient_stat\x18\x01 \x01(\r\x12\x1d\n\x15stat_aggregate_method\x18\x02 \x01(\r\"\xc0\x01\n\x0f\x43MsgClientStat2\x12\x30\n\x0bstat_detail\x18\x01 \x03(\x0b\x32\x1b.CMsgClientStat2.StatDetail\x1a{\n\nStatDetail\x12\x13\n\x0b\x63lient_stat\x18\x01 \x01(\r\x12\x10\n\x08ll_value\x18\x02 \x01(\x03\x12\x13\n\x0btime_of_day\x18\x03 \x01(\r\x12\x0f\n\x07\x63\x65ll_id\x18\x04 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x05 \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x06 \x01(\r\"\x98\x01\n\'CMsgClientMMSSetRatelimitPolicyOnClient\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x1a\n\x12\x65nable_rate_limits\x18\x02 \x01(\x08\x12\x1b\n\x13seconds_per_message\x18\x03 \x01(\x05\x12$\n\x1cmilliseconds_per_data_update\x18\x04 \x01(\x05\"\xe8\x01\n\x18\x43MsgClientMMSCreateLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0bmax_members\x18\x02 \x01(\x05\x12\x12\n\nlobby_type\x18\x03 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x04 \x01(\x05\x12\x0f\n\x07\x63\x65ll_id\x18\x05 \x01(\r\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x06 \x01(\r\x12\x10\n\x08metadata\x18\x07 \x01(\x0c\x12\x1a\n\x12persona_name_owner\x18\x08 \x01(\t\x12!\n\tpublic_ip\x18\t \x01(\x0b\x32\x0e.CMsgIPAddress\"^\n CMsgClientMMSCreateLobbyResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"V\n\x16\x43MsgClientMMSJoinLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x03 \x01(\t\"\xcf\x02\n\x1e\x43MsgClientMMSJoinLobbyResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12 \n\x18\x63hat_room_enter_response\x18\x03 \x01(\x05\x12\x13\n\x0bmax_members\x18\x04 \x01(\x05\x12\x12\n\nlobby_type\x18\x05 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x06 \x01(\x05\x12\x16\n\x0esteam_id_owner\x18\x07 \x01(\x06\x12\x10\n\x08metadata\x18\x08 \x01(\x0c\x12\x37\n\x07members\x18\t \x03(\x0b\x32&.CMsgClientMMSJoinLobbyResponse.Member\x1a\x42\n\x06Member\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\"A\n\x17\x43MsgClientMMSLeaveLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\"]\n\x1f\x43MsgClientMMSLeaveLobbyResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"\xa0\x02\n\x19\x43MsgClientMMSGetLobbyList\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x1d\n\x15num_lobbies_requested\x18\x03 \x01(\x05\x12\x0f\n\x07\x63\x65ll_id\x18\x04 \x01(\r\x12\x1c\n\x14\x64\x65precated_public_ip\x18\x05 \x01(\r\x12\x32\n\x07\x66ilters\x18\x06 \x03(\x0b\x32!.CMsgClientMMSGetLobbyList.Filter\x12!\n\tpublic_ip\x18\x07 \x01(\x0b\x32\x0e.CMsgIPAddress\x1aN\n\x06\x46ilter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x13\n\x0b\x63omparision\x18\x03 \x01(\x05\x12\x13\n\x0b\x66ilter_type\x18\x04 \x01(\x05\"\xa5\x02\n!CMsgClientMMSGetLobbyListResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\x12\x39\n\x07lobbies\x18\x04 \x03(\x0b\x32(.CMsgClientMMSGetLobbyListResponse.Lobby\x1a\xa0\x01\n\x05Lobby\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x13\n\x0bmax_members\x18\x02 \x01(\x05\x12\x12\n\nlobby_type\x18\x03 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x04 \x01(\x05\x12\x10\n\x08metadata\x18\x05 \x01(\x0c\x12\x13\n\x0bnum_members\x18\x06 \x01(\x05\x12\x10\n\x08\x64istance\x18\x07 \x01(\x02\x12\x0e\n\x06weight\x18\x08 \x01(\x03\"\xac\x01\n\x19\x43MsgClientMMSSetLobbyData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_member\x18\x03 \x01(\x06\x12\x13\n\x0bmax_members\x18\x04 \x01(\x05\x12\x12\n\nlobby_type\x18\x05 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x06 \x01(\x05\x12\x10\n\x08metadata\x18\x07 \x01(\x0c\"_\n!CMsgClientMMSSetLobbyDataResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"C\n\x19\x43MsgClientMMSGetLobbyData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\"\xed\x02\n\x16\x43MsgClientMMSLobbyData\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x13\n\x0bnum_members\x18\x03 \x01(\x05\x12\x13\n\x0bmax_members\x18\x04 \x01(\x05\x12\x12\n\nlobby_type\x18\x05 \x01(\x05\x12\x13\n\x0blobby_flags\x18\x06 \x01(\x05\x12\x16\n\x0esteam_id_owner\x18\x07 \x01(\x06\x12\x10\n\x08metadata\x18\x08 \x01(\x0c\x12/\n\x07members\x18\t \x03(\x0b\x32\x1e.CMsgClientMMSLobbyData.Member\x12\x14\n\x0clobby_cellid\x18\n \x01(\r\x12#\n\x1bowner_should_accept_changes\x18\x0b \x01(\x08\x1a\x42\n\x06Member\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\"w\n\x1d\x43MsgClientMMSSendLobbyChatMsg\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_target\x18\x03 \x01(\x06\x12\x15\n\rlobby_message\x18\x04 \x01(\x0c\"s\n\x19\x43MsgClientMMSLobbyChatMsg\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_sender\x18\x03 \x01(\x06\x12\x15\n\rlobby_message\x18\x04 \x01(\x0c\"`\n\x1a\x43MsgClientMMSSetLobbyOwner\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x1a\n\x12steam_id_new_owner\x18\x03 \x01(\x06\"`\n\"CMsgClientMMSSetLobbyOwnerResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x12\n\x07\x65result\x18\x03 \x01(\x05:\x01\x32\"^\n\x1b\x43MsgClientMMSSetLobbyLinked\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_lobby2\x18\x03 \x01(\x06\"\xcc\x01\n\x1f\x43MsgClientMMSSetLobbyGameServer\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12!\n\x19\x64\x65precated_game_server_ip\x18\x03 \x01(\r\x12\x18\n\x10game_server_port\x18\x04 \x01(\r\x12\x1c\n\x14game_server_steam_id\x18\x05 \x01(\x06\x12&\n\x0egame_server_ip\x18\x06 \x01(\x0b\x32\x0e.CMsgIPAddress\"\xcc\x01\n\x1f\x43MsgClientMMSLobbyGameServerSet\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12!\n\x19\x64\x65precated_game_server_ip\x18\x03 \x01(\r\x12\x18\n\x10game_server_port\x18\x04 \x01(\r\x12\x1c\n\x14game_server_steam_id\x18\x05 \x01(\x06\x12&\n\x0egame_server_ip\x18\x06 \x01(\x0b\x32\x0e.CMsgIPAddress\"s\n\x1c\x43MsgClientMMSUserJoinedLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x15\n\rsteam_id_user\x18\x03 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x04 \x01(\t\"q\n\x1a\x43MsgClientMMSUserLeftLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x15\n\rsteam_id_user\x18\x03 \x01(\x06\x12\x14\n\x0cpersona_name\x18\x04 \x01(\t\"c\n\x1a\x43MsgClientMMSInviteToLobby\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x1d\n\x15steam_id_user_invited\x18\x03 \x01(\x06\"x\n\x1b\x43MsgClientMMSGetLobbyStatus\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12\x18\n\x10\x63laim_membership\x18\x03 \x01(\x08\x12\x17\n\x0f\x63laim_ownership\x18\x04 \x01(\x08\"\x8f\x01\n#CMsgClientMMSGetLobbyStatusResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0esteam_id_lobby\x18\x02 \x01(\x06\x12@\n\x0clobby_status\x18\x03 \x01(\x0e\x32\x10.EMMSLobbyStatus:\x18k_EMMSLobbyStatusInvalid\"r\n\x16\x43MsgClientInviteToGame\x12\x15\n\rsteam_id_dest\x18\x01 \x01(\x06\x12\x14\n\x0csteam_id_src\x18\x02 \x01(\x06\x12\x16\n\x0e\x63onnect_string\x18\x03 \x01(\t\x12\x13\n\x0bremote_play\x18\x04 \x01(\t\"\xb9\x01\n\x14\x43MsgClientChatInvite\x12\x18\n\x10steam_id_invited\x18\x01 \x01(\x06\x12\x15\n\rsteam_id_chat\x18\x02 \x01(\x06\x12\x17\n\x0fsteam_id_patron\x18\x03 \x01(\x06\x12\x15\n\rchatroom_type\x18\x04 \x01(\x05\x12\x1c\n\x14steam_id_friend_chat\x18\x05 \x01(\x06\x12\x11\n\tchat_name\x18\x06 \x01(\t\x12\x0f\n\x07game_id\x18\x07 \x01(\x06\"\x8a\x08\n\x19\x43MsgClientConnectionStats\x12;\n\x0bstats_logon\x18\x01 \x01(\x0b\x32&.CMsgClientConnectionStats.Stats_Logon\x12;\n\x0bstats_vconn\x18\x02 \x01(\x0b\x32&.CMsgClientConnectionStats.Stats_VConn\x1a\xc7\x01\n\x0bStats_Logon\x12\x18\n\x10\x63onnect_attempts\x18\x01 \x01(\x05\x12\x19\n\x11\x63onnect_successes\x18\x02 \x01(\x05\x12\x18\n\x10\x63onnect_failures\x18\x03 \x01(\x05\x12\x1b\n\x13\x63onnections_dropped\x18\x04 \x01(\x05\x12\x17\n\x0fseconds_running\x18\x05 \x01(\r\x12\x1c\n\x14msec_tologonthistime\x18\x06 \x01(\r\x12\x15\n\rcount_bad_cms\x18\x07 \x01(\r\x1aq\n\tStats_UDP\x12\x11\n\tpkts_sent\x18\x01 \x01(\x04\x12\x12\n\nbytes_sent\x18\x02 \x01(\x04\x12\x11\n\tpkts_recv\x18\x03 \x01(\x04\x12\x16\n\x0epkts_processed\x18\x04 \x01(\x04\x12\x12\n\nbytes_recv\x18\x05 \x01(\x04\x1a\xb5\x04\n\x0bStats_VConn\x12\x17\n\x0f\x63onnections_udp\x18\x01 \x01(\r\x12\x17\n\x0f\x63onnections_tcp\x18\x02 \x01(\r\x12\x37\n\tstats_udp\x18\x03 \x01(\x0b\x32$.CMsgClientConnectionStats.Stats_UDP\x12\x16\n\x0epkts_abandoned\x18\x04 \x01(\x04\x12\x19\n\x11\x63onn_req_received\x18\x05 \x01(\x04\x12\x13\n\x0bpkts_resent\x18\x06 \x01(\x04\x12\x11\n\tmsgs_sent\x18\x07 \x01(\x04\x12\x18\n\x10msgs_sent_failed\x18\x08 \x01(\x04\x12\x11\n\tmsgs_recv\x18\t \x01(\x04\x12\x16\n\x0e\x64\x61tagrams_sent\x18\n \x01(\x04\x12\x16\n\x0e\x64\x61tagrams_recv\x18\x0b \x01(\x04\x12\x15\n\rbad_pkts_recv\x18\x0c \x01(\x04\x12\x1e\n\x16unknown_conn_pkts_recv\x18\r \x01(\x04\x12\x18\n\x10missed_pkts_recv\x18\x0e \x01(\x04\x12\x15\n\rdup_pkts_recv\x18\x0f \x01(\x04\x12!\n\x19\x66\x61iled_connect_challenges\x18\x10 \x01(\x04\x12\x1d\n\x15micro_sec_avg_latency\x18\x11 \x01(\r\x12\x1d\n\x15micro_sec_min_latency\x18\x12 \x01(\r\x12\x1d\n\x15micro_sec_max_latency\x18\x13 \x01(\r\x12\x1b\n\x13mem_pool_msg_in_use\x18\x14 \x01(\r\"\xd2\x01\n\x1a\x43MsgClientServersAvailable\x12R\n\x16server_types_available\x18\x01 \x03(\x0b\x32\x32.CMsgClientServersAvailable.Server_Types_Available\x12%\n\x1dserver_type_for_auth_services\x18\x02 \x01(\r\x1a\x39\n\x16Server_Types_Available\x12\x0e\n\x06server\x18\x01 \x01(\r\x12\x0f\n\x07\x63hanged\x18\x02 \x01(\x08\"u\n\x16\x43MsgClientGetUserStats\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x11\n\tcrc_stats\x18\x02 \x01(\r\x12\x1c\n\x14schema_local_version\x18\x03 \x01(\x05\x12\x19\n\x11steam_id_for_user\x18\x04 \x01(\x06\"\xdf\x02\n\x1e\x43MsgClientGetUserStatsResponse\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x12\n\x07\x65result\x18\x02 \x01(\x05:\x01\x32\x12\x11\n\tcrc_stats\x18\x03 \x01(\r\x12\x0e\n\x06schema\x18\x04 \x01(\x0c\x12\x34\n\x05stats\x18\x05 \x03(\x0b\x32%.CMsgClientGetUserStatsResponse.Stats\x12N\n\x12\x61\x63hievement_blocks\x18\x06 \x03(\x0b\x32\x32.CMsgClientGetUserStatsResponse.Achievement_Blocks\x1a,\n\x05Stats\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\r\x1a\x41\n\x12\x41\x63hievement_Blocks\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\r\x12\x13\n\x0bunlock_time\x18\x02 \x03(\x07\"\x9a\x02\n CMsgClientStoreUserStatsResponse\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x12\n\x07\x65result\x18\x02 \x01(\x05:\x01\x32\x12\x11\n\tcrc_stats\x18\x03 \x01(\r\x12Z\n\x17stats_failed_validation\x18\x04 \x03(\x0b\x32\x39.CMsgClientStoreUserStatsResponse.Stats_Failed_Validation\x12\x19\n\x11stats_out_of_date\x18\x05 \x01(\x08\x1aG\n\x17Stats_Failed_Validation\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x1b\n\x13reverted_stat_value\x18\x02 \x01(\r\"\xe8\x01\n\x19\x43MsgClientStoreUserStats2\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x17\n\x0fsettor_steam_id\x18\x02 \x01(\x06\x12\x17\n\x0fsettee_steam_id\x18\x03 \x01(\x06\x12\x11\n\tcrc_stats\x18\x04 \x01(\r\x12\x16\n\x0e\x65xplicit_reset\x18\x05 \x01(\x08\x12/\n\x05stats\x18\x06 \x03(\x0b\x32 .CMsgClientStoreUserStats2.Stats\x1a,\n\x05Stats\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\r\"\xc2\x01\n\x16\x43MsgClientStatsUpdated\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x0f\n\x07game_id\x18\x02 \x01(\x06\x12\x11\n\tcrc_stats\x18\x03 \x01(\r\x12<\n\rupdated_stats\x18\x04 \x03(\x0b\x32%.CMsgClientStatsUpdated.Updated_Stats\x1a\x34\n\rUpdated_Stats\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\r\"\xbc\x01\n\x18\x43MsgClientStoreUserStats\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x65xplicit_reset\x18\x02 \x01(\x08\x12@\n\x0estats_to_store\x18\x03 \x03(\x0b\x32(.CMsgClientStoreUserStats.Stats_To_Store\x1a\x35\n\x0eStats_To_Store\x12\x0f\n\x07stat_id\x18\x01 \x01(\r\x12\x12\n\nstat_value\x18\x02 \x01(\r\"\x1c\n\x1a\x43MsgClientGetClientDetails\"?\n$CMsgClientReportOverlayDetourFailure\x12\x17\n\x0f\x66\x61ilure_strings\x18\x01 \x03(\t\"\xbf\x02\n\"CMsgClientGetClientDetailsResponse\x12\x17\n\x0fpackage_version\x18\x01 \x01(\r\x12\x18\n\x10protocol_version\x18\x08 \x01(\r\x12\n\n\x02os\x18\x02 \x01(\t\x12\x14\n\x0cmachine_name\x18\x03 \x01(\t\x12\x11\n\tip_public\x18\x04 \x01(\t\x12\x12\n\nip_private\x18\x05 \x01(\t\x12\x17\n\x0f\x62ytes_available\x18\x07 \x01(\x04\x12?\n\rgames_running\x18\x06 \x03(\x0b\x32(.CMsgClientGetClientDetailsResponse.Game\x1a\x43\n\x04Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nextra_info\x18\x02 \x01(\t\x12\x18\n\x10time_running_sec\x18\x03 \x01(\r\"\x88\x01\n\x1a\x43MsgClientGetClientAppList\x12\r\n\x05media\x18\x01 \x01(\x08\x12\r\n\x05tools\x18\x02 \x01(\x08\x12\r\n\x05games\x18\x03 \x01(\x08\x12\x16\n\x0eonly_installed\x18\x04 \x01(\x08\x12\x15\n\ronly_changing\x18\x05 \x01(\x08\x12\x0e\n\x06\x63omics\x18\x06 \x01(\x08\"\x91\x04\n\"CMsgClientGetClientAppListResponse\x12\x35\n\x04\x61pps\x18\x01 \x03(\x0b\x32\'.CMsgClientGetClientAppListResponse.App\x12\x17\n\x0f\x62ytes_available\x18\x02 \x01(\x04\x1a\x9a\x03\n\x03\x41pp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x10\n\x08\x61pp_type\x18\n \x01(\t\x12\x10\n\x08\x66\x61vorite\x18\x03 \x01(\x08\x12\x11\n\tinstalled\x18\x04 \x01(\x08\x12\x13\n\x0b\x61uto_update\x18\x05 \x01(\x08\x12\x18\n\x10\x62ytes_downloaded\x18\x06 \x01(\x04\x12\x14\n\x0c\x62ytes_needed\x18\x07 \x01(\x04\x12\x1b\n\x13\x62ytes_download_rate\x18\x08 \x01(\r\x12\x17\n\x0f\x64ownload_paused\x18\x0b \x01(\x08\x12\x17\n\x0fnum_downloading\x18\x0c \x01(\r\x12\x12\n\nnum_paused\x18\r \x01(\r\x12\x10\n\x08\x63hanging\x18\x0e \x01(\x08\x12\x1d\n\x15\x61vailable_on_platform\x18\x0f \x01(\x08\x12\x39\n\x04\x64lcs\x18\t \x03(\x0b\x32+.CMsgClientGetClientAppListResponse.App.DLC\x1a\'\n\x03\x44LC\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tinstalled\x18\x02 \x01(\x08\"+\n\x1a\x43MsgClientInstallClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"4\n\"CMsgClientInstallClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"-\n\x1c\x43MsgClientUninstallClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"6\n$CMsgClientUninstallClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"B\n!CMsgClientSetClientAppUpdateState\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06update\x18\x02 \x01(\x08\";\n)CMsgClientSetClientAppUpdateStateResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"\x86\x02\n\x1e\x43MsgClientUFSUploadFileRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_size\x18\x02 \x01(\r\x12\x15\n\rraw_file_size\x18\x03 \x01(\r\x12\x10\n\x08sha_file\x18\x04 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x05 \x01(\x04\x12\x11\n\tfile_name\x18\x06 \x01(\t\x12$\n\x1cplatforms_to_sync_deprecated\x18\x07 \x01(\r\x12%\n\x11platforms_to_sync\x18\x08 \x01(\r:\n4294967295\x12\x0f\n\x07\x63\x65ll_id\x18\t \x01(\r\x12\x13\n\x0b\x63\x61n_encrypt\x18\n \x01(\x08\"\xbb\x01\n\x1f\x43MsgClientUFSUploadFileResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x10\n\x08sha_file\x18\x02 \x01(\x0c\x12\x10\n\x08use_http\x18\x03 \x01(\x08\x12\x11\n\thttp_host\x18\x04 \x01(\t\x12\x10\n\x08http_url\x18\x05 \x01(\t\x12\x12\n\nkv_headers\x18\x06 \x01(\x0c\x12\x11\n\tuse_https\x18\x07 \x01(\x08\x12\x14\n\x0c\x65ncrypt_file\x18\x08 \x01(\x08\"\xae\x01\n\x19\x43MsgClientUFSUploadCommit\x12.\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1f.CMsgClientUFSUploadCommit.File\x1a\x61\n\x04\x46ile\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x10\n\x08sha_file\x18\x03 \x01(\x0c\x12\x10\n\x08\x63ub_file\x18\x04 \x01(\r\x12\x11\n\tfile_name\x18\x05 \x01(\t\"\x99\x01\n!CMsgClientUFSUploadCommitResponse\x12\x36\n\x05\x66iles\x18\x01 \x03(\x0b\x32\'.CMsgClientUFSUploadCommitResponse.File\x1a<\n\x04\x46ile\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x10\n\x08sha_file\x18\x03 \x01(\x0c\"L\n\x16\x43MsgClientUFSFileChunk\x12\x10\n\x08sha_file\x18\x01 \x01(\x0c\x12\x12\n\nfile_start\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\" \n\x1e\x43MsgClientUFSTransferHeartbeat\"G\n\x1f\x43MsgClientUFSUploadFileFinished\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x10\n\x08sha_file\x18\x02 \x01(\x0c\"_\n\x1e\x43MsgClientUFSDeleteFileRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x1a\n\x12is_explicit_delete\x18\x03 \x01(\x08\"H\n\x1f\x43MsgClientUFSDeleteFileResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x11\n\tfile_name\x18\x02 \x01(\t\"S\n\x1e\x43MsgClientUFSGetFileListForApp\x12\x15\n\rapps_to_query\x18\x01 \x03(\r\x12\x1a\n\x12send_path_prefixes\x18\x02 \x01(\x08\"\xc1\x02\n&CMsgClientUFSGetFileListForAppResponse\x12;\n\x05\x66iles\x18\x01 \x03(\x0b\x32,.CMsgClientUFSGetFileListForAppResponse.File\x12\x15\n\rpath_prefixes\x18\x02 \x03(\t\x1a\xb8\x01\n\x04\x46ile\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x10\n\x08sha_file\x18\x03 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x04 \x01(\x04\x12\x15\n\rraw_file_size\x18\x05 \x01(\r\x12\x1a\n\x12is_explicit_delete\x18\x06 \x01(\x08\x12\x19\n\x11platforms_to_sync\x18\x07 \x01(\r\x12\x19\n\x11path_prefix_index\x18\x08 \x01(\r:\x08\x80\xb5\x18\x08\x88\xb5\x18\x10\"Z\n\x1c\x43MsgClientUFSDownloadRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x61n_handle_http\x18\x03 \x01(\x08\"\xa0\x02\n\x1d\x43MsgClientUFSDownloadResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x11\n\tfile_size\x18\x03 \x01(\r\x12\x15\n\rraw_file_size\x18\x04 \x01(\r\x12\x10\n\x08sha_file\x18\x05 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x06 \x01(\x04\x12\x1a\n\x12is_explicit_delete\x18\x07 \x01(\x08\x12\x10\n\x08use_http\x18\x08 \x01(\x08\x12\x11\n\thttp_host\x18\t \x01(\t\x12\x10\n\x08http_url\x18\n \x01(\t\x12\x12\n\nkv_headers\x18\x0b \x01(\x0c\x12\x11\n\tuse_https\x18\x0c \x01(\x08\x12\x11\n\tencrypted\x18\r \x01(\x08\"]\n\x19\x43MsgClientUFSLoginRequest\x12\x18\n\x10protocol_version\x18\x01 \x01(\r\x12\x18\n\x10\x61m_session_token\x18\x02 \x01(\x04\x12\x0c\n\x04\x61pps\x18\x03 \x03(\r\"0\n\x1a\x43MsgClientUFSLoginResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"G\n#CMsgClientRequestEncryptedAppTicket\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x10\n\x08userdata\x18\x02 \x01(\x0c\"\x84\x01\n+CMsgClientRequestEncryptedAppTicketResponse\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x12\n\x07\x65result\x18\x02 \x01(\x05:\x01\x32\x12\x31\n\x14\x65ncrypted_app_ticket\x18\x03 \x01(\x0b\x32\x13.EncryptedAppTicket\"\xa6\x01\n\x1a\x43MsgClientWalletInfoUpdate\x12\x12\n\nhas_wallet\x18\x01 \x01(\x08\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x03 \x01(\x05\x12\x17\n\x0f\x62\x61lance_delayed\x18\x04 \x01(\x05\x12\x17\n\tbalance64\x18\x05 \x01(\x03\x42\x04\xa0\xb6\x18\x01\x12\x1f\n\x11\x62\x61lance64_delayed\x18\x06 \x01(\x03\x42\x04\xa0\xb6\x18\x01\"M\n\x17\x43MsgClientAppInfoUpdate\x12\x19\n\x11last_changenumber\x18\x01 \x01(\r\x12\x17\n\x0fsend_changelist\x18\x02 \x01(\x08\"d\n\x18\x43MsgClientAppInfoChanges\x12\x1d\n\x15\x63urrent_change_number\x18\x01 \x01(\r\x12\x19\n\x11\x66orce_full_update\x18\x02 \x01(\x08\x12\x0e\n\x06\x61ppIDs\x18\x03 \x03(\r\"\xab\x01\n\x18\x43MsgClientAppInfoRequest\x12+\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x1d.CMsgClientAppInfoRequest.App\x12\x1f\n\x10supports_batches\x18\x02 \x01(\x08:\x05\x66\x61lse\x1a\x41\n\x03\x41pp\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x15\n\rsection_flags\x18\x02 \x01(\r\x12\x13\n\x0bsection_CRC\x18\x03 \x03(\r\"\x97\x02\n\x19\x43MsgClientAppInfoResponse\x12,\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x1e.CMsgClientAppInfoResponse.App\x12\x14\n\x0c\x61pps_unknown\x18\x02 \x03(\r\x12\x14\n\x0c\x61pps_pending\x18\x03 \x01(\r\x1a\x99\x01\n\x03\x41pp\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x15\n\rchange_number\x18\x02 \x01(\r\x12\x38\n\x08sections\x18\x03 \x03(\x0b\x32&.CMsgClientAppInfoResponse.App.Section\x1a\x31\n\x07Section\x12\x12\n\nsection_id\x18\x01 \x01(\r\x12\x12\n\nsection_kv\x18\x02 \x01(\x0c:\x04\x88\xb5\x18\x00\"K\n\x1c\x43MsgClientPackageInfoRequest\x12\x13\n\x0bpackage_ids\x18\x01 \x03(\r\x12\x16\n\x0emeta_data_only\x18\x02 \x01(\x08\"\xe0\x01\n\x1d\x43MsgClientPackageInfoResponse\x12\x38\n\x08packages\x18\x01 \x03(\x0b\x32&.CMsgClientPackageInfoResponse.Package\x12\x18\n\x10packages_unknown\x18\x02 \x03(\r\x12\x18\n\x10packages_pending\x18\x03 \x01(\r\x1aQ\n\x07Package\x12\x12\n\npackage_id\x18\x01 \x01(\r\x12\x15\n\rchange_number\x18\x02 \x01(\r\x12\x0b\n\x03sha\x18\x03 \x01(\x0c\x12\x0e\n\x06\x62uffer\x18\x04 \x01(\x0c\"\xc0\x01\n!CMsgClientPICSChangesSinceRequest\x12\x1b\n\x13since_change_number\x18\x01 \x01(\r\x12\x1d\n\x15send_app_info_changes\x18\x02 \x01(\x08\x12!\n\x19send_package_info_changes\x18\x03 \x01(\x08\x12\x1b\n\x13num_app_info_cached\x18\x04 \x01(\r\x12\x1f\n\x17num_package_info_cached\x18\x05 \x01(\r\"\xe5\x03\n\"CMsgClientPICSChangesSinceResponse\x12\x1d\n\x15\x63urrent_change_number\x18\x01 \x01(\r\x12\x1b\n\x13since_change_number\x18\x02 \x01(\r\x12\x19\n\x11\x66orce_full_update\x18\x03 \x01(\x08\x12J\n\x0fpackage_changes\x18\x04 \x03(\x0b\x32\x31.CMsgClientPICSChangesSinceResponse.PackageChange\x12\x42\n\x0b\x61pp_changes\x18\x05 \x03(\x0b\x32-.CMsgClientPICSChangesSinceResponse.AppChange\x12\x1d\n\x15\x66orce_full_app_update\x18\x06 \x01(\x08\x12!\n\x19\x66orce_full_package_update\x18\x07 \x01(\x08\x1aN\n\rPackageChange\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x15\n\rchange_number\x18\x02 \x01(\r\x12\x13\n\x0bneeds_token\x18\x03 \x01(\x08\x1a\x46\n\tAppChange\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x15\n\rchange_number\x18\x02 \x01(\r\x12\x13\n\x0bneeds_token\x18\x03 \x01(\x08\"\xeb\x02\n CMsgClientPICSProductInfoRequest\x12?\n\x08packages\x18\x01 \x03(\x0b\x32-.CMsgClientPICSProductInfoRequest.PackageInfo\x12\x37\n\x04\x61pps\x18\x02 \x03(\x0b\x32).CMsgClientPICSProductInfoRequest.AppInfo\x12\x16\n\x0emeta_data_only\x18\x03 \x01(\x08\x12\x17\n\x0fnum_prev_failed\x18\x04 \x01(\r\x12\x1f\n\x17supports_package_tokens\x18\x05 \x01(\r\x1a\x43\n\x07\x41ppInfo\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\x04\x12\x13\n\x0bonly_public\x18\x03 \x01(\x08\x1a\x36\n\x0bPackageInfo\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\x04\"\xb9\x04\n!CMsgClientPICSProductInfoResponse\x12\x38\n\x04\x61pps\x18\x01 \x03(\x0b\x32*.CMsgClientPICSProductInfoResponse.AppInfo\x12\x16\n\x0eunknown_appids\x18\x02 \x03(\r\x12@\n\x08packages\x18\x03 \x03(\x0b\x32..CMsgClientPICSProductInfoResponse.PackageInfo\x12\x1a\n\x12unknown_packageids\x18\x04 \x03(\r\x12\x16\n\x0emeta_data_only\x18\x05 \x01(\x08\x12\x18\n\x10response_pending\x18\x06 \x01(\x08\x12\x15\n\rhttp_min_size\x18\x07 \x01(\r\x12\x11\n\thttp_host\x18\x08 \x01(\t\x1a\x86\x01\n\x07\x41ppInfo\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x15\n\rchange_number\x18\x02 \x01(\r\x12\x15\n\rmissing_token\x18\x03 \x01(\x08\x12\x0b\n\x03sha\x18\x04 \x01(\x0c\x12\x0e\n\x06\x62uffer\x18\x05 \x01(\x0c\x12\x13\n\x0bonly_public\x18\x06 \x01(\x08\x12\x0c\n\x04size\x18\x07 \x01(\r\x1ay\n\x0bPackageInfo\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x15\n\rchange_number\x18\x02 \x01(\r\x12\x15\n\rmissing_token\x18\x03 \x01(\x08\x12\x0b\n\x03sha\x18\x04 \x01(\x0c\x12\x0e\n\x06\x62uffer\x18\x05 \x01(\x0c\x12\x0c\n\x04size\x18\x06 \x01(\r:\x04\x88\xb5\x18\x00\"F\n CMsgClientPICSAccessTokenRequest\x12\x12\n\npackageids\x18\x01 \x03(\r\x12\x0e\n\x06\x61ppids\x18\x02 \x03(\r\"\xdf\x02\n!CMsgClientPICSAccessTokenResponse\x12N\n\x15package_access_tokens\x18\x01 \x03(\x0b\x32/.CMsgClientPICSAccessTokenResponse.PackageToken\x12\x1d\n\x15package_denied_tokens\x18\x02 \x03(\r\x12\x46\n\x11\x61pp_access_tokens\x18\x03 \x03(\x0b\x32+.CMsgClientPICSAccessTokenResponse.AppToken\x12\x19\n\x11\x61pp_denied_tokens\x18\x04 \x03(\r\x1a\x37\n\x0cPackageToken\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\x04\x1a/\n\x08\x41ppToken\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\x04\"D\n\x1a\x43MsgClientUFSGetUGCDetails\x12&\n\x08hcontent\x18\x01 \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\"\xe5\x01\n\"CMsgClientUFSGetUGCDetailsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x17\n\x0fsteamid_creator\x18\x05 \x01(\x06\x12\x11\n\tfile_size\x18\x06 \x01(\r\x12\x1c\n\x14\x63ompressed_file_size\x18\x07 \x01(\r\x12\x17\n\x0frangecheck_host\x18\x08 \x01(\t\x12\x19\n\x11\x66ile_encoded_sha1\x18\t \x01(\t\"C\n\x1e\x43MsgClientUFSGetSingleFileInfo\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\"\xb8\x01\n&CMsgClientUFSGetSingleFileInfoResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x11\n\tfile_name\x18\x03 \x01(\t\x12\x10\n\x08sha_file\x18\x04 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x05 \x01(\x04\x12\x15\n\rraw_file_size\x18\x06 \x01(\r\x12\x1a\n\x12is_explicit_delete\x18\x07 \x01(\x08\";\n\x16\x43MsgClientUFSShareFile\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\"\\\n\x1e\x43MsgClientUFSShareFileResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12&\n\x08hcontent\x18\x02 \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\"3\n\x1b\x43MsgClientAMGetClanOfficers\x12\x14\n\x0csteamid_clan\x18\x01 \x01(\x06\"f\n#CMsgClientAMGetClanOfficersResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x14\n\x0csteamid_clan\x18\x02 \x01(\x06\x12\x15\n\rofficer_count\x18\x03 \x01(\x05\"\x90\x01\n!CMsgClientAMGetPersonaNameHistory\x12\x10\n\x08id_count\x18\x01 \x01(\x05\x12:\n\x03Ids\x18\x02 \x03(\x0b\x32-.CMsgClientAMGetPersonaNameHistory.IdInstance\x1a\x1d\n\nIdInstance\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\xc3\x02\n)CMsgClientAMGetPersonaNameHistoryResponse\x12O\n\tresponses\x18\x02 \x03(\x0b\x32<.CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance\x1a\xc4\x01\n\x11NameTableInstance\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12X\n\x05names\x18\x03 \x03(\x0b\x32I.CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance\x1a\x30\n\x0cNameInstance\x12\x12\n\nname_since\x18\x01 \x01(\x07\x12\x0c\n\x04name\x18\x02 \x01(\t\"E\n\x1e\x43MsgClientDeregisterWithServer\x12\x13\n\x0b\x65servertype\x18\x01 \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\"\xab\x04\n\x13\x43MsgClientClanState\x12\x14\n\x0csteamid_clan\x18\x01 \x01(\x06\x12\x1a\n\x12\x63lan_account_flags\x18\x03 \x01(\r\x12\x30\n\tname_info\x18\x04 \x01(\x0b\x32\x1d.CMsgClientClanState.NameInfo\x12\x34\n\x0buser_counts\x18\x05 \x01(\x0b\x32\x1f.CMsgClientClanState.UserCounts\x12*\n\x06\x65vents\x18\x06 \x03(\x0b\x32\x1a.CMsgClientClanState.Event\x12\x31\n\rannouncements\x18\x07 \x03(\x0b\x32\x1a.CMsgClientClanState.Event\x12\x19\n\x11\x63hat_room_private\x18\x08 \x01(\x08\x1a\x31\n\x08NameInfo\x12\x11\n\tclan_name\x18\x01 \x01(\t\x12\x12\n\nsha_avatar\x18\x02 \x01(\x0c\x1ak\n\nUserCounts\x12\x0f\n\x07members\x18\x01 \x01(\r\x12\x0e\n\x06online\x18\x02 \x01(\r\x12\x10\n\x08\x63hatting\x18\x03 \x01(\r\x12\x0f\n\x07in_game\x18\x04 \x01(\r\x12\x19\n\x11\x63hat_room_members\x18\x05 \x01(\r\x1a`\n\x05\x45vent\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\x12\n\nevent_time\x18\x02 \x01(\r\x12\x10\n\x08headline\x18\x03 \x01(\t\x12\x0f\n\x07game_id\x18\x04 \x01(\x06\x12\x13\n\x0bjust_posted\x18\x05 \x01(\x08\"\xac\x01\n\x1f\x43MsgClientUnsignedInstallScript\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x11\n\tfile_size\x18\x03 \x01(\r\x12\x18\n\x10signature_broken\x18\x04 \x01(\x08\x12\x10\n\x08\x64\x65pot_id\x18\x05 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x06 \x01(\x04\x12\x12\n\nfile_flags\x18\x07 \x01(\r*\x90\x01\n\x0f\x45MMSLobbyStatus\x12\x1c\n\x18k_EMMSLobbyStatusInvalid\x10\x00\x12\x1b\n\x17k_EMMSLobbyStatusExists\x10\x01\x12!\n\x1dk_EMMSLobbyStatusDoesNotExist\x10\x02\x12\x1f\n\x1bk_EMMSLobbyStatusNotAMember\x10\x03\x42\x05H\x01\x90\x01\x00')
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,encrypted__app__ticket__pb2.DESCRIPTOR,])

_EMMSLOBBYSTATUS = _descriptor.EnumDescriptor(
  name='EMMSLobbyStatus',
  full_name='EMMSLobbyStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMMSLobbyStatusInvalid', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMMSLobbyStatusExists', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMMSLobbyStatusDoesNotExist', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMMSLobbyStatusNotAMember', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21959,
  serialized_end=22103,
)
_sym_db.RegisterEnumDescriptor(_EMMSLOBBYSTATUS)

EMMSLobbyStatus = enum_type_wrapper.EnumTypeWrapper(_EMMSLOBBYSTATUS)
k_EMMSLobbyStatusInvalid = 0
k_EMMSLobbyStatusExists = 1
k_EMMSLobbyStatusDoesNotExist = 2
k_EMMSLobbyStatusNotAMember = 3



_CMSGCLIENTUDSP2PSESSIONSTARTED = _descriptor.Descriptor(
  name='CMsgClientUDSP2PSessionStarted',
  full_name='CMsgClientUDSP2PSessionStarted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_remote', full_name='CMsgClientUDSP2PSessionStarted.steamid_remote', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientUDSP2PSessionStarted.appid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=161,
)


_CMSGCLIENTUDSP2PSESSIONENDED = _descriptor.Descriptor(
  name='CMsgClientUDSP2PSessionEnded',
  full_name='CMsgClientUDSP2PSessionEnded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_remote', full_name='CMsgClientUDSP2PSessionEnded.steamid_remote', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientUDSP2PSessionEnded.appid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_length_sec', full_name='CMsgClientUDSP2PSessionEnded.session_length_sec', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_error', full_name='CMsgClientUDSP2PSessionEnded.session_error', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nattype', full_name='CMsgClientUDSP2PSessionEnded.nattype', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_recv', full_name='CMsgClientUDSP2PSessionEnded.bytes_recv', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_sent', full_name='CMsgClientUDSP2PSessionEnded.bytes_sent', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_sent_relay', full_name='CMsgClientUDSP2PSessionEnded.bytes_sent_relay', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_recv_relay', full_name='CMsgClientUDSP2PSessionEnded.bytes_recv_relay', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_to_connect_ms', full_name='CMsgClientUDSP2PSessionEnded.time_to_connect_ms', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=421,
)


_CMSGCLIENTREGISTERAUTHTICKETWITHCM = _descriptor.Descriptor(
  name='CMsgClientRegisterAuthTicketWithCM',
  full_name='CMsgClientRegisterAuthTicketWithCM',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='CMsgClientRegisterAuthTicketWithCM.protocol_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CMsgClientRegisterAuthTicketWithCM.ticket', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_instance_id', full_name='CMsgClientRegisterAuthTicketWithCM.client_instance_id', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=529,
)


_CMSGCLIENTTICKETAUTHCOMPLETE = _descriptor.Descriptor(
  name='CMsgClientTicketAuthComplete',
  full_name='CMsgClientTicketAuthComplete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgClientTicketAuthComplete.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientTicketAuthComplete.game_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='estate', full_name='CMsgClientTicketAuthComplete.estate', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eauth_session_response', full_name='CMsgClientTicketAuthComplete.eauth_session_response', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='DEPRECATED_ticket', full_name='CMsgClientTicketAuthComplete.DEPRECATED_ticket', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ticket_crc', full_name='CMsgClientTicketAuthComplete.ticket_crc', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ticket_sequence', full_name='CMsgClientTicketAuthComplete.ticket_sequence', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_steam_id', full_name='CMsgClientTicketAuthComplete.owner_steam_id', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=741,
)


_CMSGCLIENTCMLIST = _descriptor.Descriptor(
  name='CMsgClientCMList',
  full_name='CMsgClientCMList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cm_addresses', full_name='CMsgClientCMList.cm_addresses', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cm_ports', full_name='CMsgClientCMList.cm_ports', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cm_websocket_addresses', full_name='CMsgClientCMList.cm_websocket_addresses', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_default_to_websocket', full_name='CMsgClientCMList.percent_default_to_websocket', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=872,
)


_CMSGCLIENTP2PCONNECTIONINFO = _descriptor.Descriptor(
  name='CMsgClientP2PConnectionInfo',
  full_name='CMsgClientP2PConnectionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_dest', full_name='CMsgClientP2PConnectionInfo.steam_id_dest', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_src', full_name='CMsgClientP2PConnectionInfo.steam_id_src', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientP2PConnectionInfo.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='CMsgClientP2PConnectionInfo.candidate', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connection_id_src', full_name='CMsgClientP2PConnectionInfo.connection_id_src', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rendezvous', full_name='CMsgClientP2PConnectionInfo.rendezvous', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=875,
  serialized_end=1031,
)


_CMSGCLIENTP2PCONNECTIONFAILINFO = _descriptor.Descriptor(
  name='CMsgClientP2PConnectionFailInfo',
  full_name='CMsgClientP2PConnectionFailInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_dest', full_name='CMsgClientP2PConnectionFailInfo.steam_id_dest', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_src', full_name='CMsgClientP2PConnectionFailInfo.steam_id_src', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientP2PConnectionFailInfo.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ep2p_session_error', full_name='CMsgClientP2PConnectionFailInfo.ep2p_session_error', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connection_id_dest', full_name='CMsgClientP2PConnectionFailInfo.connection_id_dest', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_reason', full_name='CMsgClientP2PConnectionFailInfo.close_reason', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_message', full_name='CMsgClientP2PConnectionFailInfo.close_message', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1229,
)


_CMSGCLIENTNETWORKINGCERTREQUEST = _descriptor.Descriptor(
  name='CMsgClientNetworkingCertRequest',
  full_name='CMsgClientNetworkingCertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_data', full_name='CMsgClientNetworkingCertRequest.key_data', index=0,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientNetworkingCertRequest.app_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1298,
)


_CMSGCLIENTNETWORKINGCERTREPLY = _descriptor.Descriptor(
  name='CMsgClientNetworkingCertReply',
  full_name='CMsgClientNetworkingCertReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cert', full_name='CMsgClientNetworkingCertReply.cert', index=0,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ca_key_id', full_name='CMsgClientNetworkingCertReply.ca_key_id', index=1,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ca_signature', full_name='CMsgClientNetworkingCertReply.ca_signature', index=2,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1300,
  serialized_end=1386,
)


_CMSGCLIENTNETWORKINGMOBILECERTREQUEST = _descriptor.Descriptor(
  name='CMsgClientNetworkingMobileCertRequest',
  full_name='CMsgClientNetworkingMobileCertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientNetworkingMobileCertRequest.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1388,
  serialized_end=1443,
)


_CMSGCLIENTNETWORKINGMOBILECERTREPLY = _descriptor.Descriptor(
  name='CMsgClientNetworkingMobileCertReply',
  full_name='CMsgClientNetworkingMobileCertReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoded_cert', full_name='CMsgClientNetworkingMobileCertReply.encoded_cert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1445,
  serialized_end=1504,
)


_CMSGCLIENTGETAPPOWNERSHIPTICKET = _descriptor.Descriptor(
  name='CMsgClientGetAppOwnershipTicket',
  full_name='CMsgClientGetAppOwnershipTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientGetAppOwnershipTicket.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1506,
  serialized_end=1555,
)


_CMSGCLIENTGETAPPOWNERSHIPTICKETRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetAppOwnershipTicketResponse',
  full_name='CMsgClientGetAppOwnershipTicketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientGetAppOwnershipTicketResponse.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientGetAppOwnershipTicketResponse.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CMsgClientGetAppOwnershipTicketResponse.ticket', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1650,
)


_CMSGCLIENTSESSIONTOKEN = _descriptor.Descriptor(
  name='CMsgClientSessionToken',
  full_name='CMsgClientSessionToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgClientSessionToken.token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1652,
  serialized_end=1691,
)


_CMSGCLIENTGAMECONNECTTOKENS = _descriptor.Descriptor(
  name='CMsgClientGameConnectTokens',
  full_name='CMsgClientGameConnectTokens',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_tokens_to_keep', full_name='CMsgClientGameConnectTokens.max_tokens_to_keep', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tokens', full_name='CMsgClientGameConnectTokens.tokens', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1693,
  serialized_end=1770,
)


_CMSGGSSERVERTYPE = _descriptor.Descriptor(
  name='CMsgGSServerType',
  full_name='CMsgGSServerType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id_served', full_name='CMsgGSServerType.app_id_served', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CMsgGSServerType.flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_game_ip_address', full_name='CMsgGSServerType.deprecated_game_ip_address', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_port', full_name='CMsgGSServerType.game_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_dir', full_name='CMsgGSServerType.game_dir', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_version', full_name='CMsgGSServerType.game_version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_query_port', full_name='CMsgGSServerType.game_query_port', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1773,
  serialized_end=1949,
)


_CMSGGSSTATUSREPLY = _descriptor.Descriptor(
  name='CMsgGSStatusReply',
  full_name='CMsgGSStatusReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_secure', full_name='CMsgGSStatusReply.is_secure', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1951,
  serialized_end=1989,
)


_CMSGGSPLAYERLIST_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='CMsgGSPlayerList.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSPlayerList.Player.steam_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_public_ip', full_name='CMsgGSPlayerList.Player.deprecated_public_ip', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgGSPlayerList.Player.token', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_ip', full_name='CMsgGSPlayerList.Player.public_ip', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2055,
  serialized_end=2161,
)

_CMSGGSPLAYERLIST = _descriptor.Descriptor(
  name='CMsgGSPlayerList',
  full_name='CMsgGSPlayerList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='players', full_name='CMsgGSPlayerList.players', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGSPLAYERLIST_PLAYER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1992,
  serialized_end=2161,
)


_CMSGGSUSERPLAYING = _descriptor.Descriptor(
  name='CMsgGSUserPlaying',
  full_name='CMsgGSUserPlaying',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSUserPlaying.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_public_ip', full_name='CMsgGSUserPlaying.deprecated_public_ip', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgGSUserPlaying.token', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_ip', full_name='CMsgGSUserPlaying.public_ip', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2163,
  serialized_end=2280,
)


_CMSGGSDISCONNECTNOTICE = _descriptor.Descriptor(
  name='CMsgGSDisconnectNotice',
  full_name='CMsgGSDisconnectNotice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSDisconnectNotice.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2282,
  serialized_end=2324,
)


_CMSGCLIENTGAMESPLAYED_GAMEPLAYED = _descriptor.Descriptor(
  name='GamePlayed',
  full_name='CMsgClientGamesPlayed.GamePlayed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_gs', full_name='CMsgClientGamesPlayed.GamePlayed.steam_id_gs', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientGamesPlayed.GamePlayed.game_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_game_ip_address', full_name='CMsgClientGamesPlayed.GamePlayed.deprecated_game_ip_address', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_port', full_name='CMsgClientGamesPlayed.GamePlayed.game_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_secure', full_name='CMsgClientGamesPlayed.GamePlayed.is_secure', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='CMsgClientGamesPlayed.GamePlayed.token', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_extra_info', full_name='CMsgClientGamesPlayed.GamePlayed.game_extra_info', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_data_blob', full_name='CMsgClientGamesPlayed.GamePlayed.game_data_blob', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_id', full_name='CMsgClientGamesPlayed.GamePlayed.process_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streaming_provider_id', full_name='CMsgClientGamesPlayed.GamePlayed.streaming_provider_id', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_flags', full_name='CMsgClientGamesPlayed.GamePlayed.game_flags', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='CMsgClientGamesPlayed.GamePlayed.owner_id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vr_hmd_vendor', full_name='CMsgClientGamesPlayed.GamePlayed.vr_hmd_vendor', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vr_hmd_model', full_name='CMsgClientGamesPlayed.GamePlayed.vr_hmd_model', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='launch_option_type', full_name='CMsgClientGamesPlayed.GamePlayed.launch_option_type', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primary_controller_type', full_name='CMsgClientGamesPlayed.GamePlayed.primary_controller_type', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primary_steam_controller_serial', full_name='CMsgClientGamesPlayed.GamePlayed.primary_steam_controller_serial', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_steam_controller_count', full_name='CMsgClientGamesPlayed.GamePlayed.total_steam_controller_count', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_non_steam_controller_count', full_name='CMsgClientGamesPlayed.GamePlayed.total_non_steam_controller_count', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controller_workshop_file_id', full_name='CMsgClientGamesPlayed.GamePlayed.controller_workshop_file_id', index=19,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='launch_source', full_name='CMsgClientGamesPlayed.GamePlayed.launch_source', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vr_hmd_runtime', full_name='CMsgClientGamesPlayed.GamePlayed.vr_hmd_runtime', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_ip_address', full_name='CMsgClientGamesPlayed.GamePlayed.game_ip_address', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controller_connection_type', full_name='CMsgClientGamesPlayed.GamePlayed.controller_connection_type', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2465,
  serialized_end=3152,
)

_CMSGCLIENTGAMESPLAYED = _descriptor.Descriptor(
  name='CMsgClientGamesPlayed',
  full_name='CMsgClientGamesPlayed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='games_played', full_name='CMsgClientGamesPlayed.games_played', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_os_type', full_name='CMsgClientGamesPlayed.client_os_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cloud_gaming_platform', full_name='CMsgClientGamesPlayed.cloud_gaming_platform', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGAMESPLAYED_GAMEPLAYED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2327,
  serialized_end=3152,
)


_CMSGGSAPPROVE = _descriptor.Descriptor(
  name='CMsgGSApprove',
  full_name='CMsgGSApprove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSApprove.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_steam_id', full_name='CMsgGSApprove.owner_steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3154,
  serialized_end=3211,
)


_CMSGGSDENY = _descriptor.Descriptor(
  name='CMsgGSDeny',
  full_name='CMsgGSDeny',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSDeny.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edeny_reason', full_name='CMsgGSDeny.edeny_reason', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deny_string', full_name='CMsgGSDeny.deny_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3213,
  serialized_end=3286,
)


_CMSGGSKICK = _descriptor.Descriptor(
  name='CMsgGSKick',
  full_name='CMsgGSKick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgGSKick.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edeny_reason', full_name='CMsgGSKick.edeny_reason', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3288,
  serialized_end=3340,
)


_CMSGCLIENTAUTHLIST = _descriptor.Descriptor(
  name='CMsgClientAuthList',
  full_name='CMsgClientAuthList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tokens_left', full_name='CMsgClientAuthList.tokens_left', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_request_seq', full_name='CMsgClientAuthList.last_request_seq', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_request_seq_from_server', full_name='CMsgClientAuthList.last_request_seq_from_server', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tickets', full_name='CMsgClientAuthList.tickets', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_ids', full_name='CMsgClientAuthList.app_ids', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_sequence', full_name='CMsgClientAuthList.message_sequence', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3343,
  serialized_end=3525,
)


_CMSGCLIENTAUTHLISTACK = _descriptor.Descriptor(
  name='CMsgClientAuthListAck',
  full_name='CMsgClientAuthListAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_crc', full_name='CMsgClientAuthListAck.ticket_crc', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_ids', full_name='CMsgClientAuthListAck.app_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_sequence', full_name='CMsgClientAuthListAck.message_sequence', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3527,
  serialized_end=3613,
)


_CMSGCLIENTLICENSELIST_LICENSE = _descriptor.Descriptor(
  name='License',
  full_name='CMsgClientLicenseList.License',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_id', full_name='CMsgClientLicenseList.License.package_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CMsgClientLicenseList.License.time_created', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_next_process', full_name='CMsgClientLicenseList.License.time_next_process', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minute_limit', full_name='CMsgClientLicenseList.License.minute_limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minutes_used', full_name='CMsgClientLicenseList.License.minutes_used', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_method', full_name='CMsgClientLicenseList.License.payment_method', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CMsgClientLicenseList.License.flags', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purchase_country_code', full_name='CMsgClientLicenseList.License.purchase_country_code', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='license_type', full_name='CMsgClientLicenseList.License.license_type', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='territory_code', full_name='CMsgClientLicenseList.License.territory_code', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_number', full_name='CMsgClientLicenseList.License.change_number', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='CMsgClientLicenseList.License.owner_id', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_period', full_name='CMsgClientLicenseList.License.initial_period', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_time_unit', full_name='CMsgClientLicenseList.License.initial_time_unit', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='renewal_period', full_name='CMsgClientLicenseList.License.renewal_period', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='renewal_time_unit', full_name='CMsgClientLicenseList.License.renewal_time_unit', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='CMsgClientLicenseList.License.access_token', index=16,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_package_id', full_name='CMsgClientLicenseList.License.master_package_id', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3712,
  serialized_end=4142,
)

_CMSGCLIENTLICENSELIST = _descriptor.Descriptor(
  name='CMsgClientLicenseList',
  full_name='CMsgClientLicenseList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientLicenseList.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='licenses', full_name='CMsgClientLicenseList.licenses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTLICENSELIST_LICENSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3616,
  serialized_end=4142,
)


_CMSGCLIENTLBSSETSCORE = _descriptor.Descriptor(
  name='CMsgClientLBSSetScore',
  full_name='CMsgClientLBSSetScore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientLBSSetScore.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_id', full_name='CMsgClientLBSSetScore.leaderboard_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgClientLBSSetScore.score', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='CMsgClientLBSSetScore.details', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_score_method', full_name='CMsgClientLBSSetScore.upload_score_method', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4144,
  serialized_end=4268,
)


_CMSGCLIENTLBSSETSCORERESPONSE = _descriptor.Descriptor(
  name='CMsgClientLBSSetScoreResponse',
  full_name='CMsgClientLBSSetScoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientLBSSetScoreResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_entry_count', full_name='CMsgClientLBSSetScoreResponse.leaderboard_entry_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score_changed', full_name='CMsgClientLBSSetScoreResponse.score_changed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='global_rank_previous', full_name='CMsgClientLBSSetScoreResponse.global_rank_previous', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='global_rank_new', full_name='CMsgClientLBSSetScoreResponse.global_rank_new', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4271,
  serialized_end=4433,
)


_CMSGCLIENTLBSSETUGC = _descriptor.Descriptor(
  name='CMsgClientLBSSetUGC',
  full_name='CMsgClientLBSSetUGC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientLBSSetUGC.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_id', full_name='CMsgClientLBSSetUGC.leaderboard_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ugc_id', full_name='CMsgClientLBSSetUGC.ugc_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4435,
  serialized_end=4512,
)


_CMSGCLIENTLBSSETUGCRESPONSE = _descriptor.Descriptor(
  name='CMsgClientLBSSetUGCResponse',
  full_name='CMsgClientLBSSetUGCResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientLBSSetUGCResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4514,
  serialized_end=4563,
)


_CMSGCLIENTLBSFINDORCREATELB = _descriptor.Descriptor(
  name='CMsgClientLBSFindOrCreateLB',
  full_name='CMsgClientLBSFindOrCreateLB',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientLBSFindOrCreateLB.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_sort_method', full_name='CMsgClientLBSFindOrCreateLB.leaderboard_sort_method', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_display_type', full_name='CMsgClientLBSFindOrCreateLB.leaderboard_display_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_if_not_found', full_name='CMsgClientLBSFindOrCreateLB.create_if_not_found', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_name', full_name='CMsgClientLBSFindOrCreateLB.leaderboard_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4566,
  serialized_end=4733,
)


_CMSGCLIENTLBSFINDORCREATELBRESPONSE = _descriptor.Descriptor(
  name='CMsgClientLBSFindOrCreateLBResponse',
  full_name='CMsgClientLBSFindOrCreateLBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientLBSFindOrCreateLBResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_id', full_name='CMsgClientLBSFindOrCreateLBResponse.leaderboard_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_entry_count', full_name='CMsgClientLBSFindOrCreateLBResponse.leaderboard_entry_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_sort_method', full_name='CMsgClientLBSFindOrCreateLBResponse.leaderboard_sort_method', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_display_type', full_name='CMsgClientLBSFindOrCreateLBResponse.leaderboard_display_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_name', full_name='CMsgClientLBSFindOrCreateLBResponse.leaderboard_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4736,
  serialized_end=4949,
)


_CMSGCLIENTLBSGETLBENTRIES = _descriptor.Descriptor(
  name='CMsgClientLBSGetLBEntries',
  full_name='CMsgClientLBSGetLBEntries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientLBSGetLBEntries.app_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_id', full_name='CMsgClientLBSGetLBEntries.leaderboard_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_start', full_name='CMsgClientLBSGetLBEntries.range_start', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_end', full_name='CMsgClientLBSGetLBEntries.range_end', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_data_request', full_name='CMsgClientLBSGetLBEntries.leaderboard_data_request', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamids', full_name='CMsgClientLBSGetLBEntries.steamids', index=5,
      number=6, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4952,
  serialized_end=5111,
)


_CMSGCLIENTLBSGETLBENTRIESRESPONSE_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='CMsgClientLBSGetLBEntriesResponse.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_user', full_name='CMsgClientLBSGetLBEntriesResponse.Entry.steam_id_user', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='global_rank', full_name='CMsgClientLBSGetLBEntriesResponse.Entry.global_rank', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='CMsgClientLBSGetLBEntriesResponse.Entry.score', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='CMsgClientLBSGetLBEntriesResponse.Entry.details', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ugc_id', full_name='CMsgClientLBSGetLBEntriesResponse.Entry.ugc_id', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5263,
  serialized_end=5362,
)

_CMSGCLIENTLBSGETLBENTRIESRESPONSE = _descriptor.Descriptor(
  name='CMsgClientLBSGetLBEntriesResponse',
  full_name='CMsgClientLBSGetLBEntriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientLBSGetLBEntriesResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaderboard_entry_count', full_name='CMsgClientLBSGetLBEntriesResponse.leaderboard_entry_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='CMsgClientLBSGetLBEntriesResponse.entries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTLBSGETLBENTRIESRESPONSE_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5114,
  serialized_end=5362,
)


_CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA = _descriptor.Descriptor(
  name='AppMinutesPlayedData',
  full_name='CMsgClientAppMinutesPlayedData.AppMinutesPlayedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientAppMinutesPlayedData.AppMinutesPlayedData.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forever', full_name='CMsgClientAppMinutesPlayedData.AppMinutesPlayedData.forever', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_two_weeks', full_name='CMsgClientAppMinutesPlayedData.AppMinutesPlayedData.last_two_weeks', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5477,
  serialized_end=5556,
)

_CMSGCLIENTAPPMINUTESPLAYEDDATA = _descriptor.Descriptor(
  name='CMsgClientAppMinutesPlayedData',
  full_name='CMsgClientAppMinutesPlayedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='minutes_played', full_name='CMsgClientAppMinutesPlayedData.minutes_played', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5365,
  serialized_end=5556,
)


_CMSGCLIENTISLIMITEDACCOUNT = _descriptor.Descriptor(
  name='CMsgClientIsLimitedAccount',
  full_name='CMsgClientIsLimitedAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bis_limited_account', full_name='CMsgClientIsLimitedAccount.bis_limited_account', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bis_community_banned', full_name='CMsgClientIsLimitedAccount.bis_community_banned', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bis_locked_account', full_name='CMsgClientIsLimitedAccount.bis_locked_account', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bis_limited_account_allowed_to_invite_friends', full_name='CMsgClientIsLimitedAccount.bis_limited_account_allowed_to_invite_friends', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5559,
  serialized_end=5729,
)


_CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND = _descriptor.Descriptor(
  name='StatsToSend',
  full_name='CMsgClientRequestedClientStats.StatsToSend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_stat', full_name='CMsgClientRequestedClientStats.StatsToSend.client_stat', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stat_aggregate_method', full_name='CMsgClientRequestedClientStats.StatsToSend.stat_aggregate_method', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5834,
  serialized_end=5899,
)

_CMSGCLIENTREQUESTEDCLIENTSTATS = _descriptor.Descriptor(
  name='CMsgClientRequestedClientStats',
  full_name='CMsgClientRequestedClientStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats_to_send', full_name='CMsgClientRequestedClientStats.stats_to_send', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5732,
  serialized_end=5899,
)


_CMSGCLIENTSTAT2_STATDETAIL = _descriptor.Descriptor(
  name='StatDetail',
  full_name='CMsgClientStat2.StatDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_stat', full_name='CMsgClientStat2.StatDetail.client_stat', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ll_value', full_name='CMsgClientStat2.StatDetail.ll_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_of_day', full_name='CMsgClientStat2.StatDetail.time_of_day', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgClientStat2.StatDetail.cell_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depot_id', full_name='CMsgClientStat2.StatDetail.depot_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientStat2.StatDetail.app_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5971,
  serialized_end=6094,
)

_CMSGCLIENTSTAT2 = _descriptor.Descriptor(
  name='CMsgClientStat2',
  full_name='CMsgClientStat2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_detail', full_name='CMsgClientStat2.stat_detail', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSTAT2_STATDETAIL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5902,
  serialized_end=6094,
)


_CMSGCLIENTMMSSETRATELIMITPOLICYONCLIENT = _descriptor.Descriptor(
  name='CMsgClientMMSSetRatelimitPolicyOnClient',
  full_name='CMsgClientMMSSetRatelimitPolicyOnClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetRatelimitPolicyOnClient.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_rate_limits', full_name='CMsgClientMMSSetRatelimitPolicyOnClient.enable_rate_limits', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seconds_per_message', full_name='CMsgClientMMSSetRatelimitPolicyOnClient.seconds_per_message', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='milliseconds_per_data_update', full_name='CMsgClientMMSSetRatelimitPolicyOnClient.milliseconds_per_data_update', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6097,
  serialized_end=6249,
)


_CMSGCLIENTMMSCREATELOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSCreateLobby',
  full_name='CMsgClientMMSCreateLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSCreateLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgClientMMSCreateLobby.max_members', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgClientMMSCreateLobby.lobby_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_flags', full_name='CMsgClientMMSCreateLobby.lobby_flags', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgClientMMSCreateLobby.cell_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_public_ip', full_name='CMsgClientMMSCreateLobby.deprecated_public_ip', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSCreateLobby.metadata', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persona_name_owner', full_name='CMsgClientMMSCreateLobby.persona_name_owner', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_ip', full_name='CMsgClientMMSCreateLobby.public_ip', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6252,
  serialized_end=6484,
)


_CMSGCLIENTMMSCREATELOBBYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSCreateLobbyResponse',
  full_name='CMsgClientMMSCreateLobbyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSCreateLobbyResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSCreateLobbyResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientMMSCreateLobbyResponse.eresult', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6486,
  serialized_end=6580,
)


_CMSGCLIENTMMSJOINLOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSJoinLobby',
  full_name='CMsgClientMMSJoinLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSJoinLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSJoinLobby.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgClientMMSJoinLobby.persona_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6582,
  serialized_end=6668,
)


_CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='CMsgClientMMSJoinLobbyResponse.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgClientMMSJoinLobbyResponse.Member.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgClientMMSJoinLobbyResponse.Member.persona_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSJoinLobbyResponse.Member.metadata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6940,
  serialized_end=7006,
)

_CMSGCLIENTMMSJOINLOBBYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSJoinLobbyResponse',
  full_name='CMsgClientMMSJoinLobbyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSJoinLobbyResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSJoinLobbyResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chat_room_enter_response', full_name='CMsgClientMMSJoinLobbyResponse.chat_room_enter_response', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgClientMMSJoinLobbyResponse.max_members', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgClientMMSJoinLobbyResponse.lobby_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_flags', full_name='CMsgClientMMSJoinLobbyResponse.lobby_flags', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_owner', full_name='CMsgClientMMSJoinLobbyResponse.steam_id_owner', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSJoinLobbyResponse.metadata', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgClientMMSJoinLobbyResponse.members', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6671,
  serialized_end=7006,
)


_CMSGCLIENTMMSLEAVELOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSLeaveLobby',
  full_name='CMsgClientMMSLeaveLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSLeaveLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSLeaveLobby.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7008,
  serialized_end=7073,
)


_CMSGCLIENTMMSLEAVELOBBYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSLeaveLobbyResponse',
  full_name='CMsgClientMMSLeaveLobbyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSLeaveLobbyResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSLeaveLobbyResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientMMSLeaveLobbyResponse.eresult', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7075,
  serialized_end=7168,
)


_CMSGCLIENTMMSGETLOBBYLIST_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='CMsgClientMMSGetLobbyList.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='CMsgClientMMSGetLobbyList.Filter.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgClientMMSGetLobbyList.Filter.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comparision', full_name='CMsgClientMMSGetLobbyList.Filter.comparision', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_type', full_name='CMsgClientMMSGetLobbyList.Filter.filter_type', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7381,
  serialized_end=7459,
)

_CMSGCLIENTMMSGETLOBBYLIST = _descriptor.Descriptor(
  name='CMsgClientMMSGetLobbyList',
  full_name='CMsgClientMMSGetLobbyList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSGetLobbyList.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_lobbies_requested', full_name='CMsgClientMMSGetLobbyList.num_lobbies_requested', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgClientMMSGetLobbyList.cell_id', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_public_ip', full_name='CMsgClientMMSGetLobbyList.deprecated_public_ip', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='CMsgClientMMSGetLobbyList.filters', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_ip', full_name='CMsgClientMMSGetLobbyList.public_ip', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTMMSGETLOBBYLIST_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7171,
  serialized_end=7459,
)


_CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY = _descriptor.Descriptor(
  name='Lobby',
  full_name='CMsgClientMMSGetLobbyListResponse.Lobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.max_members', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.lobby_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_flags', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.lobby_flags', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.metadata', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_members', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.num_members', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distance', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.distance', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='CMsgClientMMSGetLobbyListResponse.Lobby.weight', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7595,
  serialized_end=7755,
)

_CMSGCLIENTMMSGETLOBBYLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSGetLobbyListResponse',
  full_name='CMsgClientMMSGetLobbyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSGetLobbyListResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientMMSGetLobbyListResponse.eresult', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobbies', full_name='CMsgClientMMSGetLobbyListResponse.lobbies', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7462,
  serialized_end=7755,
)


_CMSGCLIENTMMSSETLOBBYDATA = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyData',
  full_name='CMsgClientMMSSetLobbyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyData.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyData.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_member', full_name='CMsgClientMMSSetLobbyData.steam_id_member', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgClientMMSSetLobbyData.max_members', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgClientMMSSetLobbyData.lobby_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_flags', full_name='CMsgClientMMSSetLobbyData.lobby_flags', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSSetLobbyData.metadata', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7758,
  serialized_end=7930,
)


_CMSGCLIENTMMSSETLOBBYDATARESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyDataResponse',
  full_name='CMsgClientMMSSetLobbyDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyDataResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyDataResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientMMSSetLobbyDataResponse.eresult', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7932,
  serialized_end=8027,
)


_CMSGCLIENTMMSGETLOBBYDATA = _descriptor.Descriptor(
  name='CMsgClientMMSGetLobbyData',
  full_name='CMsgClientMMSGetLobbyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSGetLobbyData.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSGetLobbyData.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8029,
  serialized_end=8096,
)


_CMSGCLIENTMMSLOBBYDATA_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='CMsgClientMMSLobbyData.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgClientMMSLobbyData.Member.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgClientMMSLobbyData.Member.persona_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSLobbyData.Member.metadata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6940,
  serialized_end=7006,
)

_CMSGCLIENTMMSLOBBYDATA = _descriptor.Descriptor(
  name='CMsgClientMMSLobbyData',
  full_name='CMsgClientMMSLobbyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSLobbyData.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSLobbyData.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_members', full_name='CMsgClientMMSLobbyData.num_members', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_members', full_name='CMsgClientMMSLobbyData.max_members', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_type', full_name='CMsgClientMMSLobbyData.lobby_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_flags', full_name='CMsgClientMMSLobbyData.lobby_flags', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_owner', full_name='CMsgClientMMSLobbyData.steam_id_owner', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='CMsgClientMMSLobbyData.metadata', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgClientMMSLobbyData.members', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_cellid', full_name='CMsgClientMMSLobbyData.lobby_cellid', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_should_accept_changes', full_name='CMsgClientMMSLobbyData.owner_should_accept_changes', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTMMSLOBBYDATA_MEMBER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8099,
  serialized_end=8464,
)


_CMSGCLIENTMMSSENDLOBBYCHATMSG = _descriptor.Descriptor(
  name='CMsgClientMMSSendLobbyChatMsg',
  full_name='CMsgClientMMSSendLobbyChatMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSendLobbyChatMsg.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSendLobbyChatMsg.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_target', full_name='CMsgClientMMSSendLobbyChatMsg.steam_id_target', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_message', full_name='CMsgClientMMSSendLobbyChatMsg.lobby_message', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8466,
  serialized_end=8585,
)


_CMSGCLIENTMMSLOBBYCHATMSG = _descriptor.Descriptor(
  name='CMsgClientMMSLobbyChatMsg',
  full_name='CMsgClientMMSLobbyChatMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSLobbyChatMsg.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSLobbyChatMsg.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_sender', full_name='CMsgClientMMSLobbyChatMsg.steam_id_sender', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_message', full_name='CMsgClientMMSLobbyChatMsg.lobby_message', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8587,
  serialized_end=8702,
)


_CMSGCLIENTMMSSETLOBBYOWNER = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyOwner',
  full_name='CMsgClientMMSSetLobbyOwner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyOwner.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyOwner.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_new_owner', full_name='CMsgClientMMSSetLobbyOwner.steam_id_new_owner', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8704,
  serialized_end=8800,
)


_CMSGCLIENTMMSSETLOBBYOWNERRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyOwnerResponse',
  full_name='CMsgClientMMSSetLobbyOwnerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyOwnerResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyOwnerResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientMMSSetLobbyOwnerResponse.eresult', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8802,
  serialized_end=8898,
)


_CMSGCLIENTMMSSETLOBBYLINKED = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyLinked',
  full_name='CMsgClientMMSSetLobbyLinked',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyLinked.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyLinked.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby2', full_name='CMsgClientMMSSetLobbyLinked.steam_id_lobby2', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8900,
  serialized_end=8994,
)


_CMSGCLIENTMMSSETLOBBYGAMESERVER = _descriptor.Descriptor(
  name='CMsgClientMMSSetLobbyGameServer',
  full_name='CMsgClientMMSSetLobbyGameServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSSetLobbyGameServer.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSSetLobbyGameServer.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_game_server_ip', full_name='CMsgClientMMSSetLobbyGameServer.deprecated_game_server_ip', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_server_port', full_name='CMsgClientMMSSetLobbyGameServer.game_server_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_server_steam_id', full_name='CMsgClientMMSSetLobbyGameServer.game_server_steam_id', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_server_ip', full_name='CMsgClientMMSSetLobbyGameServer.game_server_ip', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8997,
  serialized_end=9201,
)


_CMSGCLIENTMMSLOBBYGAMESERVERSET = _descriptor.Descriptor(
  name='CMsgClientMMSLobbyGameServerSet',
  full_name='CMsgClientMMSLobbyGameServerSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSLobbyGameServerSet.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSLobbyGameServerSet.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_game_server_ip', full_name='CMsgClientMMSLobbyGameServerSet.deprecated_game_server_ip', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_server_port', full_name='CMsgClientMMSLobbyGameServerSet.game_server_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_server_steam_id', full_name='CMsgClientMMSLobbyGameServerSet.game_server_steam_id', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_server_ip', full_name='CMsgClientMMSLobbyGameServerSet.game_server_ip', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9204,
  serialized_end=9408,
)


_CMSGCLIENTMMSUSERJOINEDLOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSUserJoinedLobby',
  full_name='CMsgClientMMSUserJoinedLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSUserJoinedLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSUserJoinedLobby.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_user', full_name='CMsgClientMMSUserJoinedLobby.steam_id_user', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgClientMMSUserJoinedLobby.persona_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9410,
  serialized_end=9525,
)


_CMSGCLIENTMMSUSERLEFTLOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSUserLeftLobby',
  full_name='CMsgClientMMSUserLeftLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSUserLeftLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSUserLeftLobby.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_user', full_name='CMsgClientMMSUserLeftLobby.steam_id_user', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CMsgClientMMSUserLeftLobby.persona_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9527,
  serialized_end=9640,
)


_CMSGCLIENTMMSINVITETOLOBBY = _descriptor.Descriptor(
  name='CMsgClientMMSInviteToLobby',
  full_name='CMsgClientMMSInviteToLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSInviteToLobby.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSInviteToLobby.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_user_invited', full_name='CMsgClientMMSInviteToLobby.steam_id_user_invited', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9642,
  serialized_end=9741,
)


_CMSGCLIENTMMSGETLOBBYSTATUS = _descriptor.Descriptor(
  name='CMsgClientMMSGetLobbyStatus',
  full_name='CMsgClientMMSGetLobbyStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSGetLobbyStatus.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSGetLobbyStatus.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='claim_membership', full_name='CMsgClientMMSGetLobbyStatus.claim_membership', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='claim_ownership', full_name='CMsgClientMMSGetLobbyStatus.claim_ownership', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9743,
  serialized_end=9863,
)


_CMSGCLIENTMMSGETLOBBYSTATUSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientMMSGetLobbyStatusResponse',
  full_name='CMsgClientMMSGetLobbyStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientMMSGetLobbyStatusResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_lobby', full_name='CMsgClientMMSGetLobbyStatusResponse.steam_id_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_status', full_name='CMsgClientMMSGetLobbyStatusResponse.lobby_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9866,
  serialized_end=10009,
)


_CMSGCLIENTINVITETOGAME = _descriptor.Descriptor(
  name='CMsgClientInviteToGame',
  full_name='CMsgClientInviteToGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_dest', full_name='CMsgClientInviteToGame.steam_id_dest', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_src', full_name='CMsgClientInviteToGame.steam_id_src', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connect_string', full_name='CMsgClientInviteToGame.connect_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_play', full_name='CMsgClientInviteToGame.remote_play', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10011,
  serialized_end=10125,
)


_CMSGCLIENTCHATINVITE = _descriptor.Descriptor(
  name='CMsgClientChatInvite',
  full_name='CMsgClientChatInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id_invited', full_name='CMsgClientChatInvite.steam_id_invited', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_chat', full_name='CMsgClientChatInvite.steam_id_chat', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_patron', full_name='CMsgClientChatInvite.steam_id_patron', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatroom_type', full_name='CMsgClientChatInvite.chatroom_type', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_friend_chat', full_name='CMsgClientChatInvite.steam_id_friend_chat', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chat_name', full_name='CMsgClientChatInvite.chat_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientChatInvite.game_id', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10128,
  serialized_end=10313,
)


_CMSGCLIENTCONNECTIONSTATS_STATS_LOGON = _descriptor.Descriptor(
  name='Stats_Logon',
  full_name='CMsgClientConnectionStats.Stats_Logon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='connect_attempts', full_name='CMsgClientConnectionStats.Stats_Logon.connect_attempts', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connect_successes', full_name='CMsgClientConnectionStats.Stats_Logon.connect_successes', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connect_failures', full_name='CMsgClientConnectionStats.Stats_Logon.connect_failures', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connections_dropped', full_name='CMsgClientConnectionStats.Stats_Logon.connections_dropped', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seconds_running', full_name='CMsgClientConnectionStats.Stats_Logon.seconds_running', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msec_tologonthistime', full_name='CMsgClientConnectionStats.Stats_Logon.msec_tologonthistime', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count_bad_cms', full_name='CMsgClientConnectionStats.Stats_Logon.count_bad_cms', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10468,
  serialized_end=10667,
)

_CMSGCLIENTCONNECTIONSTATS_STATS_UDP = _descriptor.Descriptor(
  name='Stats_UDP',
  full_name='CMsgClientConnectionStats.Stats_UDP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pkts_sent', full_name='CMsgClientConnectionStats.Stats_UDP.pkts_sent', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_sent', full_name='CMsgClientConnectionStats.Stats_UDP.bytes_sent', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkts_recv', full_name='CMsgClientConnectionStats.Stats_UDP.pkts_recv', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkts_processed', full_name='CMsgClientConnectionStats.Stats_UDP.pkts_processed', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_recv', full_name='CMsgClientConnectionStats.Stats_UDP.bytes_recv', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10669,
  serialized_end=10782,
)

_CMSGCLIENTCONNECTIONSTATS_STATS_VCONN = _descriptor.Descriptor(
  name='Stats_VConn',
  full_name='CMsgClientConnectionStats.Stats_VConn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='connections_udp', full_name='CMsgClientConnectionStats.Stats_VConn.connections_udp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connections_tcp', full_name='CMsgClientConnectionStats.Stats_VConn.connections_tcp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats_udp', full_name='CMsgClientConnectionStats.Stats_VConn.stats_udp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkts_abandoned', full_name='CMsgClientConnectionStats.Stats_VConn.pkts_abandoned', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conn_req_received', full_name='CMsgClientConnectionStats.Stats_VConn.conn_req_received', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkts_resent', full_name='CMsgClientConnectionStats.Stats_VConn.pkts_resent', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msgs_sent', full_name='CMsgClientConnectionStats.Stats_VConn.msgs_sent', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msgs_sent_failed', full_name='CMsgClientConnectionStats.Stats_VConn.msgs_sent_failed', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msgs_recv', full_name='CMsgClientConnectionStats.Stats_VConn.msgs_recv', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datagrams_sent', full_name='CMsgClientConnectionStats.Stats_VConn.datagrams_sent', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datagrams_recv', full_name='CMsgClientConnectionStats.Stats_VConn.datagrams_recv', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bad_pkts_recv', full_name='CMsgClientConnectionStats.Stats_VConn.bad_pkts_recv', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unknown_conn_pkts_recv', full_name='CMsgClientConnectionStats.Stats_VConn.unknown_conn_pkts_recv', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missed_pkts_recv', full_name='CMsgClientConnectionStats.Stats_VConn.missed_pkts_recv', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dup_pkts_recv', full_name='CMsgClientConnectionStats.Stats_VConn.dup_pkts_recv', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failed_connect_challenges', full_name='CMsgClientConnectionStats.Stats_VConn.failed_connect_challenges', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='micro_sec_avg_latency', full_name='CMsgClientConnectionStats.Stats_VConn.micro_sec_avg_latency', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='micro_sec_min_latency', full_name='CMsgClientConnectionStats.Stats_VConn.micro_sec_min_latency', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='micro_sec_max_latency', full_name='CMsgClientConnectionStats.Stats_VConn.micro_sec_max_latency', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mem_pool_msg_in_use', full_name='CMsgClientConnectionStats.Stats_VConn.mem_pool_msg_in_use', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10785,
  serialized_end=11350,
)

_CMSGCLIENTCONNECTIONSTATS = _descriptor.Descriptor(
  name='CMsgClientConnectionStats',
  full_name='CMsgClientConnectionStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats_logon', full_name='CMsgClientConnectionStats.stats_logon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats_vconn', full_name='CMsgClientConnectionStats.stats_vconn', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTCONNECTIONSTATS_STATS_LOGON, _CMSGCLIENTCONNECTIONSTATS_STATS_UDP, _CMSGCLIENTCONNECTIONSTATS_STATS_VCONN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10316,
  serialized_end=11350,
)


_CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE = _descriptor.Descriptor(
  name='Server_Types_Available',
  full_name='CMsgClientServersAvailable.Server_Types_Available',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server', full_name='CMsgClientServersAvailable.Server_Types_Available.server', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changed', full_name='CMsgClientServersAvailable.Server_Types_Available.changed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11506,
  serialized_end=11563,
)

_CMSGCLIENTSERVERSAVAILABLE = _descriptor.Descriptor(
  name='CMsgClientServersAvailable',
  full_name='CMsgClientServersAvailable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_types_available', full_name='CMsgClientServersAvailable.server_types_available', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_type_for_auth_services', full_name='CMsgClientServersAvailable.server_type_for_auth_services', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11353,
  serialized_end=11563,
)


_CMSGCLIENTGETUSERSTATS = _descriptor.Descriptor(
  name='CMsgClientGetUserStats',
  full_name='CMsgClientGetUserStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientGetUserStats.game_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crc_stats', full_name='CMsgClientGetUserStats.crc_stats', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema_local_version', full_name='CMsgClientGetUserStats.schema_local_version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id_for_user', full_name='CMsgClientGetUserStats.steam_id_for_user', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11565,
  serialized_end=11682,
)


_CMSGCLIENTGETUSERSTATSRESPONSE_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='CMsgClientGetUserStatsResponse.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientGetUserStatsResponse.Stats.stat_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stat_value', full_name='CMsgClientGetUserStatsResponse.Stats.stat_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11925,
  serialized_end=11969,
)

_CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS = _descriptor.Descriptor(
  name='Achievement_Blocks',
  full_name='CMsgClientGetUserStatsResponse.Achievement_Blocks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='achievement_id', full_name='CMsgClientGetUserStatsResponse.Achievement_Blocks.achievement_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unlock_time', full_name='CMsgClientGetUserStatsResponse.Achievement_Blocks.unlock_time', index=1,
      number=2, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11971,
  serialized_end=12036,
)

_CMSGCLIENTGETUSERSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetUserStatsResponse',
  full_name='CMsgClientGetUserStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientGetUserStatsResponse.game_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientGetUserStatsResponse.eresult', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crc_stats', full_name='CMsgClientGetUserStatsResponse.crc_stats', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='CMsgClientGetUserStatsResponse.schema', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgClientGetUserStatsResponse.stats', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='achievement_blocks', full_name='CMsgClientGetUserStatsResponse.achievement_blocks', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETUSERSTATSRESPONSE_STATS, _CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11685,
  serialized_end=12036,
)


_CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION = _descriptor.Descriptor(
  name='Stats_Failed_Validation',
  full_name='CMsgClientStoreUserStatsResponse.Stats_Failed_Validation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientStoreUserStatsResponse.Stats_Failed_Validation.stat_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverted_stat_value', full_name='CMsgClientStoreUserStatsResponse.Stats_Failed_Validation.reverted_stat_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12250,
  serialized_end=12321,
)

_CMSGCLIENTSTOREUSERSTATSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientStoreUserStatsResponse',
  full_name='CMsgClientStoreUserStatsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientStoreUserStatsResponse.game_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientStoreUserStatsResponse.eresult', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crc_stats', full_name='CMsgClientStoreUserStatsResponse.crc_stats', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats_failed_validation', full_name='CMsgClientStoreUserStatsResponse.stats_failed_validation', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats_out_of_date', full_name='CMsgClientStoreUserStatsResponse.stats_out_of_date', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12039,
  serialized_end=12321,
)


_CMSGCLIENTSTOREUSERSTATS2_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='CMsgClientStoreUserStats2.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientStoreUserStats2.Stats.stat_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stat_value', full_name='CMsgClientStoreUserStats2.Stats.stat_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11925,
  serialized_end=11969,
)

_CMSGCLIENTSTOREUSERSTATS2 = _descriptor.Descriptor(
  name='CMsgClientStoreUserStats2',
  full_name='CMsgClientStoreUserStats2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientStoreUserStats2.game_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settor_steam_id', full_name='CMsgClientStoreUserStats2.settor_steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settee_steam_id', full_name='CMsgClientStoreUserStats2.settee_steam_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crc_stats', full_name='CMsgClientStoreUserStats2.crc_stats', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='explicit_reset', full_name='CMsgClientStoreUserStats2.explicit_reset', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CMsgClientStoreUserStats2.stats', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSTOREUSERSTATS2_STATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12324,
  serialized_end=12556,
)


_CMSGCLIENTSTATSUPDATED_UPDATED_STATS = _descriptor.Descriptor(
  name='Updated_Stats',
  full_name='CMsgClientStatsUpdated.Updated_Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientStatsUpdated.Updated_Stats.stat_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stat_value', full_name='CMsgClientStatsUpdated.Updated_Stats.stat_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12701,
  serialized_end=12753,
)

_CMSGCLIENTSTATSUPDATED = _descriptor.Descriptor(
  name='CMsgClientStatsUpdated',
  full_name='CMsgClientStatsUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgClientStatsUpdated.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientStatsUpdated.game_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crc_stats', full_name='CMsgClientStatsUpdated.crc_stats', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_stats', full_name='CMsgClientStatsUpdated.updated_stats', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSTATSUPDATED_UPDATED_STATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12559,
  serialized_end=12753,
)


_CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE = _descriptor.Descriptor(
  name='Stats_To_Store',
  full_name='CMsgClientStoreUserStats.Stats_To_Store',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_id', full_name='CMsgClientStoreUserStats.Stats_To_Store.stat_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stat_value', full_name='CMsgClientStoreUserStats.Stats_To_Store.stat_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12891,
  serialized_end=12944,
)

_CMSGCLIENTSTOREUSERSTATS = _descriptor.Descriptor(
  name='CMsgClientStoreUserStats',
  full_name='CMsgClientStoreUserStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientStoreUserStats.game_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='explicit_reset', full_name='CMsgClientStoreUserStats.explicit_reset', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats_to_store', full_name='CMsgClientStoreUserStats.stats_to_store', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12756,
  serialized_end=12944,
)


_CMSGCLIENTGETCLIENTDETAILS = _descriptor.Descriptor(
  name='CMsgClientGetClientDetails',
  full_name='CMsgClientGetClientDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12946,
  serialized_end=12974,
)


_CMSGCLIENTREPORTOVERLAYDETOURFAILURE = _descriptor.Descriptor(
  name='CMsgClientReportOverlayDetourFailure',
  full_name='CMsgClientReportOverlayDetourFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='failure_strings', full_name='CMsgClientReportOverlayDetourFailure.failure_strings', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12976,
  serialized_end=13039,
)


_CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME = _descriptor.Descriptor(
  name='Game',
  full_name='CMsgClientGetClientDetailsResponse.Game',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientGetClientDetailsResponse.Game.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_info', full_name='CMsgClientGetClientDetailsResponse.Game.extra_info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_running_sec', full_name='CMsgClientGetClientDetailsResponse.Game.time_running_sec', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13294,
  serialized_end=13361,
)

_CMSGCLIENTGETCLIENTDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetClientDetailsResponse',
  full_name='CMsgClientGetClientDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_version', full_name='CMsgClientGetClientDetailsResponse.package_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='CMsgClientGetClientDetailsResponse.protocol_version', index=1,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os', full_name='CMsgClientGetClientDetailsResponse.os', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='machine_name', full_name='CMsgClientGetClientDetailsResponse.machine_name', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip_public', full_name='CMsgClientGetClientDetailsResponse.ip_public', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip_private', full_name='CMsgClientGetClientDetailsResponse.ip_private', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_available', full_name='CMsgClientGetClientDetailsResponse.bytes_available', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='games_running', full_name='CMsgClientGetClientDetailsResponse.games_running', index=7,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13042,
  serialized_end=13361,
)


_CMSGCLIENTGETCLIENTAPPLIST = _descriptor.Descriptor(
  name='CMsgClientGetClientAppList',
  full_name='CMsgClientGetClientAppList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='media', full_name='CMsgClientGetClientAppList.media', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tools', full_name='CMsgClientGetClientAppList.tools', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='games', full_name='CMsgClientGetClientAppList.games', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='only_installed', full_name='CMsgClientGetClientAppList.only_installed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='only_changing', full_name='CMsgClientGetClientAppList.only_changing', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comics', full_name='CMsgClientGetClientAppList.comics', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13364,
  serialized_end=13500,
)


_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC = _descriptor.Descriptor(
  name='DLC',
  full_name='CMsgClientGetClientAppListResponse.App.DLC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientGetClientAppListResponse.App.DLC.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='installed', full_name='CMsgClientGetClientAppListResponse.App.DLC.installed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13993,
  serialized_end=14032,
)

_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP = _descriptor.Descriptor(
  name='App',
  full_name='CMsgClientGetClientAppListResponse.App',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientGetClientAppListResponse.App.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='CMsgClientGetClientAppListResponse.App.category', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_type', full_name='CMsgClientGetClientAppListResponse.App.app_type', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='favorite', full_name='CMsgClientGetClientAppListResponse.App.favorite', index=3,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='installed', full_name='CMsgClientGetClientAppListResponse.App.installed', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_update', full_name='CMsgClientGetClientAppListResponse.App.auto_update', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_downloaded', full_name='CMsgClientGetClientAppListResponse.App.bytes_downloaded', index=6,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_needed', full_name='CMsgClientGetClientAppListResponse.App.bytes_needed', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_download_rate', full_name='CMsgClientGetClientAppListResponse.App.bytes_download_rate', index=8,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='download_paused', full_name='CMsgClientGetClientAppListResponse.App.download_paused', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_downloading', full_name='CMsgClientGetClientAppListResponse.App.num_downloading', index=10,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_paused', full_name='CMsgClientGetClientAppListResponse.App.num_paused', index=11,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changing', full_name='CMsgClientGetClientAppListResponse.App.changing', index=12,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='available_on_platform', full_name='CMsgClientGetClientAppListResponse.App.available_on_platform', index=13,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dlcs', full_name='CMsgClientGetClientAppListResponse.App.dlcs', index=14,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13622,
  serialized_end=14032,
)

_CMSGCLIENTGETCLIENTAPPLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetClientAppListResponse',
  full_name='CMsgClientGetClientAppListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps', full_name='CMsgClientGetClientAppListResponse.apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_available', full_name='CMsgClientGetClientAppListResponse.bytes_available', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13503,
  serialized_end=14032,
)


_CMSGCLIENTINSTALLCLIENTAPP = _descriptor.Descriptor(
  name='CMsgClientInstallClientApp',
  full_name='CMsgClientInstallClientApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientInstallClientApp.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14034,
  serialized_end=14077,
)


_CMSGCLIENTINSTALLCLIENTAPPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientInstallClientAppResponse',
  full_name='CMsgClientInstallClientAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientInstallClientAppResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14079,
  serialized_end=14131,
)


_CMSGCLIENTUNINSTALLCLIENTAPP = _descriptor.Descriptor(
  name='CMsgClientUninstallClientApp',
  full_name='CMsgClientUninstallClientApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientUninstallClientApp.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14133,
  serialized_end=14178,
)


_CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUninstallClientAppResponse',
  full_name='CMsgClientUninstallClientAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientUninstallClientAppResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14180,
  serialized_end=14234,
)


_CMSGCLIENTSETCLIENTAPPUPDATESTATE = _descriptor.Descriptor(
  name='CMsgClientSetClientAppUpdateState',
  full_name='CMsgClientSetClientAppUpdateState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientSetClientAppUpdateState.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='CMsgClientSetClientAppUpdateState.update', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14236,
  serialized_end=14302,
)


_CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE = _descriptor.Descriptor(
  name='CMsgClientSetClientAppUpdateStateResponse',
  full_name='CMsgClientSetClientAppUpdateStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientSetClientAppUpdateStateResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14304,
  serialized_end=14363,
)


_CMSGCLIENTUFSUPLOADFILEREQUEST = _descriptor.Descriptor(
  name='CMsgClientUFSUploadFileRequest',
  full_name='CMsgClientUFSUploadFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSUploadFileRequest.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='CMsgClientUFSUploadFileRequest.file_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_file_size', full_name='CMsgClientUFSUploadFileRequest.raw_file_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSUploadFileRequest.sha_file', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='CMsgClientUFSUploadFileRequest.time_stamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSUploadFileRequest.file_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platforms_to_sync_deprecated', full_name='CMsgClientUFSUploadFileRequest.platforms_to_sync_deprecated', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platforms_to_sync', full_name='CMsgClientUFSUploadFileRequest.platforms_to_sync', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4294967295,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgClientUFSUploadFileRequest.cell_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_encrypt', full_name='CMsgClientUFSUploadFileRequest.can_encrypt', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14366,
  serialized_end=14628,
)


_CMSGCLIENTUFSUPLOADFILERESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSUploadFileResponse',
  full_name='CMsgClientUFSUploadFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSUploadFileResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSUploadFileResponse.sha_file', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_http', full_name='CMsgClientUFSUploadFileResponse.use_http', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_host', full_name='CMsgClientUFSUploadFileResponse.http_host', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_url', full_name='CMsgClientUFSUploadFileResponse.http_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kv_headers', full_name='CMsgClientUFSUploadFileResponse.kv_headers', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_https', full_name='CMsgClientUFSUploadFileResponse.use_https', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encrypt_file', full_name='CMsgClientUFSUploadFileResponse.encrypt_file', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14631,
  serialized_end=14818,
)


_CMSGCLIENTUFSUPLOADCOMMIT_FILE = _descriptor.Descriptor(
  name='File',
  full_name='CMsgClientUFSUploadCommit.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSUploadCommit.File.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSUploadCommit.File.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSUploadCommit.File.sha_file', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cub_file', full_name='CMsgClientUFSUploadCommit.File.cub_file', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSUploadCommit.File.file_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14898,
  serialized_end=14995,
)

_CMSGCLIENTUFSUPLOADCOMMIT = _descriptor.Descriptor(
  name='CMsgClientUFSUploadCommit',
  full_name='CMsgClientUFSUploadCommit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='CMsgClientUFSUploadCommit.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTUFSUPLOADCOMMIT_FILE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14821,
  serialized_end=14995,
)


_CMSGCLIENTUFSUPLOADCOMMITRESPONSE_FILE = _descriptor.Descriptor(
  name='File',
  full_name='CMsgClientUFSUploadCommitResponse.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSUploadCommitResponse.File.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSUploadCommitResponse.File.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSUploadCommitResponse.File.sha_file', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14898,
  serialized_end=14958,
)

_CMSGCLIENTUFSUPLOADCOMMITRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSUploadCommitResponse',
  full_name='CMsgClientUFSUploadCommitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='CMsgClientUFSUploadCommitResponse.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTUFSUPLOADCOMMITRESPONSE_FILE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14998,
  serialized_end=15151,
)


_CMSGCLIENTUFSFILECHUNK = _descriptor.Descriptor(
  name='CMsgClientUFSFileChunk',
  full_name='CMsgClientUFSFileChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSFileChunk.sha_file', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_start', full_name='CMsgClientUFSFileChunk.file_start', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='CMsgClientUFSFileChunk.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15153,
  serialized_end=15229,
)


_CMSGCLIENTUFSTRANSFERHEARTBEAT = _descriptor.Descriptor(
  name='CMsgClientUFSTransferHeartbeat',
  full_name='CMsgClientUFSTransferHeartbeat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15231,
  serialized_end=15263,
)


_CMSGCLIENTUFSUPLOADFILEFINISHED = _descriptor.Descriptor(
  name='CMsgClientUFSUploadFileFinished',
  full_name='CMsgClientUFSUploadFileFinished',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSUploadFileFinished.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSUploadFileFinished.sha_file', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15265,
  serialized_end=15336,
)


_CMSGCLIENTUFSDELETEFILEREQUEST = _descriptor.Descriptor(
  name='CMsgClientUFSDeleteFileRequest',
  full_name='CMsgClientUFSDeleteFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSDeleteFileRequest.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSDeleteFileRequest.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_explicit_delete', full_name='CMsgClientUFSDeleteFileRequest.is_explicit_delete', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15338,
  serialized_end=15433,
)


_CMSGCLIENTUFSDELETEFILERESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSDeleteFileResponse',
  full_name='CMsgClientUFSDeleteFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSDeleteFileResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSDeleteFileResponse.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15435,
  serialized_end=15507,
)


_CMSGCLIENTUFSGETFILELISTFORAPP = _descriptor.Descriptor(
  name='CMsgClientUFSGetFileListForApp',
  full_name='CMsgClientUFSGetFileListForApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps_to_query', full_name='CMsgClientUFSGetFileListForApp.apps_to_query', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_path_prefixes', full_name='CMsgClientUFSGetFileListForApp.send_path_prefixes', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15509,
  serialized_end=15592,
)


_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE_FILE = _descriptor.Descriptor(
  name='File',
  full_name='CMsgClientUFSGetFileListForAppResponse.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSGetFileListForAppResponse.File.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSGetFileListForAppResponse.File.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSGetFileListForAppResponse.File.sha_file', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='CMsgClientUFSGetFileListForAppResponse.File.time_stamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_file_size', full_name='CMsgClientUFSGetFileListForAppResponse.File.raw_file_size', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_explicit_delete', full_name='CMsgClientUFSGetFileListForAppResponse.File.is_explicit_delete', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platforms_to_sync', full_name='CMsgClientUFSGetFileListForAppResponse.File.platforms_to_sync', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_prefix_index', full_name='CMsgClientUFSGetFileListForAppResponse.File.path_prefix_index', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15722,
  serialized_end=15906,
)

_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSGetFileListForAppResponse',
  full_name='CMsgClientUFSGetFileListForAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='CMsgClientUFSGetFileListForAppResponse.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_prefixes', full_name='CMsgClientUFSGetFileListForAppResponse.path_prefixes', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE_FILE, ],
  enum_types=[
  ],
  serialized_options=_b('\200\265\030\010\210\265\030\020'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15595,
  serialized_end=15916,
)


_CMSGCLIENTUFSDOWNLOADREQUEST = _descriptor.Descriptor(
  name='CMsgClientUFSDownloadRequest',
  full_name='CMsgClientUFSDownloadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSDownloadRequest.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSDownloadRequest.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_handle_http', full_name='CMsgClientUFSDownloadRequest.can_handle_http', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15918,
  serialized_end=16008,
)


_CMSGCLIENTUFSDOWNLOADRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSDownloadResponse',
  full_name='CMsgClientUFSDownloadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSDownloadResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSDownloadResponse.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='CMsgClientUFSDownloadResponse.file_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_file_size', full_name='CMsgClientUFSDownloadResponse.raw_file_size', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSDownloadResponse.sha_file', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='CMsgClientUFSDownloadResponse.time_stamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_explicit_delete', full_name='CMsgClientUFSDownloadResponse.is_explicit_delete', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_http', full_name='CMsgClientUFSDownloadResponse.use_http', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_host', full_name='CMsgClientUFSDownloadResponse.http_host', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_url', full_name='CMsgClientUFSDownloadResponse.http_url', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kv_headers', full_name='CMsgClientUFSDownloadResponse.kv_headers', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_https', full_name='CMsgClientUFSDownloadResponse.use_https', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encrypted', full_name='CMsgClientUFSDownloadResponse.encrypted', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16011,
  serialized_end=16299,
)


_CMSGCLIENTUFSLOGINREQUEST = _descriptor.Descriptor(
  name='CMsgClientUFSLoginRequest',
  full_name='CMsgClientUFSLoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='CMsgClientUFSLoginRequest.protocol_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='am_session_token', full_name='CMsgClientUFSLoginRequest.am_session_token', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apps', full_name='CMsgClientUFSLoginRequest.apps', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16301,
  serialized_end=16394,
)


_CMSGCLIENTUFSLOGINRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSLoginResponse',
  full_name='CMsgClientUFSLoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSLoginResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16396,
  serialized_end=16444,
)


_CMSGCLIENTREQUESTENCRYPTEDAPPTICKET = _descriptor.Descriptor(
  name='CMsgClientRequestEncryptedAppTicket',
  full_name='CMsgClientRequestEncryptedAppTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientRequestEncryptedAppTicket.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userdata', full_name='CMsgClientRequestEncryptedAppTicket.userdata', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16446,
  serialized_end=16517,
)


_CMSGCLIENTREQUESTENCRYPTEDAPPTICKETRESPONSE = _descriptor.Descriptor(
  name='CMsgClientRequestEncryptedAppTicketResponse',
  full_name='CMsgClientRequestEncryptedAppTicketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientRequestEncryptedAppTicketResponse.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientRequestEncryptedAppTicketResponse.eresult', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encrypted_app_ticket', full_name='CMsgClientRequestEncryptedAppTicketResponse.encrypted_app_ticket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16520,
  serialized_end=16652,
)


_CMSGCLIENTWALLETINFOUPDATE = _descriptor.Descriptor(
  name='CMsgClientWalletInfoUpdate',
  full_name='CMsgClientWalletInfoUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_wallet', full_name='CMsgClientWalletInfoUpdate.has_wallet', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balance', full_name='CMsgClientWalletInfoUpdate.balance', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CMsgClientWalletInfoUpdate.currency', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balance_delayed', full_name='CMsgClientWalletInfoUpdate.balance_delayed', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balance64', full_name='CMsgClientWalletInfoUpdate.balance64', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\240\266\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balance64_delayed', full_name='CMsgClientWalletInfoUpdate.balance64_delayed', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\240\266\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16655,
  serialized_end=16821,
)


_CMSGCLIENTAPPINFOUPDATE = _descriptor.Descriptor(
  name='CMsgClientAppInfoUpdate',
  full_name='CMsgClientAppInfoUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_changenumber', full_name='CMsgClientAppInfoUpdate.last_changenumber', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_changelist', full_name='CMsgClientAppInfoUpdate.send_changelist', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16823,
  serialized_end=16900,
)


_CMSGCLIENTAPPINFOCHANGES = _descriptor.Descriptor(
  name='CMsgClientAppInfoChanges',
  full_name='CMsgClientAppInfoChanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_change_number', full_name='CMsgClientAppInfoChanges.current_change_number', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_full_update', full_name='CMsgClientAppInfoChanges.force_full_update', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appIDs', full_name='CMsgClientAppInfoChanges.appIDs', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16902,
  serialized_end=17002,
)


_CMSGCLIENTAPPINFOREQUEST_APP = _descriptor.Descriptor(
  name='App',
  full_name='CMsgClientAppInfoRequest.App',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientAppInfoRequest.App.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='section_flags', full_name='CMsgClientAppInfoRequest.App.section_flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='section_CRC', full_name='CMsgClientAppInfoRequest.App.section_CRC', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17111,
  serialized_end=17176,
)

_CMSGCLIENTAPPINFOREQUEST = _descriptor.Descriptor(
  name='CMsgClientAppInfoRequest',
  full_name='CMsgClientAppInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps', full_name='CMsgClientAppInfoRequest.apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supports_batches', full_name='CMsgClientAppInfoRequest.supports_batches', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTAPPINFOREQUEST_APP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17005,
  serialized_end=17176,
)


_CMSGCLIENTAPPINFORESPONSE_APP_SECTION = _descriptor.Descriptor(
  name='Section',
  full_name='CMsgClientAppInfoResponse.App.Section',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='section_id', full_name='CMsgClientAppInfoResponse.App.Section.section_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='section_kv', full_name='CMsgClientAppInfoResponse.App.Section.section_kv', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17403,
  serialized_end=17452,
)

_CMSGCLIENTAPPINFORESPONSE_APP = _descriptor.Descriptor(
  name='App',
  full_name='CMsgClientAppInfoResponse.App',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientAppInfoResponse.App.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_number', full_name='CMsgClientAppInfoResponse.App.change_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sections', full_name='CMsgClientAppInfoResponse.App.sections', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTAPPINFORESPONSE_APP_SECTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17299,
  serialized_end=17452,
)

_CMSGCLIENTAPPINFORESPONSE = _descriptor.Descriptor(
  name='CMsgClientAppInfoResponse',
  full_name='CMsgClientAppInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps', full_name='CMsgClientAppInfoResponse.apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apps_unknown', full_name='CMsgClientAppInfoResponse.apps_unknown', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apps_pending', full_name='CMsgClientAppInfoResponse.apps_pending', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTAPPINFORESPONSE_APP, ],
  enum_types=[
  ],
  serialized_options=_b('\210\265\030\000'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17179,
  serialized_end=17458,
)


_CMSGCLIENTPACKAGEINFOREQUEST = _descriptor.Descriptor(
  name='CMsgClientPackageInfoRequest',
  full_name='CMsgClientPackageInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_ids', full_name='CMsgClientPackageInfoRequest.package_ids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta_data_only', full_name='CMsgClientPackageInfoRequest.meta_data_only', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17460,
  serialized_end=17535,
)


_CMSGCLIENTPACKAGEINFORESPONSE_PACKAGE = _descriptor.Descriptor(
  name='Package',
  full_name='CMsgClientPackageInfoResponse.Package',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_id', full_name='CMsgClientPackageInfoResponse.Package.package_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_number', full_name='CMsgClientPackageInfoResponse.Package.change_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha', full_name='CMsgClientPackageInfoResponse.Package.sha', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='CMsgClientPackageInfoResponse.Package.buffer', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17681,
  serialized_end=17762,
)

_CMSGCLIENTPACKAGEINFORESPONSE = _descriptor.Descriptor(
  name='CMsgClientPackageInfoResponse',
  full_name='CMsgClientPackageInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packages', full_name='CMsgClientPackageInfoResponse.packages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packages_unknown', full_name='CMsgClientPackageInfoResponse.packages_unknown', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packages_pending', full_name='CMsgClientPackageInfoResponse.packages_pending', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTPACKAGEINFORESPONSE_PACKAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17538,
  serialized_end=17762,
)


_CMSGCLIENTPICSCHANGESSINCEREQUEST = _descriptor.Descriptor(
  name='CMsgClientPICSChangesSinceRequest',
  full_name='CMsgClientPICSChangesSinceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='since_change_number', full_name='CMsgClientPICSChangesSinceRequest.since_change_number', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_app_info_changes', full_name='CMsgClientPICSChangesSinceRequest.send_app_info_changes', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_package_info_changes', full_name='CMsgClientPICSChangesSinceRequest.send_package_info_changes', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_app_info_cached', full_name='CMsgClientPICSChangesSinceRequest.num_app_info_cached', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_package_info_cached', full_name='CMsgClientPICSChangesSinceRequest.num_package_info_cached', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17765,
  serialized_end=17957,
)


_CMSGCLIENTPICSCHANGESSINCERESPONSE_PACKAGECHANGE = _descriptor.Descriptor(
  name='PackageChange',
  full_name='CMsgClientPICSChangesSinceResponse.PackageChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packageid', full_name='CMsgClientPICSChangesSinceResponse.PackageChange.packageid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_number', full_name='CMsgClientPICSChangesSinceResponse.PackageChange.change_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_token', full_name='CMsgClientPICSChangesSinceResponse.PackageChange.needs_token', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18295,
  serialized_end=18373,
)

_CMSGCLIENTPICSCHANGESSINCERESPONSE_APPCHANGE = _descriptor.Descriptor(
  name='AppChange',
  full_name='CMsgClientPICSChangesSinceResponse.AppChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientPICSChangesSinceResponse.AppChange.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_number', full_name='CMsgClientPICSChangesSinceResponse.AppChange.change_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_token', full_name='CMsgClientPICSChangesSinceResponse.AppChange.needs_token', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18375,
  serialized_end=18445,
)

_CMSGCLIENTPICSCHANGESSINCERESPONSE = _descriptor.Descriptor(
  name='CMsgClientPICSChangesSinceResponse',
  full_name='CMsgClientPICSChangesSinceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_change_number', full_name='CMsgClientPICSChangesSinceResponse.current_change_number', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='since_change_number', full_name='CMsgClientPICSChangesSinceResponse.since_change_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_full_update', full_name='CMsgClientPICSChangesSinceResponse.force_full_update', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='package_changes', full_name='CMsgClientPICSChangesSinceResponse.package_changes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_changes', full_name='CMsgClientPICSChangesSinceResponse.app_changes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_full_app_update', full_name='CMsgClientPICSChangesSinceResponse.force_full_app_update', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_full_package_update', full_name='CMsgClientPICSChangesSinceResponse.force_full_package_update', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTPICSCHANGESSINCERESPONSE_PACKAGECHANGE, _CMSGCLIENTPICSCHANGESSINCERESPONSE_APPCHANGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17960,
  serialized_end=18445,
)


_CMSGCLIENTPICSPRODUCTINFOREQUEST_APPINFO = _descriptor.Descriptor(
  name='AppInfo',
  full_name='CMsgClientPICSProductInfoRequest.AppInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientPICSProductInfoRequest.AppInfo.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='CMsgClientPICSProductInfoRequest.AppInfo.access_token', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='only_public', full_name='CMsgClientPICSProductInfoRequest.AppInfo.only_public', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18688,
  serialized_end=18755,
)

_CMSGCLIENTPICSPRODUCTINFOREQUEST_PACKAGEINFO = _descriptor.Descriptor(
  name='PackageInfo',
  full_name='CMsgClientPICSProductInfoRequest.PackageInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packageid', full_name='CMsgClientPICSProductInfoRequest.PackageInfo.packageid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='CMsgClientPICSProductInfoRequest.PackageInfo.access_token', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18757,
  serialized_end=18811,
)

_CMSGCLIENTPICSPRODUCTINFOREQUEST = _descriptor.Descriptor(
  name='CMsgClientPICSProductInfoRequest',
  full_name='CMsgClientPICSProductInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packages', full_name='CMsgClientPICSProductInfoRequest.packages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apps', full_name='CMsgClientPICSProductInfoRequest.apps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta_data_only', full_name='CMsgClientPICSProductInfoRequest.meta_data_only', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_prev_failed', full_name='CMsgClientPICSProductInfoRequest.num_prev_failed', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supports_package_tokens', full_name='CMsgClientPICSProductInfoRequest.supports_package_tokens', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTPICSPRODUCTINFOREQUEST_APPINFO, _CMSGCLIENTPICSPRODUCTINFOREQUEST_PACKAGEINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18448,
  serialized_end=18811,
)


_CMSGCLIENTPICSPRODUCTINFORESPONSE_APPINFO = _descriptor.Descriptor(
  name='AppInfo',
  full_name='CMsgClientPICSProductInfoResponse.AppInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientPICSProductInfoResponse.AppInfo.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_number', full_name='CMsgClientPICSProductInfoResponse.AppInfo.change_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missing_token', full_name='CMsgClientPICSProductInfoResponse.AppInfo.missing_token', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha', full_name='CMsgClientPICSProductInfoResponse.AppInfo.sha', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='CMsgClientPICSProductInfoResponse.AppInfo.buffer', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='only_public', full_name='CMsgClientPICSProductInfoResponse.AppInfo.only_public', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='CMsgClientPICSProductInfoResponse.AppInfo.size', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19120,
  serialized_end=19254,
)

_CMSGCLIENTPICSPRODUCTINFORESPONSE_PACKAGEINFO = _descriptor.Descriptor(
  name='PackageInfo',
  full_name='CMsgClientPICSProductInfoResponse.PackageInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packageid', full_name='CMsgClientPICSProductInfoResponse.PackageInfo.packageid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_number', full_name='CMsgClientPICSProductInfoResponse.PackageInfo.change_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missing_token', full_name='CMsgClientPICSProductInfoResponse.PackageInfo.missing_token', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha', full_name='CMsgClientPICSProductInfoResponse.PackageInfo.sha', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='CMsgClientPICSProductInfoResponse.PackageInfo.buffer', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='CMsgClientPICSProductInfoResponse.PackageInfo.size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19256,
  serialized_end=19377,
)

_CMSGCLIENTPICSPRODUCTINFORESPONSE = _descriptor.Descriptor(
  name='CMsgClientPICSProductInfoResponse',
  full_name='CMsgClientPICSProductInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps', full_name='CMsgClientPICSProductInfoResponse.apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unknown_appids', full_name='CMsgClientPICSProductInfoResponse.unknown_appids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packages', full_name='CMsgClientPICSProductInfoResponse.packages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unknown_packageids', full_name='CMsgClientPICSProductInfoResponse.unknown_packageids', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta_data_only', full_name='CMsgClientPICSProductInfoResponse.meta_data_only', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_pending', full_name='CMsgClientPICSProductInfoResponse.response_pending', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_min_size', full_name='CMsgClientPICSProductInfoResponse.http_min_size', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_host', full_name='CMsgClientPICSProductInfoResponse.http_host', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTPICSPRODUCTINFORESPONSE_APPINFO, _CMSGCLIENTPICSPRODUCTINFORESPONSE_PACKAGEINFO, ],
  enum_types=[
  ],
  serialized_options=_b('\210\265\030\000'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18814,
  serialized_end=19383,
)


_CMSGCLIENTPICSACCESSTOKENREQUEST = _descriptor.Descriptor(
  name='CMsgClientPICSAccessTokenRequest',
  full_name='CMsgClientPICSAccessTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packageids', full_name='CMsgClientPICSAccessTokenRequest.packageids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appids', full_name='CMsgClientPICSAccessTokenRequest.appids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19385,
  serialized_end=19455,
)


_CMSGCLIENTPICSACCESSTOKENRESPONSE_PACKAGETOKEN = _descriptor.Descriptor(
  name='PackageToken',
  full_name='CMsgClientPICSAccessTokenResponse.PackageToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packageid', full_name='CMsgClientPICSAccessTokenResponse.PackageToken.packageid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='CMsgClientPICSAccessTokenResponse.PackageToken.access_token', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19705,
  serialized_end=19760,
)

_CMSGCLIENTPICSACCESSTOKENRESPONSE_APPTOKEN = _descriptor.Descriptor(
  name='AppToken',
  full_name='CMsgClientPICSAccessTokenResponse.AppToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientPICSAccessTokenResponse.AppToken.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_token', full_name='CMsgClientPICSAccessTokenResponse.AppToken.access_token', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19762,
  serialized_end=19809,
)

_CMSGCLIENTPICSACCESSTOKENRESPONSE = _descriptor.Descriptor(
  name='CMsgClientPICSAccessTokenResponse',
  full_name='CMsgClientPICSAccessTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_access_tokens', full_name='CMsgClientPICSAccessTokenResponse.package_access_tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='package_denied_tokens', full_name='CMsgClientPICSAccessTokenResponse.package_denied_tokens', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_access_tokens', full_name='CMsgClientPICSAccessTokenResponse.app_access_tokens', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_denied_tokens', full_name='CMsgClientPICSAccessTokenResponse.app_denied_tokens', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTPICSACCESSTOKENRESPONSE_PACKAGETOKEN, _CMSGCLIENTPICSACCESSTOKENRESPONSE_APPTOKEN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19458,
  serialized_end=19809,
)


_CMSGCLIENTUFSGETUGCDETAILS = _descriptor.Descriptor(
  name='CMsgClientUFSGetUGCDetails',
  full_name='CMsgClientUFSGetUGCDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hcontent', full_name='CMsgClientUFSGetUGCDetails.hcontent', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=True, default_value=18446744073709551615,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19811,
  serialized_end=19879,
)


_CMSGCLIENTUFSGETUGCDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSGetUGCDetailsResponse',
  full_name='CMsgClientUFSGetUGCDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSGetUGCDetailsResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='CMsgClientUFSGetUGCDetailsResponse.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSGetUGCDetailsResponse.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='CMsgClientUFSGetUGCDetailsResponse.filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamid_creator', full_name='CMsgClientUFSGetUGCDetailsResponse.steamid_creator', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='CMsgClientUFSGetUGCDetailsResponse.file_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed_file_size', full_name='CMsgClientUFSGetUGCDetailsResponse.compressed_file_size', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rangecheck_host', full_name='CMsgClientUFSGetUGCDetailsResponse.rangecheck_host', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_encoded_sha1', full_name='CMsgClientUFSGetUGCDetailsResponse.file_encoded_sha1', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19882,
  serialized_end=20111,
)


_CMSGCLIENTUFSGETSINGLEFILEINFO = _descriptor.Descriptor(
  name='CMsgClientUFSGetSingleFileInfo',
  full_name='CMsgClientUFSGetSingleFileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSGetSingleFileInfo.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSGetSingleFileInfo.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20113,
  serialized_end=20180,
)


_CMSGCLIENTUFSGETSINGLEFILEINFORESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSGetSingleFileInfoResponse',
  full_name='CMsgClientUFSGetSingleFileInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSGetSingleFileInfoResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSGetSingleFileInfoResponse.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSGetSingleFileInfoResponse.file_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSGetSingleFileInfoResponse.sha_file', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='CMsgClientUFSGetSingleFileInfoResponse.time_stamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_file_size', full_name='CMsgClientUFSGetSingleFileInfoResponse.raw_file_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_explicit_delete', full_name='CMsgClientUFSGetSingleFileInfoResponse.is_explicit_delete', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20183,
  serialized_end=20367,
)


_CMSGCLIENTUFSSHAREFILE = _descriptor.Descriptor(
  name='CMsgClientUFSShareFile',
  full_name='CMsgClientUFSShareFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSShareFile.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSShareFile.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20369,
  serialized_end=20428,
)


_CMSGCLIENTUFSSHAREFILERESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSShareFileResponse',
  full_name='CMsgClientUFSShareFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSShareFileResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hcontent', full_name='CMsgClientUFSShareFileResponse.hcontent', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=True, default_value=18446744073709551615,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20430,
  serialized_end=20522,
)


_CMSGCLIENTAMGETCLANOFFICERS = _descriptor.Descriptor(
  name='CMsgClientAMGetClanOfficers',
  full_name='CMsgClientAMGetClanOfficers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_clan', full_name='CMsgClientAMGetClanOfficers.steamid_clan', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20524,
  serialized_end=20575,
)


_CMSGCLIENTAMGETCLANOFFICERSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientAMGetClanOfficersResponse',
  full_name='CMsgClientAMGetClanOfficersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientAMGetClanOfficersResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamid_clan', full_name='CMsgClientAMGetClanOfficersResponse.steamid_clan', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='officer_count', full_name='CMsgClientAMGetClanOfficersResponse.officer_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20577,
  serialized_end=20679,
)


_CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE = _descriptor.Descriptor(
  name='IdInstance',
  full_name='CMsgClientAMGetPersonaNameHistory.IdInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientAMGetPersonaNameHistory.IdInstance.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20797,
  serialized_end=20826,
)

_CMSGCLIENTAMGETPERSONANAMEHISTORY = _descriptor.Descriptor(
  name='CMsgClientAMGetPersonaNameHistory',
  full_name='CMsgClientAMGetPersonaNameHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id_count', full_name='CMsgClientAMGetPersonaNameHistory.id_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Ids', full_name='CMsgClientAMGetPersonaNameHistory.Ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20682,
  serialized_end=20826,
)


_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE = _descriptor.Descriptor(
  name='NameInstance',
  full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name_since', full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance.name_since', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21104,
  serialized_end=21152,
)

_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE = _descriptor.Descriptor(
  name='NameTableInstance',
  full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='names', full_name='CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.names', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20956,
  serialized_end=21152,
)

_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE = _descriptor.Descriptor(
  name='CMsgClientAMGetPersonaNameHistoryResponse',
  full_name='CMsgClientAMGetPersonaNameHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='CMsgClientAMGetPersonaNameHistoryResponse.responses', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20829,
  serialized_end=21152,
)


_CMSGCLIENTDEREGISTERWITHSERVER = _descriptor.Descriptor(
  name='CMsgClientDeregisterWithServer',
  full_name='CMsgClientDeregisterWithServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eservertype', full_name='CMsgClientDeregisterWithServer.eservertype', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientDeregisterWithServer.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21154,
  serialized_end=21223,
)


_CMSGCLIENTCLANSTATE_NAMEINFO = _descriptor.Descriptor(
  name='NameInfo',
  full_name='CMsgClientClanState.NameInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clan_name', full_name='CMsgClientClanState.NameInfo.clan_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sha_avatar', full_name='CMsgClientClanState.NameInfo.sha_avatar', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21525,
  serialized_end=21574,
)

_CMSGCLIENTCLANSTATE_USERCOUNTS = _descriptor.Descriptor(
  name='UserCounts',
  full_name='CMsgClientClanState.UserCounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgClientClanState.UserCounts.members', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='online', full_name='CMsgClientClanState.UserCounts.online', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chatting', full_name='CMsgClientClanState.UserCounts.chatting', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_game', full_name='CMsgClientClanState.UserCounts.in_game', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chat_room_members', full_name='CMsgClientClanState.UserCounts.chat_room_members', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21576,
  serialized_end=21683,
)

_CMSGCLIENTCLANSTATE_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='CMsgClientClanState.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='CMsgClientClanState.Event.gid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_time', full_name='CMsgClientClanState.Event.event_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline', full_name='CMsgClientClanState.Event.headline', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_id', full_name='CMsgClientClanState.Event.game_id', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='just_posted', full_name='CMsgClientClanState.Event.just_posted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21685,
  serialized_end=21781,
)

_CMSGCLIENTCLANSTATE = _descriptor.Descriptor(
  name='CMsgClientClanState',
  full_name='CMsgClientClanState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_clan', full_name='CMsgClientClanState.steamid_clan', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clan_account_flags', full_name='CMsgClientClanState.clan_account_flags', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name_info', full_name='CMsgClientClanState.name_info', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_counts', full_name='CMsgClientClanState.user_counts', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='CMsgClientClanState.events', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='announcements', full_name='CMsgClientClanState.announcements', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chat_room_private', full_name='CMsgClientClanState.chat_room_private', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTCLANSTATE_NAMEINFO, _CMSGCLIENTCLANSTATE_USERCOUNTS, _CMSGCLIENTCLANSTATE_EVENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21226,
  serialized_end=21781,
)


_CMSGCLIENTUNSIGNEDINSTALLSCRIPT = _descriptor.Descriptor(
  name='CMsgClientUnsignedInstallScript',
  full_name='CMsgClientUnsignedInstallScript',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUnsignedInstallScript.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUnsignedInstallScript.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='CMsgClientUnsignedInstallScript.file_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature_broken', full_name='CMsgClientUnsignedInstallScript.signature_broken', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depot_id', full_name='CMsgClientUnsignedInstallScript.depot_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manifest_id', full_name='CMsgClientUnsignedInstallScript.manifest_id', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_flags', full_name='CMsgClientUnsignedInstallScript.file_flags', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21784,
  serialized_end=21956,
)

_CMSGGSPLAYERLIST_PLAYER.fields_by_name['public_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGGSPLAYERLIST_PLAYER.containing_type = _CMSGGSPLAYERLIST
_CMSGGSPLAYERLIST.fields_by_name['players'].message_type = _CMSGGSPLAYERLIST_PLAYER
_CMSGGSUSERPLAYING.fields_by_name['public_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTGAMESPLAYED_GAMEPLAYED.fields_by_name['game_ip_address'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTGAMESPLAYED_GAMEPLAYED.containing_type = _CMSGCLIENTGAMESPLAYED
_CMSGCLIENTGAMESPLAYED.fields_by_name['games_played'].message_type = _CMSGCLIENTGAMESPLAYED_GAMEPLAYED
_CMSGCLIENTAUTHLIST.fields_by_name['tickets'].message_type = steammessages__base__pb2._CMSGAUTHTICKET
_CMSGCLIENTLICENSELIST_LICENSE.containing_type = _CMSGCLIENTLICENSELIST
_CMSGCLIENTLICENSELIST.fields_by_name['licenses'].message_type = _CMSGCLIENTLICENSELIST_LICENSE
_CMSGCLIENTLBSGETLBENTRIESRESPONSE_ENTRY.containing_type = _CMSGCLIENTLBSGETLBENTRIESRESPONSE
_CMSGCLIENTLBSGETLBENTRIESRESPONSE.fields_by_name['entries'].message_type = _CMSGCLIENTLBSGETLBENTRIESRESPONSE_ENTRY
_CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA.containing_type = _CMSGCLIENTAPPMINUTESPLAYEDDATA
_CMSGCLIENTAPPMINUTESPLAYEDDATA.fields_by_name['minutes_played'].message_type = _CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA
_CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND.containing_type = _CMSGCLIENTREQUESTEDCLIENTSTATS
_CMSGCLIENTREQUESTEDCLIENTSTATS.fields_by_name['stats_to_send'].message_type = _CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND
_CMSGCLIENTSTAT2_STATDETAIL.containing_type = _CMSGCLIENTSTAT2
_CMSGCLIENTSTAT2.fields_by_name['stat_detail'].message_type = _CMSGCLIENTSTAT2_STATDETAIL
_CMSGCLIENTMMSCREATELOBBY.fields_by_name['public_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER.containing_type = _CMSGCLIENTMMSJOINLOBBYRESPONSE
_CMSGCLIENTMMSJOINLOBBYRESPONSE.fields_by_name['members'].message_type = _CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER
_CMSGCLIENTMMSGETLOBBYLIST_FILTER.containing_type = _CMSGCLIENTMMSGETLOBBYLIST
_CMSGCLIENTMMSGETLOBBYLIST.fields_by_name['filters'].message_type = _CMSGCLIENTMMSGETLOBBYLIST_FILTER
_CMSGCLIENTMMSGETLOBBYLIST.fields_by_name['public_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY.containing_type = _CMSGCLIENTMMSGETLOBBYLISTRESPONSE
_CMSGCLIENTMMSGETLOBBYLISTRESPONSE.fields_by_name['lobbies'].message_type = _CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY
_CMSGCLIENTMMSLOBBYDATA_MEMBER.containing_type = _CMSGCLIENTMMSLOBBYDATA
_CMSGCLIENTMMSLOBBYDATA.fields_by_name['members'].message_type = _CMSGCLIENTMMSLOBBYDATA_MEMBER
_CMSGCLIENTMMSSETLOBBYGAMESERVER.fields_by_name['game_server_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTMMSLOBBYGAMESERVERSET.fields_by_name['game_server_ip'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CMSGCLIENTMMSGETLOBBYSTATUSRESPONSE.fields_by_name['lobby_status'].enum_type = _EMMSLOBBYSTATUS
_CMSGCLIENTCONNECTIONSTATS_STATS_LOGON.containing_type = _CMSGCLIENTCONNECTIONSTATS
_CMSGCLIENTCONNECTIONSTATS_STATS_UDP.containing_type = _CMSGCLIENTCONNECTIONSTATS
_CMSGCLIENTCONNECTIONSTATS_STATS_VCONN.fields_by_name['stats_udp'].message_type = _CMSGCLIENTCONNECTIONSTATS_STATS_UDP
_CMSGCLIENTCONNECTIONSTATS_STATS_VCONN.containing_type = _CMSGCLIENTCONNECTIONSTATS
_CMSGCLIENTCONNECTIONSTATS.fields_by_name['stats_logon'].message_type = _CMSGCLIENTCONNECTIONSTATS_STATS_LOGON
_CMSGCLIENTCONNECTIONSTATS.fields_by_name['stats_vconn'].message_type = _CMSGCLIENTCONNECTIONSTATS_STATS_VCONN
_CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE.containing_type = _CMSGCLIENTSERVERSAVAILABLE
_CMSGCLIENTSERVERSAVAILABLE.fields_by_name['server_types_available'].message_type = _CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE
_CMSGCLIENTGETUSERSTATSRESPONSE_STATS.containing_type = _CMSGCLIENTGETUSERSTATSRESPONSE
_CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS.containing_type = _CMSGCLIENTGETUSERSTATSRESPONSE
_CMSGCLIENTGETUSERSTATSRESPONSE.fields_by_name['stats'].message_type = _CMSGCLIENTGETUSERSTATSRESPONSE_STATS
_CMSGCLIENTGETUSERSTATSRESPONSE.fields_by_name['achievement_blocks'].message_type = _CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS
_CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION.containing_type = _CMSGCLIENTSTOREUSERSTATSRESPONSE
_CMSGCLIENTSTOREUSERSTATSRESPONSE.fields_by_name['stats_failed_validation'].message_type = _CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION
_CMSGCLIENTSTOREUSERSTATS2_STATS.containing_type = _CMSGCLIENTSTOREUSERSTATS2
_CMSGCLIENTSTOREUSERSTATS2.fields_by_name['stats'].message_type = _CMSGCLIENTSTOREUSERSTATS2_STATS
_CMSGCLIENTSTATSUPDATED_UPDATED_STATS.containing_type = _CMSGCLIENTSTATSUPDATED
_CMSGCLIENTSTATSUPDATED.fields_by_name['updated_stats'].message_type = _CMSGCLIENTSTATSUPDATED_UPDATED_STATS
_CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE.containing_type = _CMSGCLIENTSTOREUSERSTATS
_CMSGCLIENTSTOREUSERSTATS.fields_by_name['stats_to_store'].message_type = _CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE
_CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME.containing_type = _CMSGCLIENTGETCLIENTDETAILSRESPONSE
_CMSGCLIENTGETCLIENTDETAILSRESPONSE.fields_by_name['games_running'].message_type = _CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC.containing_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP.fields_by_name['dlcs'].message_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP.containing_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE.fields_by_name['apps'].message_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP
_CMSGCLIENTUFSUPLOADCOMMIT_FILE.containing_type = _CMSGCLIENTUFSUPLOADCOMMIT
_CMSGCLIENTUFSUPLOADCOMMIT.fields_by_name['files'].message_type = _CMSGCLIENTUFSUPLOADCOMMIT_FILE
_CMSGCLIENTUFSUPLOADCOMMITRESPONSE_FILE.containing_type = _CMSGCLIENTUFSUPLOADCOMMITRESPONSE
_CMSGCLIENTUFSUPLOADCOMMITRESPONSE.fields_by_name['files'].message_type = _CMSGCLIENTUFSUPLOADCOMMITRESPONSE_FILE
_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE_FILE.containing_type = _CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE
_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE.fields_by_name['files'].message_type = _CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE_FILE
_CMSGCLIENTREQUESTENCRYPTEDAPPTICKETRESPONSE.fields_by_name['encrypted_app_ticket'].message_type = encrypted__app__ticket__pb2._ENCRYPTEDAPPTICKET
_CMSGCLIENTAPPINFOREQUEST_APP.containing_type = _CMSGCLIENTAPPINFOREQUEST
_CMSGCLIENTAPPINFOREQUEST.fields_by_name['apps'].message_type = _CMSGCLIENTAPPINFOREQUEST_APP
_CMSGCLIENTAPPINFORESPONSE_APP_SECTION.containing_type = _CMSGCLIENTAPPINFORESPONSE_APP
_CMSGCLIENTAPPINFORESPONSE_APP.fields_by_name['sections'].message_type = _CMSGCLIENTAPPINFORESPONSE_APP_SECTION
_CMSGCLIENTAPPINFORESPONSE_APP.containing_type = _CMSGCLIENTAPPINFORESPONSE
_CMSGCLIENTAPPINFORESPONSE.fields_by_name['apps'].message_type = _CMSGCLIENTAPPINFORESPONSE_APP
_CMSGCLIENTPACKAGEINFORESPONSE_PACKAGE.containing_type = _CMSGCLIENTPACKAGEINFORESPONSE
_CMSGCLIENTPACKAGEINFORESPONSE.fields_by_name['packages'].message_type = _CMSGCLIENTPACKAGEINFORESPONSE_PACKAGE
_CMSGCLIENTPICSCHANGESSINCERESPONSE_PACKAGECHANGE.containing_type = _CMSGCLIENTPICSCHANGESSINCERESPONSE
_CMSGCLIENTPICSCHANGESSINCERESPONSE_APPCHANGE.containing_type = _CMSGCLIENTPICSCHANGESSINCERESPONSE
_CMSGCLIENTPICSCHANGESSINCERESPONSE.fields_by_name['package_changes'].message_type = _CMSGCLIENTPICSCHANGESSINCERESPONSE_PACKAGECHANGE
_CMSGCLIENTPICSCHANGESSINCERESPONSE.fields_by_name['app_changes'].message_type = _CMSGCLIENTPICSCHANGESSINCERESPONSE_APPCHANGE
_CMSGCLIENTPICSPRODUCTINFOREQUEST_APPINFO.containing_type = _CMSGCLIENTPICSPRODUCTINFOREQUEST
_CMSGCLIENTPICSPRODUCTINFOREQUEST_PACKAGEINFO.containing_type = _CMSGCLIENTPICSPRODUCTINFOREQUEST
_CMSGCLIENTPICSPRODUCTINFOREQUEST.fields_by_name['packages'].message_type = _CMSGCLIENTPICSPRODUCTINFOREQUEST_PACKAGEINFO
_CMSGCLIENTPICSPRODUCTINFOREQUEST.fields_by_name['apps'].message_type = _CMSGCLIENTPICSPRODUCTINFOREQUEST_APPINFO
_CMSGCLIENTPICSPRODUCTINFORESPONSE_APPINFO.containing_type = _CMSGCLIENTPICSPRODUCTINFORESPONSE
_CMSGCLIENTPICSPRODUCTINFORESPONSE_PACKAGEINFO.containing_type = _CMSGCLIENTPICSPRODUCTINFORESPONSE
_CMSGCLIENTPICSPRODUCTINFORESPONSE.fields_by_name['apps'].message_type = _CMSGCLIENTPICSPRODUCTINFORESPONSE_APPINFO
_CMSGCLIENTPICSPRODUCTINFORESPONSE.fields_by_name['packages'].message_type = _CMSGCLIENTPICSPRODUCTINFORESPONSE_PACKAGEINFO
_CMSGCLIENTPICSACCESSTOKENRESPONSE_PACKAGETOKEN.containing_type = _CMSGCLIENTPICSACCESSTOKENRESPONSE
_CMSGCLIENTPICSACCESSTOKENRESPONSE_APPTOKEN.containing_type = _CMSGCLIENTPICSACCESSTOKENRESPONSE
_CMSGCLIENTPICSACCESSTOKENRESPONSE.fields_by_name['package_access_tokens'].message_type = _CMSGCLIENTPICSACCESSTOKENRESPONSE_PACKAGETOKEN
_CMSGCLIENTPICSACCESSTOKENRESPONSE.fields_by_name['app_access_tokens'].message_type = _CMSGCLIENTPICSACCESSTOKENRESPONSE_APPTOKEN
_CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE.containing_type = _CMSGCLIENTAMGETPERSONANAMEHISTORY
_CMSGCLIENTAMGETPERSONANAMEHISTORY.fields_by_name['Ids'].message_type = _CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE
_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE.containing_type = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE
_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE.fields_by_name['names'].message_type = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE
_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE.containing_type = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE
_CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE.fields_by_name['responses'].message_type = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE
_CMSGCLIENTCLANSTATE_NAMEINFO.containing_type = _CMSGCLIENTCLANSTATE
_CMSGCLIENTCLANSTATE_USERCOUNTS.containing_type = _CMSGCLIENTCLANSTATE
_CMSGCLIENTCLANSTATE_EVENT.containing_type = _CMSGCLIENTCLANSTATE
_CMSGCLIENTCLANSTATE.fields_by_name['name_info'].message_type = _CMSGCLIENTCLANSTATE_NAMEINFO
_CMSGCLIENTCLANSTATE.fields_by_name['user_counts'].message_type = _CMSGCLIENTCLANSTATE_USERCOUNTS
_CMSGCLIENTCLANSTATE.fields_by_name['events'].message_type = _CMSGCLIENTCLANSTATE_EVENT
_CMSGCLIENTCLANSTATE.fields_by_name['announcements'].message_type = _CMSGCLIENTCLANSTATE_EVENT
DESCRIPTOR.message_types_by_name['CMsgClientUDSP2PSessionStarted'] = _CMSGCLIENTUDSP2PSESSIONSTARTED
DESCRIPTOR.message_types_by_name['CMsgClientUDSP2PSessionEnded'] = _CMSGCLIENTUDSP2PSESSIONENDED
DESCRIPTOR.message_types_by_name['CMsgClientRegisterAuthTicketWithCM'] = _CMSGCLIENTREGISTERAUTHTICKETWITHCM
DESCRIPTOR.message_types_by_name['CMsgClientTicketAuthComplete'] = _CMSGCLIENTTICKETAUTHCOMPLETE
DESCRIPTOR.message_types_by_name['CMsgClientCMList'] = _CMSGCLIENTCMLIST
DESCRIPTOR.message_types_by_name['CMsgClientP2PConnectionInfo'] = _CMSGCLIENTP2PCONNECTIONINFO
DESCRIPTOR.message_types_by_name['CMsgClientP2PConnectionFailInfo'] = _CMSGCLIENTP2PCONNECTIONFAILINFO
DESCRIPTOR.message_types_by_name['CMsgClientNetworkingCertRequest'] = _CMSGCLIENTNETWORKINGCERTREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientNetworkingCertReply'] = _CMSGCLIENTNETWORKINGCERTREPLY
DESCRIPTOR.message_types_by_name['CMsgClientNetworkingMobileCertRequest'] = _CMSGCLIENTNETWORKINGMOBILECERTREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientNetworkingMobileCertReply'] = _CMSGCLIENTNETWORKINGMOBILECERTREPLY
DESCRIPTOR.message_types_by_name['CMsgClientGetAppOwnershipTicket'] = _CMSGCLIENTGETAPPOWNERSHIPTICKET
DESCRIPTOR.message_types_by_name['CMsgClientGetAppOwnershipTicketResponse'] = _CMSGCLIENTGETAPPOWNERSHIPTICKETRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientSessionToken'] = _CMSGCLIENTSESSIONTOKEN
DESCRIPTOR.message_types_by_name['CMsgClientGameConnectTokens'] = _CMSGCLIENTGAMECONNECTTOKENS
DESCRIPTOR.message_types_by_name['CMsgGSServerType'] = _CMSGGSSERVERTYPE
DESCRIPTOR.message_types_by_name['CMsgGSStatusReply'] = _CMSGGSSTATUSREPLY
DESCRIPTOR.message_types_by_name['CMsgGSPlayerList'] = _CMSGGSPLAYERLIST
DESCRIPTOR.message_types_by_name['CMsgGSUserPlaying'] = _CMSGGSUSERPLAYING
DESCRIPTOR.message_types_by_name['CMsgGSDisconnectNotice'] = _CMSGGSDISCONNECTNOTICE
DESCRIPTOR.message_types_by_name['CMsgClientGamesPlayed'] = _CMSGCLIENTGAMESPLAYED
DESCRIPTOR.message_types_by_name['CMsgGSApprove'] = _CMSGGSAPPROVE
DESCRIPTOR.message_types_by_name['CMsgGSDeny'] = _CMSGGSDENY
DESCRIPTOR.message_types_by_name['CMsgGSKick'] = _CMSGGSKICK
DESCRIPTOR.message_types_by_name['CMsgClientAuthList'] = _CMSGCLIENTAUTHLIST
DESCRIPTOR.message_types_by_name['CMsgClientAuthListAck'] = _CMSGCLIENTAUTHLISTACK
DESCRIPTOR.message_types_by_name['CMsgClientLicenseList'] = _CMSGCLIENTLICENSELIST
DESCRIPTOR.message_types_by_name['CMsgClientLBSSetScore'] = _CMSGCLIENTLBSSETSCORE
DESCRIPTOR.message_types_by_name['CMsgClientLBSSetScoreResponse'] = _CMSGCLIENTLBSSETSCORERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientLBSSetUGC'] = _CMSGCLIENTLBSSETUGC
DESCRIPTOR.message_types_by_name['CMsgClientLBSSetUGCResponse'] = _CMSGCLIENTLBSSETUGCRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientLBSFindOrCreateLB'] = _CMSGCLIENTLBSFINDORCREATELB
DESCRIPTOR.message_types_by_name['CMsgClientLBSFindOrCreateLBResponse'] = _CMSGCLIENTLBSFINDORCREATELBRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientLBSGetLBEntries'] = _CMSGCLIENTLBSGETLBENTRIES
DESCRIPTOR.message_types_by_name['CMsgClientLBSGetLBEntriesResponse'] = _CMSGCLIENTLBSGETLBENTRIESRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientAppMinutesPlayedData'] = _CMSGCLIENTAPPMINUTESPLAYEDDATA
DESCRIPTOR.message_types_by_name['CMsgClientIsLimitedAccount'] = _CMSGCLIENTISLIMITEDACCOUNT
DESCRIPTOR.message_types_by_name['CMsgClientRequestedClientStats'] = _CMSGCLIENTREQUESTEDCLIENTSTATS
DESCRIPTOR.message_types_by_name['CMsgClientStat2'] = _CMSGCLIENTSTAT2
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetRatelimitPolicyOnClient'] = _CMSGCLIENTMMSSETRATELIMITPOLICYONCLIENT
DESCRIPTOR.message_types_by_name['CMsgClientMMSCreateLobby'] = _CMSGCLIENTMMSCREATELOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSCreateLobbyResponse'] = _CMSGCLIENTMMSCREATELOBBYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSJoinLobby'] = _CMSGCLIENTMMSJOINLOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSJoinLobbyResponse'] = _CMSGCLIENTMMSJOINLOBBYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSLeaveLobby'] = _CMSGCLIENTMMSLEAVELOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSLeaveLobbyResponse'] = _CMSGCLIENTMMSLEAVELOBBYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSGetLobbyList'] = _CMSGCLIENTMMSGETLOBBYLIST
DESCRIPTOR.message_types_by_name['CMsgClientMMSGetLobbyListResponse'] = _CMSGCLIENTMMSGETLOBBYLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyData'] = _CMSGCLIENTMMSSETLOBBYDATA
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyDataResponse'] = _CMSGCLIENTMMSSETLOBBYDATARESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSGetLobbyData'] = _CMSGCLIENTMMSGETLOBBYDATA
DESCRIPTOR.message_types_by_name['CMsgClientMMSLobbyData'] = _CMSGCLIENTMMSLOBBYDATA
DESCRIPTOR.message_types_by_name['CMsgClientMMSSendLobbyChatMsg'] = _CMSGCLIENTMMSSENDLOBBYCHATMSG
DESCRIPTOR.message_types_by_name['CMsgClientMMSLobbyChatMsg'] = _CMSGCLIENTMMSLOBBYCHATMSG
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyOwner'] = _CMSGCLIENTMMSSETLOBBYOWNER
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyOwnerResponse'] = _CMSGCLIENTMMSSETLOBBYOWNERRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyLinked'] = _CMSGCLIENTMMSSETLOBBYLINKED
DESCRIPTOR.message_types_by_name['CMsgClientMMSSetLobbyGameServer'] = _CMSGCLIENTMMSSETLOBBYGAMESERVER
DESCRIPTOR.message_types_by_name['CMsgClientMMSLobbyGameServerSet'] = _CMSGCLIENTMMSLOBBYGAMESERVERSET
DESCRIPTOR.message_types_by_name['CMsgClientMMSUserJoinedLobby'] = _CMSGCLIENTMMSUSERJOINEDLOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSUserLeftLobby'] = _CMSGCLIENTMMSUSERLEFTLOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSInviteToLobby'] = _CMSGCLIENTMMSINVITETOLOBBY
DESCRIPTOR.message_types_by_name['CMsgClientMMSGetLobbyStatus'] = _CMSGCLIENTMMSGETLOBBYSTATUS
DESCRIPTOR.message_types_by_name['CMsgClientMMSGetLobbyStatusResponse'] = _CMSGCLIENTMMSGETLOBBYSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientInviteToGame'] = _CMSGCLIENTINVITETOGAME
DESCRIPTOR.message_types_by_name['CMsgClientChatInvite'] = _CMSGCLIENTCHATINVITE
DESCRIPTOR.message_types_by_name['CMsgClientConnectionStats'] = _CMSGCLIENTCONNECTIONSTATS
DESCRIPTOR.message_types_by_name['CMsgClientServersAvailable'] = _CMSGCLIENTSERVERSAVAILABLE
DESCRIPTOR.message_types_by_name['CMsgClientGetUserStats'] = _CMSGCLIENTGETUSERSTATS
DESCRIPTOR.message_types_by_name['CMsgClientGetUserStatsResponse'] = _CMSGCLIENTGETUSERSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientStoreUserStatsResponse'] = _CMSGCLIENTSTOREUSERSTATSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientStoreUserStats2'] = _CMSGCLIENTSTOREUSERSTATS2
DESCRIPTOR.message_types_by_name['CMsgClientStatsUpdated'] = _CMSGCLIENTSTATSUPDATED
DESCRIPTOR.message_types_by_name['CMsgClientStoreUserStats'] = _CMSGCLIENTSTOREUSERSTATS
DESCRIPTOR.message_types_by_name['CMsgClientGetClientDetails'] = _CMSGCLIENTGETCLIENTDETAILS
DESCRIPTOR.message_types_by_name['CMsgClientReportOverlayDetourFailure'] = _CMSGCLIENTREPORTOVERLAYDETOURFAILURE
DESCRIPTOR.message_types_by_name['CMsgClientGetClientDetailsResponse'] = _CMSGCLIENTGETCLIENTDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientGetClientAppList'] = _CMSGCLIENTGETCLIENTAPPLIST
DESCRIPTOR.message_types_by_name['CMsgClientGetClientAppListResponse'] = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientInstallClientApp'] = _CMSGCLIENTINSTALLCLIENTAPP
DESCRIPTOR.message_types_by_name['CMsgClientInstallClientAppResponse'] = _CMSGCLIENTINSTALLCLIENTAPPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUninstallClientApp'] = _CMSGCLIENTUNINSTALLCLIENTAPP
DESCRIPTOR.message_types_by_name['CMsgClientUninstallClientAppResponse'] = _CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientSetClientAppUpdateState'] = _CMSGCLIENTSETCLIENTAPPUPDATESTATE
DESCRIPTOR.message_types_by_name['CMsgClientSetClientAppUpdateStateResponse'] = _CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSUploadFileRequest'] = _CMSGCLIENTUFSUPLOADFILEREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientUFSUploadFileResponse'] = _CMSGCLIENTUFSUPLOADFILERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSUploadCommit'] = _CMSGCLIENTUFSUPLOADCOMMIT
DESCRIPTOR.message_types_by_name['CMsgClientUFSUploadCommitResponse'] = _CMSGCLIENTUFSUPLOADCOMMITRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSFileChunk'] = _CMSGCLIENTUFSFILECHUNK
DESCRIPTOR.message_types_by_name['CMsgClientUFSTransferHeartbeat'] = _CMSGCLIENTUFSTRANSFERHEARTBEAT
DESCRIPTOR.message_types_by_name['CMsgClientUFSUploadFileFinished'] = _CMSGCLIENTUFSUPLOADFILEFINISHED
DESCRIPTOR.message_types_by_name['CMsgClientUFSDeleteFileRequest'] = _CMSGCLIENTUFSDELETEFILEREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientUFSDeleteFileResponse'] = _CMSGCLIENTUFSDELETEFILERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetFileListForApp'] = _CMSGCLIENTUFSGETFILELISTFORAPP
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetFileListForAppResponse'] = _CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSDownloadRequest'] = _CMSGCLIENTUFSDOWNLOADREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientUFSDownloadResponse'] = _CMSGCLIENTUFSDOWNLOADRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSLoginRequest'] = _CMSGCLIENTUFSLOGINREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientUFSLoginResponse'] = _CMSGCLIENTUFSLOGINRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientRequestEncryptedAppTicket'] = _CMSGCLIENTREQUESTENCRYPTEDAPPTICKET
DESCRIPTOR.message_types_by_name['CMsgClientRequestEncryptedAppTicketResponse'] = _CMSGCLIENTREQUESTENCRYPTEDAPPTICKETRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientWalletInfoUpdate'] = _CMSGCLIENTWALLETINFOUPDATE
DESCRIPTOR.message_types_by_name['CMsgClientAppInfoUpdate'] = _CMSGCLIENTAPPINFOUPDATE
DESCRIPTOR.message_types_by_name['CMsgClientAppInfoChanges'] = _CMSGCLIENTAPPINFOCHANGES
DESCRIPTOR.message_types_by_name['CMsgClientAppInfoRequest'] = _CMSGCLIENTAPPINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientAppInfoResponse'] = _CMSGCLIENTAPPINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientPackageInfoRequest'] = _CMSGCLIENTPACKAGEINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientPackageInfoResponse'] = _CMSGCLIENTPACKAGEINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientPICSChangesSinceRequest'] = _CMSGCLIENTPICSCHANGESSINCEREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientPICSChangesSinceResponse'] = _CMSGCLIENTPICSCHANGESSINCERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientPICSProductInfoRequest'] = _CMSGCLIENTPICSPRODUCTINFOREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientPICSProductInfoResponse'] = _CMSGCLIENTPICSPRODUCTINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientPICSAccessTokenRequest'] = _CMSGCLIENTPICSACCESSTOKENREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientPICSAccessTokenResponse'] = _CMSGCLIENTPICSACCESSTOKENRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetUGCDetails'] = _CMSGCLIENTUFSGETUGCDETAILS
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetUGCDetailsResponse'] = _CMSGCLIENTUFSGETUGCDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetSingleFileInfo'] = _CMSGCLIENTUFSGETSINGLEFILEINFO
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetSingleFileInfoResponse'] = _CMSGCLIENTUFSGETSINGLEFILEINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSShareFile'] = _CMSGCLIENTUFSSHAREFILE
DESCRIPTOR.message_types_by_name['CMsgClientUFSShareFileResponse'] = _CMSGCLIENTUFSSHAREFILERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientAMGetClanOfficers'] = _CMSGCLIENTAMGETCLANOFFICERS
DESCRIPTOR.message_types_by_name['CMsgClientAMGetClanOfficersResponse'] = _CMSGCLIENTAMGETCLANOFFICERSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientAMGetPersonaNameHistory'] = _CMSGCLIENTAMGETPERSONANAMEHISTORY
DESCRIPTOR.message_types_by_name['CMsgClientAMGetPersonaNameHistoryResponse'] = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientDeregisterWithServer'] = _CMSGCLIENTDEREGISTERWITHSERVER
DESCRIPTOR.message_types_by_name['CMsgClientClanState'] = _CMSGCLIENTCLANSTATE
DESCRIPTOR.message_types_by_name['CMsgClientUnsignedInstallScript'] = _CMSGCLIENTUNSIGNEDINSTALLSCRIPT
DESCRIPTOR.enum_types_by_name['EMMSLobbyStatus'] = _EMMSLOBBYSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientUDSP2PSessionStarted = _reflection.GeneratedProtocolMessageType('CMsgClientUDSP2PSessionStarted', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUDSP2PSESSIONSTARTED,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUDSP2PSessionStarted)
  ))
_sym_db.RegisterMessage(CMsgClientUDSP2PSessionStarted)

CMsgClientUDSP2PSessionEnded = _reflection.GeneratedProtocolMessageType('CMsgClientUDSP2PSessionEnded', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUDSP2PSESSIONENDED,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUDSP2PSessionEnded)
  ))
_sym_db.RegisterMessage(CMsgClientUDSP2PSessionEnded)

CMsgClientRegisterAuthTicketWithCM = _reflection.GeneratedProtocolMessageType('CMsgClientRegisterAuthTicketWithCM', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTREGISTERAUTHTICKETWITHCM,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRegisterAuthTicketWithCM)
  ))
_sym_db.RegisterMessage(CMsgClientRegisterAuthTicketWithCM)

CMsgClientTicketAuthComplete = _reflection.GeneratedProtocolMessageType('CMsgClientTicketAuthComplete', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTTICKETAUTHCOMPLETE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientTicketAuthComplete)
  ))
_sym_db.RegisterMessage(CMsgClientTicketAuthComplete)

CMsgClientCMList = _reflection.GeneratedProtocolMessageType('CMsgClientCMList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTCMLIST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientCMList)
  ))
_sym_db.RegisterMessage(CMsgClientCMList)

CMsgClientP2PConnectionInfo = _reflection.GeneratedProtocolMessageType('CMsgClientP2PConnectionInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTP2PCONNECTIONINFO,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientP2PConnectionInfo)
  ))
_sym_db.RegisterMessage(CMsgClientP2PConnectionInfo)

CMsgClientP2PConnectionFailInfo = _reflection.GeneratedProtocolMessageType('CMsgClientP2PConnectionFailInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTP2PCONNECTIONFAILINFO,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientP2PConnectionFailInfo)
  ))
_sym_db.RegisterMessage(CMsgClientP2PConnectionFailInfo)

CMsgClientNetworkingCertRequest = _reflection.GeneratedProtocolMessageType('CMsgClientNetworkingCertRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTNETWORKINGCERTREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientNetworkingCertRequest)
  ))
_sym_db.RegisterMessage(CMsgClientNetworkingCertRequest)

CMsgClientNetworkingCertReply = _reflection.GeneratedProtocolMessageType('CMsgClientNetworkingCertReply', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTNETWORKINGCERTREPLY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientNetworkingCertReply)
  ))
_sym_db.RegisterMessage(CMsgClientNetworkingCertReply)

CMsgClientNetworkingMobileCertRequest = _reflection.GeneratedProtocolMessageType('CMsgClientNetworkingMobileCertRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTNETWORKINGMOBILECERTREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientNetworkingMobileCertRequest)
  ))
_sym_db.RegisterMessage(CMsgClientNetworkingMobileCertRequest)

CMsgClientNetworkingMobileCertReply = _reflection.GeneratedProtocolMessageType('CMsgClientNetworkingMobileCertReply', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTNETWORKINGMOBILECERTREPLY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientNetworkingMobileCertReply)
  ))
_sym_db.RegisterMessage(CMsgClientNetworkingMobileCertReply)

CMsgClientGetAppOwnershipTicket = _reflection.GeneratedProtocolMessageType('CMsgClientGetAppOwnershipTicket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTGETAPPOWNERSHIPTICKET,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetAppOwnershipTicket)
  ))
_sym_db.RegisterMessage(CMsgClientGetAppOwnershipTicket)

CMsgClientGetAppOwnershipTicketResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetAppOwnershipTicketResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTGETAPPOWNERSHIPTICKETRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetAppOwnershipTicketResponse)
  ))
_sym_db.RegisterMessage(CMsgClientGetAppOwnershipTicketResponse)

CMsgClientSessionToken = _reflection.GeneratedProtocolMessageType('CMsgClientSessionToken', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTSESSIONTOKEN,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSessionToken)
  ))
_sym_db.RegisterMessage(CMsgClientSessionToken)

CMsgClientGameConnectTokens = _reflection.GeneratedProtocolMessageType('CMsgClientGameConnectTokens', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTGAMECONNECTTOKENS,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGameConnectTokens)
  ))
_sym_db.RegisterMessage(CMsgClientGameConnectTokens)

CMsgGSServerType = _reflection.GeneratedProtocolMessageType('CMsgGSServerType', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGSSERVERTYPE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSServerType)
  ))
_sym_db.RegisterMessage(CMsgGSServerType)

CMsgGSStatusReply = _reflection.GeneratedProtocolMessageType('CMsgGSStatusReply', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGSSTATUSREPLY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSStatusReply)
  ))
_sym_db.RegisterMessage(CMsgGSStatusReply)

CMsgGSPlayerList = _reflection.GeneratedProtocolMessageType('CMsgGSPlayerList', (_message.Message,), dict(

  Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGSPLAYERLIST_PLAYER,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgGSPlayerList.Player)
    ))
  ,
  DESCRIPTOR = _CMSGGSPLAYERLIST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSPlayerList)
  ))
_sym_db.RegisterMessage(CMsgGSPlayerList)
_sym_db.RegisterMessage(CMsgGSPlayerList.Player)

CMsgGSUserPlaying = _reflection.GeneratedProtocolMessageType('CMsgGSUserPlaying', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGSUSERPLAYING,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSUserPlaying)
  ))
_sym_db.RegisterMessage(CMsgGSUserPlaying)

CMsgGSDisconnectNotice = _reflection.GeneratedProtocolMessageType('CMsgGSDisconnectNotice', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGSDISCONNECTNOTICE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSDisconnectNotice)
  ))
_sym_db.RegisterMessage(CMsgGSDisconnectNotice)

CMsgClientGamesPlayed = _reflection.GeneratedProtocolMessageType('CMsgClientGamesPlayed', (_message.Message,), dict(

  GamePlayed = _reflection.GeneratedProtocolMessageType('GamePlayed', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTGAMESPLAYED_GAMEPLAYED,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGamesPlayed.GamePlayed)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTGAMESPLAYED,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGamesPlayed)
  ))
_sym_db.RegisterMessage(CMsgClientGamesPlayed)
_sym_db.RegisterMessage(CMsgClientGamesPlayed.GamePlayed)

CMsgGSApprove = _reflection.GeneratedProtocolMessageType('CMsgGSApprove', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGSAPPROVE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSApprove)
  ))
_sym_db.RegisterMessage(CMsgGSApprove)

CMsgGSDeny = _reflection.GeneratedProtocolMessageType('CMsgGSDeny', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGSDENY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSDeny)
  ))
_sym_db.RegisterMessage(CMsgGSDeny)

CMsgGSKick = _reflection.GeneratedProtocolMessageType('CMsgGSKick', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGSKICK,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGSKick)
  ))
_sym_db.RegisterMessage(CMsgGSKick)

CMsgClientAuthList = _reflection.GeneratedProtocolMessageType('CMsgClientAuthList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTAUTHLIST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAuthList)
  ))
_sym_db.RegisterMessage(CMsgClientAuthList)

CMsgClientAuthListAck = _reflection.GeneratedProtocolMessageType('CMsgClientAuthListAck', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTAUTHLISTACK,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAuthListAck)
  ))
_sym_db.RegisterMessage(CMsgClientAuthListAck)

CMsgClientLicenseList = _reflection.GeneratedProtocolMessageType('CMsgClientLicenseList', (_message.Message,), dict(

  License = _reflection.GeneratedProtocolMessageType('License', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTLICENSELIST_LICENSE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientLicenseList.License)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTLICENSELIST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLicenseList)
  ))
_sym_db.RegisterMessage(CMsgClientLicenseList)
_sym_db.RegisterMessage(CMsgClientLicenseList.License)

CMsgClientLBSSetScore = _reflection.GeneratedProtocolMessageType('CMsgClientLBSSetScore', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTLBSSETSCORE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSSetScore)
  ))
_sym_db.RegisterMessage(CMsgClientLBSSetScore)

CMsgClientLBSSetScoreResponse = _reflection.GeneratedProtocolMessageType('CMsgClientLBSSetScoreResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTLBSSETSCORERESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSSetScoreResponse)
  ))
_sym_db.RegisterMessage(CMsgClientLBSSetScoreResponse)

CMsgClientLBSSetUGC = _reflection.GeneratedProtocolMessageType('CMsgClientLBSSetUGC', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTLBSSETUGC,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSSetUGC)
  ))
_sym_db.RegisterMessage(CMsgClientLBSSetUGC)

CMsgClientLBSSetUGCResponse = _reflection.GeneratedProtocolMessageType('CMsgClientLBSSetUGCResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTLBSSETUGCRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSSetUGCResponse)
  ))
_sym_db.RegisterMessage(CMsgClientLBSSetUGCResponse)

CMsgClientLBSFindOrCreateLB = _reflection.GeneratedProtocolMessageType('CMsgClientLBSFindOrCreateLB', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTLBSFINDORCREATELB,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSFindOrCreateLB)
  ))
_sym_db.RegisterMessage(CMsgClientLBSFindOrCreateLB)

CMsgClientLBSFindOrCreateLBResponse = _reflection.GeneratedProtocolMessageType('CMsgClientLBSFindOrCreateLBResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTLBSFINDORCREATELBRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSFindOrCreateLBResponse)
  ))
_sym_db.RegisterMessage(CMsgClientLBSFindOrCreateLBResponse)

CMsgClientLBSGetLBEntries = _reflection.GeneratedProtocolMessageType('CMsgClientLBSGetLBEntries', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTLBSGETLBENTRIES,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSGetLBEntries)
  ))
_sym_db.RegisterMessage(CMsgClientLBSGetLBEntries)

CMsgClientLBSGetLBEntriesResponse = _reflection.GeneratedProtocolMessageType('CMsgClientLBSGetLBEntriesResponse', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTLBSGETLBENTRIESRESPONSE_ENTRY,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientLBSGetLBEntriesResponse.Entry)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTLBSGETLBENTRIESRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientLBSGetLBEntriesResponse)
  ))
_sym_db.RegisterMessage(CMsgClientLBSGetLBEntriesResponse)
_sym_db.RegisterMessage(CMsgClientLBSGetLBEntriesResponse.Entry)

CMsgClientAppMinutesPlayedData = _reflection.GeneratedProtocolMessageType('CMsgClientAppMinutesPlayedData', (_message.Message,), dict(

  AppMinutesPlayedData = _reflection.GeneratedProtocolMessageType('AppMinutesPlayedData', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTAPPMINUTESPLAYEDDATA_APPMINUTESPLAYEDDATA,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientAppMinutesPlayedData.AppMinutesPlayedData)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTAPPMINUTESPLAYEDDATA,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAppMinutesPlayedData)
  ))
_sym_db.RegisterMessage(CMsgClientAppMinutesPlayedData)
_sym_db.RegisterMessage(CMsgClientAppMinutesPlayedData.AppMinutesPlayedData)

CMsgClientIsLimitedAccount = _reflection.GeneratedProtocolMessageType('CMsgClientIsLimitedAccount', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTISLIMITEDACCOUNT,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientIsLimitedAccount)
  ))
_sym_db.RegisterMessage(CMsgClientIsLimitedAccount)

CMsgClientRequestedClientStats = _reflection.GeneratedProtocolMessageType('CMsgClientRequestedClientStats', (_message.Message,), dict(

  StatsToSend = _reflection.GeneratedProtocolMessageType('StatsToSend', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTREQUESTEDCLIENTSTATS_STATSTOSEND,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientRequestedClientStats.StatsToSend)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTREQUESTEDCLIENTSTATS,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestedClientStats)
  ))
_sym_db.RegisterMessage(CMsgClientRequestedClientStats)
_sym_db.RegisterMessage(CMsgClientRequestedClientStats.StatsToSend)

CMsgClientStat2 = _reflection.GeneratedProtocolMessageType('CMsgClientStat2', (_message.Message,), dict(

  StatDetail = _reflection.GeneratedProtocolMessageType('StatDetail', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTSTAT2_STATDETAIL,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientStat2.StatDetail)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTSTAT2,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientStat2)
  ))
_sym_db.RegisterMessage(CMsgClientStat2)
_sym_db.RegisterMessage(CMsgClientStat2.StatDetail)

CMsgClientMMSSetRatelimitPolicyOnClient = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetRatelimitPolicyOnClient', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSSETRATELIMITPOLICYONCLIENT,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetRatelimitPolicyOnClient)
  ))
_sym_db.RegisterMessage(CMsgClientMMSSetRatelimitPolicyOnClient)

CMsgClientMMSCreateLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSCreateLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSCREATELOBBY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSCreateLobby)
  ))
_sym_db.RegisterMessage(CMsgClientMMSCreateLobby)

CMsgClientMMSCreateLobbyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSCreateLobbyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSCREATELOBBYRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSCreateLobbyResponse)
  ))
_sym_db.RegisterMessage(CMsgClientMMSCreateLobbyResponse)

CMsgClientMMSJoinLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSJoinLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSJOINLOBBY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSJoinLobby)
  ))
_sym_db.RegisterMessage(CMsgClientMMSJoinLobby)

CMsgClientMMSJoinLobbyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSJoinLobbyResponse', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTMMSJOINLOBBYRESPONSE_MEMBER,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientMMSJoinLobbyResponse.Member)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTMMSJOINLOBBYRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSJoinLobbyResponse)
  ))
_sym_db.RegisterMessage(CMsgClientMMSJoinLobbyResponse)
_sym_db.RegisterMessage(CMsgClientMMSJoinLobbyResponse.Member)

CMsgClientMMSLeaveLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSLeaveLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSLEAVELOBBY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSLeaveLobby)
  ))
_sym_db.RegisterMessage(CMsgClientMMSLeaveLobby)

CMsgClientMMSLeaveLobbyResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSLeaveLobbyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSLEAVELOBBYRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSLeaveLobbyResponse)
  ))
_sym_db.RegisterMessage(CMsgClientMMSLeaveLobbyResponse)

CMsgClientMMSGetLobbyList = _reflection.GeneratedProtocolMessageType('CMsgClientMMSGetLobbyList', (_message.Message,), dict(

  Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTMMSGETLOBBYLIST_FILTER,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyList.Filter)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTMMSGETLOBBYLIST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyList)
  ))
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyList)
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyList.Filter)

CMsgClientMMSGetLobbyListResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSGetLobbyListResponse', (_message.Message,), dict(

  Lobby = _reflection.GeneratedProtocolMessageType('Lobby', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTMMSGETLOBBYLISTRESPONSE_LOBBY,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyListResponse.Lobby)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTMMSGETLOBBYLISTRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyListResponse)
  ))
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyListResponse)
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyListResponse.Lobby)

CMsgClientMMSSetLobbyData = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSSETLOBBYDATA,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyData)
  ))
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyData)

CMsgClientMMSSetLobbyDataResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSSETLOBBYDATARESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyDataResponse)
  ))
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyDataResponse)

CMsgClientMMSGetLobbyData = _reflection.GeneratedProtocolMessageType('CMsgClientMMSGetLobbyData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSGETLOBBYDATA,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyData)
  ))
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyData)

CMsgClientMMSLobbyData = _reflection.GeneratedProtocolMessageType('CMsgClientMMSLobbyData', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTMMSLOBBYDATA_MEMBER,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientMMSLobbyData.Member)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTMMSLOBBYDATA,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSLobbyData)
  ))
_sym_db.RegisterMessage(CMsgClientMMSLobbyData)
_sym_db.RegisterMessage(CMsgClientMMSLobbyData.Member)

CMsgClientMMSSendLobbyChatMsg = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSendLobbyChatMsg', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSSENDLOBBYCHATMSG,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSendLobbyChatMsg)
  ))
_sym_db.RegisterMessage(CMsgClientMMSSendLobbyChatMsg)

CMsgClientMMSLobbyChatMsg = _reflection.GeneratedProtocolMessageType('CMsgClientMMSLobbyChatMsg', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSLOBBYCHATMSG,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSLobbyChatMsg)
  ))
_sym_db.RegisterMessage(CMsgClientMMSLobbyChatMsg)

CMsgClientMMSSetLobbyOwner = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyOwner', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSSETLOBBYOWNER,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyOwner)
  ))
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyOwner)

CMsgClientMMSSetLobbyOwnerResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyOwnerResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSSETLOBBYOWNERRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyOwnerResponse)
  ))
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyOwnerResponse)

CMsgClientMMSSetLobbyLinked = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyLinked', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSSETLOBBYLINKED,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyLinked)
  ))
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyLinked)

CMsgClientMMSSetLobbyGameServer = _reflection.GeneratedProtocolMessageType('CMsgClientMMSSetLobbyGameServer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSSETLOBBYGAMESERVER,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSSetLobbyGameServer)
  ))
_sym_db.RegisterMessage(CMsgClientMMSSetLobbyGameServer)

CMsgClientMMSLobbyGameServerSet = _reflection.GeneratedProtocolMessageType('CMsgClientMMSLobbyGameServerSet', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSLOBBYGAMESERVERSET,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSLobbyGameServerSet)
  ))
_sym_db.RegisterMessage(CMsgClientMMSLobbyGameServerSet)

CMsgClientMMSUserJoinedLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSUserJoinedLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSUSERJOINEDLOBBY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSUserJoinedLobby)
  ))
_sym_db.RegisterMessage(CMsgClientMMSUserJoinedLobby)

CMsgClientMMSUserLeftLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSUserLeftLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSUSERLEFTLOBBY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSUserLeftLobby)
  ))
_sym_db.RegisterMessage(CMsgClientMMSUserLeftLobby)

CMsgClientMMSInviteToLobby = _reflection.GeneratedProtocolMessageType('CMsgClientMMSInviteToLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSINVITETOLOBBY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSInviteToLobby)
  ))
_sym_db.RegisterMessage(CMsgClientMMSInviteToLobby)

CMsgClientMMSGetLobbyStatus = _reflection.GeneratedProtocolMessageType('CMsgClientMMSGetLobbyStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSGETLOBBYSTATUS,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyStatus)
  ))
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyStatus)

CMsgClientMMSGetLobbyStatusResponse = _reflection.GeneratedProtocolMessageType('CMsgClientMMSGetLobbyStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTMMSGETLOBBYSTATUSRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientMMSGetLobbyStatusResponse)
  ))
_sym_db.RegisterMessage(CMsgClientMMSGetLobbyStatusResponse)

CMsgClientInviteToGame = _reflection.GeneratedProtocolMessageType('CMsgClientInviteToGame', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTINVITETOGAME,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientInviteToGame)
  ))
_sym_db.RegisterMessage(CMsgClientInviteToGame)

CMsgClientChatInvite = _reflection.GeneratedProtocolMessageType('CMsgClientChatInvite', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTCHATINVITE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientChatInvite)
  ))
_sym_db.RegisterMessage(CMsgClientChatInvite)

CMsgClientConnectionStats = _reflection.GeneratedProtocolMessageType('CMsgClientConnectionStats', (_message.Message,), dict(

  Stats_Logon = _reflection.GeneratedProtocolMessageType('Stats_Logon', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTCONNECTIONSTATS_STATS_LOGON,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientConnectionStats.Stats_Logon)
    ))
  ,

  Stats_UDP = _reflection.GeneratedProtocolMessageType('Stats_UDP', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTCONNECTIONSTATS_STATS_UDP,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientConnectionStats.Stats_UDP)
    ))
  ,

  Stats_VConn = _reflection.GeneratedProtocolMessageType('Stats_VConn', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTCONNECTIONSTATS_STATS_VCONN,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientConnectionStats.Stats_VConn)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTCONNECTIONSTATS,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientConnectionStats)
  ))
_sym_db.RegisterMessage(CMsgClientConnectionStats)
_sym_db.RegisterMessage(CMsgClientConnectionStats.Stats_Logon)
_sym_db.RegisterMessage(CMsgClientConnectionStats.Stats_UDP)
_sym_db.RegisterMessage(CMsgClientConnectionStats.Stats_VConn)

CMsgClientServersAvailable = _reflection.GeneratedProtocolMessageType('CMsgClientServersAvailable', (_message.Message,), dict(

  Server_Types_Available = _reflection.GeneratedProtocolMessageType('Server_Types_Available', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTSERVERSAVAILABLE_SERVER_TYPES_AVAILABLE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientServersAvailable.Server_Types_Available)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTSERVERSAVAILABLE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientServersAvailable)
  ))
_sym_db.RegisterMessage(CMsgClientServersAvailable)
_sym_db.RegisterMessage(CMsgClientServersAvailable.Server_Types_Available)

CMsgClientGetUserStats = _reflection.GeneratedProtocolMessageType('CMsgClientGetUserStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTGETUSERSTATS,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetUserStats)
  ))
_sym_db.RegisterMessage(CMsgClientGetUserStats)

CMsgClientGetUserStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetUserStatsResponse', (_message.Message,), dict(

  Stats = _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTGETUSERSTATSRESPONSE_STATS,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetUserStatsResponse.Stats)
    ))
  ,

  Achievement_Blocks = _reflection.GeneratedProtocolMessageType('Achievement_Blocks', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTGETUSERSTATSRESPONSE_ACHIEVEMENT_BLOCKS,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetUserStatsResponse.Achievement_Blocks)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTGETUSERSTATSRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetUserStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientGetUserStatsResponse)
_sym_db.RegisterMessage(CMsgClientGetUserStatsResponse.Stats)
_sym_db.RegisterMessage(CMsgClientGetUserStatsResponse.Achievement_Blocks)

CMsgClientStoreUserStatsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientStoreUserStatsResponse', (_message.Message,), dict(

  Stats_Failed_Validation = _reflection.GeneratedProtocolMessageType('Stats_Failed_Validation', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTSTOREUSERSTATSRESPONSE_STATS_FAILED_VALIDATION,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStatsResponse.Stats_Failed_Validation)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTSTOREUSERSTATSRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStatsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientStoreUserStatsResponse)
_sym_db.RegisterMessage(CMsgClientStoreUserStatsResponse.Stats_Failed_Validation)

CMsgClientStoreUserStats2 = _reflection.GeneratedProtocolMessageType('CMsgClientStoreUserStats2', (_message.Message,), dict(

  Stats = _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTSTOREUSERSTATS2_STATS,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStats2.Stats)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTSTOREUSERSTATS2,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStats2)
  ))
_sym_db.RegisterMessage(CMsgClientStoreUserStats2)
_sym_db.RegisterMessage(CMsgClientStoreUserStats2.Stats)

CMsgClientStatsUpdated = _reflection.GeneratedProtocolMessageType('CMsgClientStatsUpdated', (_message.Message,), dict(

  Updated_Stats = _reflection.GeneratedProtocolMessageType('Updated_Stats', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTSTATSUPDATED_UPDATED_STATS,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientStatsUpdated.Updated_Stats)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTSTATSUPDATED,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientStatsUpdated)
  ))
_sym_db.RegisterMessage(CMsgClientStatsUpdated)
_sym_db.RegisterMessage(CMsgClientStatsUpdated.Updated_Stats)

CMsgClientStoreUserStats = _reflection.GeneratedProtocolMessageType('CMsgClientStoreUserStats', (_message.Message,), dict(

  Stats_To_Store = _reflection.GeneratedProtocolMessageType('Stats_To_Store', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTSTOREUSERSTATS_STATS_TO_STORE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStats.Stats_To_Store)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTSTOREUSERSTATS,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientStoreUserStats)
  ))
_sym_db.RegisterMessage(CMsgClientStoreUserStats)
_sym_db.RegisterMessage(CMsgClientStoreUserStats.Stats_To_Store)

CMsgClientGetClientDetails = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientDetails', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTGETCLIENTDETAILS,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientDetails)
  ))
_sym_db.RegisterMessage(CMsgClientGetClientDetails)

CMsgClientReportOverlayDetourFailure = _reflection.GeneratedProtocolMessageType('CMsgClientReportOverlayDetourFailure', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTREPORTOVERLAYDETOURFAILURE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientReportOverlayDetourFailure)
  ))
_sym_db.RegisterMessage(CMsgClientReportOverlayDetourFailure)

CMsgClientGetClientDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientDetailsResponse', (_message.Message,), dict(

  Game = _reflection.GeneratedProtocolMessageType('Game', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetClientDetailsResponse.Game)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTGETCLIENTDETAILSRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientGetClientDetailsResponse)
_sym_db.RegisterMessage(CMsgClientGetClientDetailsResponse.Game)

CMsgClientGetClientAppList = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientAppList', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTGETCLIENTAPPLIST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppList)
  ))
_sym_db.RegisterMessage(CMsgClientGetClientAppList)

CMsgClientGetClientAppListResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientAppListResponse', (_message.Message,), dict(

  App = _reflection.GeneratedProtocolMessageType('App', (_message.Message,), dict(

    DLC = _reflection.GeneratedProtocolMessageType('DLC', (_message.Message,), dict(
      DESCRIPTOR = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC,
      __module__ = 'steammessages_clientserver_pb2'
      # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppListResponse.App.DLC)
      ))
    ,
    DESCRIPTOR = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppListResponse.App)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppListResponse)
  ))
_sym_db.RegisterMessage(CMsgClientGetClientAppListResponse)
_sym_db.RegisterMessage(CMsgClientGetClientAppListResponse.App)
_sym_db.RegisterMessage(CMsgClientGetClientAppListResponse.App.DLC)

CMsgClientInstallClientApp = _reflection.GeneratedProtocolMessageType('CMsgClientInstallClientApp', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTINSTALLCLIENTAPP,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientInstallClientApp)
  ))
_sym_db.RegisterMessage(CMsgClientInstallClientApp)

CMsgClientInstallClientAppResponse = _reflection.GeneratedProtocolMessageType('CMsgClientInstallClientAppResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTINSTALLCLIENTAPPRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientInstallClientAppResponse)
  ))
_sym_db.RegisterMessage(CMsgClientInstallClientAppResponse)

CMsgClientUninstallClientApp = _reflection.GeneratedProtocolMessageType('CMsgClientUninstallClientApp', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUNINSTALLCLIENTAPP,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUninstallClientApp)
  ))
_sym_db.RegisterMessage(CMsgClientUninstallClientApp)

CMsgClientUninstallClientAppResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUninstallClientAppResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUninstallClientAppResponse)
  ))
_sym_db.RegisterMessage(CMsgClientUninstallClientAppResponse)

CMsgClientSetClientAppUpdateState = _reflection.GeneratedProtocolMessageType('CMsgClientSetClientAppUpdateState', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTSETCLIENTAPPUPDATESTATE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSetClientAppUpdateState)
  ))
_sym_db.RegisterMessage(CMsgClientSetClientAppUpdateState)

CMsgClientSetClientAppUpdateStateResponse = _reflection.GeneratedProtocolMessageType('CMsgClientSetClientAppUpdateStateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSetClientAppUpdateStateResponse)
  ))
_sym_db.RegisterMessage(CMsgClientSetClientAppUpdateStateResponse)

CMsgClientUFSUploadFileRequest = _reflection.GeneratedProtocolMessageType('CMsgClientUFSUploadFileRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSUPLOADFILEREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadFileRequest)
  ))
_sym_db.RegisterMessage(CMsgClientUFSUploadFileRequest)

CMsgClientUFSUploadFileResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSUploadFileResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSUPLOADFILERESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadFileResponse)
  ))
_sym_db.RegisterMessage(CMsgClientUFSUploadFileResponse)

CMsgClientUFSUploadCommit = _reflection.GeneratedProtocolMessageType('CMsgClientUFSUploadCommit', (_message.Message,), dict(

  File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTUFSUPLOADCOMMIT_FILE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadCommit.File)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTUFSUPLOADCOMMIT,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadCommit)
  ))
_sym_db.RegisterMessage(CMsgClientUFSUploadCommit)
_sym_db.RegisterMessage(CMsgClientUFSUploadCommit.File)

CMsgClientUFSUploadCommitResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSUploadCommitResponse', (_message.Message,), dict(

  File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTUFSUPLOADCOMMITRESPONSE_FILE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadCommitResponse.File)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTUFSUPLOADCOMMITRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadCommitResponse)
  ))
_sym_db.RegisterMessage(CMsgClientUFSUploadCommitResponse)
_sym_db.RegisterMessage(CMsgClientUFSUploadCommitResponse.File)

CMsgClientUFSFileChunk = _reflection.GeneratedProtocolMessageType('CMsgClientUFSFileChunk', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSFILECHUNK,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSFileChunk)
  ))
_sym_db.RegisterMessage(CMsgClientUFSFileChunk)

CMsgClientUFSTransferHeartbeat = _reflection.GeneratedProtocolMessageType('CMsgClientUFSTransferHeartbeat', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSTRANSFERHEARTBEAT,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSTransferHeartbeat)
  ))
_sym_db.RegisterMessage(CMsgClientUFSTransferHeartbeat)

CMsgClientUFSUploadFileFinished = _reflection.GeneratedProtocolMessageType('CMsgClientUFSUploadFileFinished', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSUPLOADFILEFINISHED,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadFileFinished)
  ))
_sym_db.RegisterMessage(CMsgClientUFSUploadFileFinished)

CMsgClientUFSDeleteFileRequest = _reflection.GeneratedProtocolMessageType('CMsgClientUFSDeleteFileRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSDELETEFILEREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSDeleteFileRequest)
  ))
_sym_db.RegisterMessage(CMsgClientUFSDeleteFileRequest)

CMsgClientUFSDeleteFileResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSDeleteFileResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSDELETEFILERESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSDeleteFileResponse)
  ))
_sym_db.RegisterMessage(CMsgClientUFSDeleteFileResponse)

CMsgClientUFSGetFileListForApp = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetFileListForApp', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSGETFILELISTFORAPP,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetFileListForApp)
  ))
_sym_db.RegisterMessage(CMsgClientUFSGetFileListForApp)

CMsgClientUFSGetFileListForAppResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetFileListForAppResponse', (_message.Message,), dict(

  File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE_FILE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientUFSGetFileListForAppResponse.File)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetFileListForAppResponse)
  ))
_sym_db.RegisterMessage(CMsgClientUFSGetFileListForAppResponse)
_sym_db.RegisterMessage(CMsgClientUFSGetFileListForAppResponse.File)

CMsgClientUFSDownloadRequest = _reflection.GeneratedProtocolMessageType('CMsgClientUFSDownloadRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSDOWNLOADREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSDownloadRequest)
  ))
_sym_db.RegisterMessage(CMsgClientUFSDownloadRequest)

CMsgClientUFSDownloadResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSDownloadResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSDOWNLOADRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSDownloadResponse)
  ))
_sym_db.RegisterMessage(CMsgClientUFSDownloadResponse)

CMsgClientUFSLoginRequest = _reflection.GeneratedProtocolMessageType('CMsgClientUFSLoginRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSLOGINREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSLoginRequest)
  ))
_sym_db.RegisterMessage(CMsgClientUFSLoginRequest)

CMsgClientUFSLoginResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSLoginResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSLOGINRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSLoginResponse)
  ))
_sym_db.RegisterMessage(CMsgClientUFSLoginResponse)

CMsgClientRequestEncryptedAppTicket = _reflection.GeneratedProtocolMessageType('CMsgClientRequestEncryptedAppTicket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTREQUESTENCRYPTEDAPPTICKET,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestEncryptedAppTicket)
  ))
_sym_db.RegisterMessage(CMsgClientRequestEncryptedAppTicket)

CMsgClientRequestEncryptedAppTicketResponse = _reflection.GeneratedProtocolMessageType('CMsgClientRequestEncryptedAppTicketResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTREQUESTENCRYPTEDAPPTICKETRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientRequestEncryptedAppTicketResponse)
  ))
_sym_db.RegisterMessage(CMsgClientRequestEncryptedAppTicketResponse)

CMsgClientWalletInfoUpdate = _reflection.GeneratedProtocolMessageType('CMsgClientWalletInfoUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTWALLETINFOUPDATE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientWalletInfoUpdate)
  ))
_sym_db.RegisterMessage(CMsgClientWalletInfoUpdate)

CMsgClientAppInfoUpdate = _reflection.GeneratedProtocolMessageType('CMsgClientAppInfoUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTAPPINFOUPDATE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAppInfoUpdate)
  ))
_sym_db.RegisterMessage(CMsgClientAppInfoUpdate)

CMsgClientAppInfoChanges = _reflection.GeneratedProtocolMessageType('CMsgClientAppInfoChanges', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTAPPINFOCHANGES,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAppInfoChanges)
  ))
_sym_db.RegisterMessage(CMsgClientAppInfoChanges)

CMsgClientAppInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgClientAppInfoRequest', (_message.Message,), dict(

  App = _reflection.GeneratedProtocolMessageType('App', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTAPPINFOREQUEST_APP,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientAppInfoRequest.App)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTAPPINFOREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAppInfoRequest)
  ))
_sym_db.RegisterMessage(CMsgClientAppInfoRequest)
_sym_db.RegisterMessage(CMsgClientAppInfoRequest.App)

CMsgClientAppInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgClientAppInfoResponse', (_message.Message,), dict(

  App = _reflection.GeneratedProtocolMessageType('App', (_message.Message,), dict(

    Section = _reflection.GeneratedProtocolMessageType('Section', (_message.Message,), dict(
      DESCRIPTOR = _CMSGCLIENTAPPINFORESPONSE_APP_SECTION,
      __module__ = 'steammessages_clientserver_pb2'
      # @@protoc_insertion_point(class_scope:CMsgClientAppInfoResponse.App.Section)
      ))
    ,
    DESCRIPTOR = _CMSGCLIENTAPPINFORESPONSE_APP,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientAppInfoResponse.App)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTAPPINFORESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAppInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgClientAppInfoResponse)
_sym_db.RegisterMessage(CMsgClientAppInfoResponse.App)
_sym_db.RegisterMessage(CMsgClientAppInfoResponse.App.Section)

CMsgClientPackageInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgClientPackageInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTPACKAGEINFOREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPackageInfoRequest)
  ))
_sym_db.RegisterMessage(CMsgClientPackageInfoRequest)

CMsgClientPackageInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgClientPackageInfoResponse', (_message.Message,), dict(

  Package = _reflection.GeneratedProtocolMessageType('Package', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPACKAGEINFORESPONSE_PACKAGE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPackageInfoResponse.Package)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTPACKAGEINFORESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPackageInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgClientPackageInfoResponse)
_sym_db.RegisterMessage(CMsgClientPackageInfoResponse.Package)

CMsgClientPICSChangesSinceRequest = _reflection.GeneratedProtocolMessageType('CMsgClientPICSChangesSinceRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTPICSCHANGESSINCEREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPICSChangesSinceRequest)
  ))
_sym_db.RegisterMessage(CMsgClientPICSChangesSinceRequest)

CMsgClientPICSChangesSinceResponse = _reflection.GeneratedProtocolMessageType('CMsgClientPICSChangesSinceResponse', (_message.Message,), dict(

  PackageChange = _reflection.GeneratedProtocolMessageType('PackageChange', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPICSCHANGESSINCERESPONSE_PACKAGECHANGE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPICSChangesSinceResponse.PackageChange)
    ))
  ,

  AppChange = _reflection.GeneratedProtocolMessageType('AppChange', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPICSCHANGESSINCERESPONSE_APPCHANGE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPICSChangesSinceResponse.AppChange)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTPICSCHANGESSINCERESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPICSChangesSinceResponse)
  ))
_sym_db.RegisterMessage(CMsgClientPICSChangesSinceResponse)
_sym_db.RegisterMessage(CMsgClientPICSChangesSinceResponse.PackageChange)
_sym_db.RegisterMessage(CMsgClientPICSChangesSinceResponse.AppChange)

CMsgClientPICSProductInfoRequest = _reflection.GeneratedProtocolMessageType('CMsgClientPICSProductInfoRequest', (_message.Message,), dict(

  AppInfo = _reflection.GeneratedProtocolMessageType('AppInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPICSPRODUCTINFOREQUEST_APPINFO,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPICSProductInfoRequest.AppInfo)
    ))
  ,

  PackageInfo = _reflection.GeneratedProtocolMessageType('PackageInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPICSPRODUCTINFOREQUEST_PACKAGEINFO,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPICSProductInfoRequest.PackageInfo)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTPICSPRODUCTINFOREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPICSProductInfoRequest)
  ))
_sym_db.RegisterMessage(CMsgClientPICSProductInfoRequest)
_sym_db.RegisterMessage(CMsgClientPICSProductInfoRequest.AppInfo)
_sym_db.RegisterMessage(CMsgClientPICSProductInfoRequest.PackageInfo)

CMsgClientPICSProductInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgClientPICSProductInfoResponse', (_message.Message,), dict(

  AppInfo = _reflection.GeneratedProtocolMessageType('AppInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPICSPRODUCTINFORESPONSE_APPINFO,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPICSProductInfoResponse.AppInfo)
    ))
  ,

  PackageInfo = _reflection.GeneratedProtocolMessageType('PackageInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPICSPRODUCTINFORESPONSE_PACKAGEINFO,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPICSProductInfoResponse.PackageInfo)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTPICSPRODUCTINFORESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPICSProductInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgClientPICSProductInfoResponse)
_sym_db.RegisterMessage(CMsgClientPICSProductInfoResponse.AppInfo)
_sym_db.RegisterMessage(CMsgClientPICSProductInfoResponse.PackageInfo)

CMsgClientPICSAccessTokenRequest = _reflection.GeneratedProtocolMessageType('CMsgClientPICSAccessTokenRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTPICSACCESSTOKENREQUEST,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPICSAccessTokenRequest)
  ))
_sym_db.RegisterMessage(CMsgClientPICSAccessTokenRequest)

CMsgClientPICSAccessTokenResponse = _reflection.GeneratedProtocolMessageType('CMsgClientPICSAccessTokenResponse', (_message.Message,), dict(

  PackageToken = _reflection.GeneratedProtocolMessageType('PackageToken', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPICSACCESSTOKENRESPONSE_PACKAGETOKEN,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPICSAccessTokenResponse.PackageToken)
    ))
  ,

  AppToken = _reflection.GeneratedProtocolMessageType('AppToken', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTPICSACCESSTOKENRESPONSE_APPTOKEN,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientPICSAccessTokenResponse.AppToken)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTPICSACCESSTOKENRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPICSAccessTokenResponse)
  ))
_sym_db.RegisterMessage(CMsgClientPICSAccessTokenResponse)
_sym_db.RegisterMessage(CMsgClientPICSAccessTokenResponse.PackageToken)
_sym_db.RegisterMessage(CMsgClientPICSAccessTokenResponse.AppToken)

CMsgClientUFSGetUGCDetails = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetUGCDetails', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSGETUGCDETAILS,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetUGCDetails)
  ))
_sym_db.RegisterMessage(CMsgClientUFSGetUGCDetails)

CMsgClientUFSGetUGCDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetUGCDetailsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSGETUGCDETAILSRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetUGCDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgClientUFSGetUGCDetailsResponse)

CMsgClientUFSGetSingleFileInfo = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetSingleFileInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSGETSINGLEFILEINFO,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetSingleFileInfo)
  ))
_sym_db.RegisterMessage(CMsgClientUFSGetSingleFileInfo)

CMsgClientUFSGetSingleFileInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetSingleFileInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSGETSINGLEFILEINFORESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetSingleFileInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgClientUFSGetSingleFileInfoResponse)

CMsgClientUFSShareFile = _reflection.GeneratedProtocolMessageType('CMsgClientUFSShareFile', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSSHAREFILE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSShareFile)
  ))
_sym_db.RegisterMessage(CMsgClientUFSShareFile)

CMsgClientUFSShareFileResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSShareFileResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUFSSHAREFILERESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSShareFileResponse)
  ))
_sym_db.RegisterMessage(CMsgClientUFSShareFileResponse)

CMsgClientAMGetClanOfficers = _reflection.GeneratedProtocolMessageType('CMsgClientAMGetClanOfficers', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTAMGETCLANOFFICERS,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAMGetClanOfficers)
  ))
_sym_db.RegisterMessage(CMsgClientAMGetClanOfficers)

CMsgClientAMGetClanOfficersResponse = _reflection.GeneratedProtocolMessageType('CMsgClientAMGetClanOfficersResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTAMGETCLANOFFICERSRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAMGetClanOfficersResponse)
  ))
_sym_db.RegisterMessage(CMsgClientAMGetClanOfficersResponse)

CMsgClientAMGetPersonaNameHistory = _reflection.GeneratedProtocolMessageType('CMsgClientAMGetPersonaNameHistory', (_message.Message,), dict(

  IdInstance = _reflection.GeneratedProtocolMessageType('IdInstance', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTAMGETPERSONANAMEHISTORY_IDINSTANCE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientAMGetPersonaNameHistory.IdInstance)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTAMGETPERSONANAMEHISTORY,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAMGetPersonaNameHistory)
  ))
_sym_db.RegisterMessage(CMsgClientAMGetPersonaNameHistory)
_sym_db.RegisterMessage(CMsgClientAMGetPersonaNameHistory.IdInstance)

CMsgClientAMGetPersonaNameHistoryResponse = _reflection.GeneratedProtocolMessageType('CMsgClientAMGetPersonaNameHistoryResponse', (_message.Message,), dict(

  NameTableInstance = _reflection.GeneratedProtocolMessageType('NameTableInstance', (_message.Message,), dict(

    NameInstance = _reflection.GeneratedProtocolMessageType('NameInstance', (_message.Message,), dict(
      DESCRIPTOR = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE_NAMEINSTANCE,
      __module__ = 'steammessages_clientserver_pb2'
      # @@protoc_insertion_point(class_scope:CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance)
      ))
    ,
    DESCRIPTOR = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE_NAMETABLEINSTANCE,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTAMGETPERSONANAMEHISTORYRESPONSE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientAMGetPersonaNameHistoryResponse)
  ))
_sym_db.RegisterMessage(CMsgClientAMGetPersonaNameHistoryResponse)
_sym_db.RegisterMessage(CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance)
_sym_db.RegisterMessage(CMsgClientAMGetPersonaNameHistoryResponse.NameTableInstance.NameInstance)

CMsgClientDeregisterWithServer = _reflection.GeneratedProtocolMessageType('CMsgClientDeregisterWithServer', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTDEREGISTERWITHSERVER,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientDeregisterWithServer)
  ))
_sym_db.RegisterMessage(CMsgClientDeregisterWithServer)

CMsgClientClanState = _reflection.GeneratedProtocolMessageType('CMsgClientClanState', (_message.Message,), dict(

  NameInfo = _reflection.GeneratedProtocolMessageType('NameInfo', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTCLANSTATE_NAMEINFO,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientClanState.NameInfo)
    ))
  ,

  UserCounts = _reflection.GeneratedProtocolMessageType('UserCounts', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTCLANSTATE_USERCOUNTS,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientClanState.UserCounts)
    ))
  ,

  Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTCLANSTATE_EVENT,
    __module__ = 'steammessages_clientserver_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientClanState.Event)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTCLANSTATE,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientClanState)
  ))
_sym_db.RegisterMessage(CMsgClientClanState)
_sym_db.RegisterMessage(CMsgClientClanState.NameInfo)
_sym_db.RegisterMessage(CMsgClientClanState.UserCounts)
_sym_db.RegisterMessage(CMsgClientClanState.Event)

CMsgClientUnsignedInstallScript = _reflection.GeneratedProtocolMessageType('CMsgClientUnsignedInstallScript', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTUNSIGNEDINSTALLSCRIPT,
  __module__ = 'steammessages_clientserver_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUnsignedInstallScript)
  ))
_sym_db.RegisterMessage(CMsgClientUnsignedInstallScript)


DESCRIPTOR._options = None
_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE._options = None
_CMSGCLIENTWALLETINFOUPDATE.fields_by_name['balance64']._options = None
_CMSGCLIENTWALLETINFOUPDATE.fields_by_name['balance64_delayed']._options = None
_CMSGCLIENTAPPINFORESPONSE._options = None
_CMSGCLIENTPICSPRODUCTINFORESPONSE._options = None
# @@protoc_insertion_point(module_scope)
